package com.gyh.wifidata.util;

import java.util.concurrent.Callable;
import java.util.concurrent.ExecutorService;
import java.util.concurrent.Future;
import java.util.concurrent.LinkedBlockingQueue;
import java.util.concurrent.RejectedExecutionHandler;
import java.util.concurrent.ThreadPoolExecutor;
import java.util.concurrent.TimeUnit;
import kotlin.Metadata;
import kotlin.Unit;
import kotlin.jvm.functions.Function0;
import kotlin.jvm.internal.Intrinsics;
/* compiled from: ThreadManager.kt */
@Metadata(bv = {1, 0, 3}, d1 = {"\u0000<\n\u0002\u0018\u0002\n\u0002\u0010\u0000\n\u0002\b\u0002\n\u0002\u0018\u0002\n\u0002\b\u0003\n\u0002\u0010\b\n\u0002\b\u0005\n\u0002\u0010\u0002\n\u0000\n\u0002\u0018\u0002\n\u0002\u0018\u0002\n\u0002\b\u0002\n\u0002\u0018\u0002\n\u0002\b\u0002\n\u0002\u0018\u0002\n\u0000\bÆ\u0002\u0018\u00002\u00020\u0001B\u0007\b\u0002¢\u0006\u0002\u0010\u0002J\u0014\u0010\r\u001a\u00020\u000e2\f\u0010\u000f\u001a\b\u0012\u0004\u0012\u00020\u000e0\u0010J\u000e\u0010\r\u001a\u00020\u000e2\u0006\u0010\u000f\u001a\u00020\u0011J\u0006\u0010\u0012\u001a\u00020\u000eJ \u0010\u0013\u001a\b\u0012\u0004\u0012\u0002H\u00150\u0014\"\u0004\b\u0000\u0010\u00152\f\u0010\u0016\u001a\b\u0012\u0004\u0012\u0002H\u00150\u0017R\u0011\u0010\u0003\u001a\u00020\u0004¢\u0006\b\n\u0000\u001a\u0004\b\u0005\u0010\u0006R\u001a\u0010\u0007\u001a\u00020\bX\u0086\u000e¢\u0006\u000e\n\u0000\u001a\u0004\b\t\u0010\n\"\u0004\b\u000b\u0010\f¨\u0006\u0018"}, d2 = {"Lcom/gyh/wifidata/util/ThreadManager;", "", "()V", "executorService", "Ljava/util/concurrent/ExecutorService;", "getExecutorService", "()Ljava/util/concurrent/ExecutorService;", "poolSize", "", "getPoolSize", "()I", "setPoolSize", "(I)V", "execute", "", "command", "Lkotlin/Function0;", "Ljava/lang/Runnable;", "shutdown", "submit", "Ljava/util/concurrent/Future;", "T", "task", "Ljava/util/concurrent/Callable;", "app_debug"}, k = 1, mv = {1, 1, 16})
/* loaded from: classes2.dex */
public final class ThreadManager {
    private static final ExecutorService executorService;
    public static final ThreadManager INSTANCE = new ThreadManager();
    private static int poolSize = 4;

    static {
        int i = poolSize;
        executorService = new ThreadPoolExecutor(i, i, 0L, TimeUnit.MINUTES, new LinkedBlockingQueue(4), AnonymousClass1.INSTANCE);
    }

    private ThreadManager() {
    }

    public final ExecutorService getExecutorService() {
        return executorService;
    }

    public final <T> Future<T> submit(Callable<T> task) {
        Intrinsics.checkParameterIsNotNull(task, "task");
        Future<T> submit = executorService.submit(task);
        Intrinsics.checkExpressionValueIsNotNull(submit, "executorService.submit(task)");
        return submit;
    }

    public final void execute(Runnable command) {
        Intrinsics.checkParameterIsNotNull(command, "command");
        executorService.execute(command);
    }

    public final void execute(final Function0<Unit> command) {
        Intrinsics.checkParameterIsNotNull(command, "command");
        executorService.execute(new Runnable() { // from class: com.gyh.wifidata.util.ThreadManager$sam$java_lang_Runnable$0
            @Override // java.lang.Runnable
            public final /* synthetic */ void run() {
                Intrinsics.checkExpressionValueIsNotNull(Function0.this.invoke(), "invoke(...)");
            }
        });
    }

    public final void shutdown() {
        executorService.shutdown();
    }

    public final int getPoolSize() {
        return poolSize;
    }

    public final void setPoolSize(int i) {
        poolSize = i;
    }

    /* compiled from: ThreadManager.kt */
    @Metadata(bv = {1, 0, 3}, d1 = {"\u0000\u0014\n\u0000\n\u0002\u0010\u0002\n\u0000\n\u0002\u0018\u0002\n\u0000\n\u0002\u0018\u0002\n\u0000\u0010\u0000\u001a\u00020\u00012\u0006\u0010\u0002\u001a\u00020\u00032\u0006\u0010\u0004\u001a\u00020\u0005H\n¢\u0006\u0002\b\u0006"}, d2 = {"<anonymous>", "", "run", "Ljava/lang/Runnable;", "executor", "Ljava/util/concurrent/ThreadPoolExecutor;", "rejectedExecution"}, k = 3, mv = {1, 1, 16})
    /* renamed from: com.gyh.wifidata.util.ThreadManager$1  reason: invalid class name */
    /* loaded from: classes2.dex */
    static final class AnonymousClass1 implements RejectedExecutionHandler {
        public static final AnonymousClass1 INSTANCE = new AnonymousClass1();

        AnonymousClass1() {
        }

        @Override // java.util.concurrent.RejectedExecutionHandler
        public final void rejectedExecution(Runnable run, ThreadPoolExecutor executor) {
            Intrinsics.checkParameterIsNotNull(run, "run");
            Intrinsics.checkParameterIsNotNull(executor, "executor");
            if (!executor.isShutdown()) {
                try {
                    executor.getQueue().put(run);
                } catch (InterruptedException e) {
                    e.printStackTrace();
                }
            }
        }
    }
}
