package com.gyh.wifidata.view;

import android.app.Activity;
import android.app.Application;
import android.content.Context;
import android.content.DialogInterface;
import android.content.Intent;
import android.graphics.Color;
import android.net.Uri;
import android.os.Bundle;
import android.os.Handler;
import android.os.Looper;
import android.os.Message;
import android.text.Html;
import android.text.Spanned;
import android.text.TextUtils;
import android.util.Log;
import android.util.TypedValue;
import android.view.KeyEvent;
import android.view.MotionEvent;
import android.view.View;
import android.view.ViewGroup;
import android.widget.AbsListView;
import android.widget.AdapterView;
import android.widget.ArrayAdapter;
import android.widget.Button;
import android.widget.EditText;
import android.widget.FrameLayout;
import android.widget.LinearLayout;
import android.widget.ListAdapter;
import android.widget.ListView;
import android.widget.Spinner;
import android.widget.SpinnerAdapter;
import android.widget.TextView;
import android.widget.Toast;
import androidx.appcompat.app.AlertDialog;
import androidx.core.view.ViewCompat;
import androidx.customview.widget.ViewDragHelper;
import androidx.vectordrawable.graphics.drawable.PathInterpolatorCompat;
import com.gyh.wifidata.common.MessageDecoder;
import com.gyh.wifidata.util.ThreadManager;
import java.io.ByteArrayOutputStream;
import java.io.IOException;
import java.io.OutputStream;
import java.io.PrintStream;
import java.lang.Thread;
import java.lang.annotation.ElementType;
import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;
import java.lang.annotation.Target;
import java.lang.ref.ReferenceQueue;
import java.lang.ref.WeakReference;
import java.net.ServerSocket;
import java.net.Socket;
import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.Collections;
import java.util.Date;
import java.util.List;
import java.util.Locale;
import java.util.WeakHashMap;
/* loaded from: classes2.dex */
public class Logger extends FrameLayout implements Thread.UncaughtExceptionHandler, Application.ActivityLifecycleCallbacks {
    private static final int LOG_SOUT = 8;
    private static boolean debuggable = true;
    private static Thread.UncaughtExceptionHandler mDefaultHandler;
    private static Logger me;
    private static String tag;
    final ViewDragHelper dragHelper;
    private Handler handler;
    private boolean mAutoScroll;
    private final Context mContext;
    private Context mCurrentActivity;
    private final EditText mEdit;
    private AlertDialog mFilterDialog;
    private int mFilterLevel;
    private List<String> mFilterList;
    private String mFilterText;
    private LeakCheck mLeakCheck;
    private final ArrayAdapter<String> mLogAdapter;
    private final LinearLayout mLogContainer;
    private List<String> mLogList;
    private final ListView mLvLog;
    private View mSrcView;
    private final TextView mTvTitle;
    private OnSendClickListener sendClickListener;

    @Target({ElementType.TYPE})
    @Retention(RetentionPolicy.RUNTIME)
    /* loaded from: classes2.dex */
    public @interface IgnoreLoggerView {
    }

    /* loaded from: classes2.dex */
    public interface OnSendClickListener {
        void onClick(View view, byte[] bArr);
    }

    public static void setTag(String tag2) {
        tag = tag2;
    }

    private Logger(Context context, final OnSendClickListener sendClickListener) {
        super(context);
        this.mLogList = new ArrayList();
        this.mFilterList = new ArrayList();
        this.mAutoScroll = true;
        this.dragHelper = ViewDragHelper.create(this, new ViewDragHelper.Callback() { // from class: com.gyh.wifidata.view.Logger.5
            @Override // androidx.customview.widget.ViewDragHelper.Callback
            public boolean tryCaptureView(View child, int pointerId) {
                return child == Logger.this.mLogContainer;
            }

            @Override // androidx.customview.widget.ViewDragHelper.Callback
            public int clampViewPositionHorizontal(View child, int left, int dx) {
                return left;
            }

            @Override // androidx.customview.widget.ViewDragHelper.Callback
            public int clampViewPositionVertical(View child, int top, int dy) {
                return top;
            }

            @Override // androidx.customview.widget.ViewDragHelper.Callback
            public void onViewPositionChanged(View changedView, int left, int top, int dx, int dy) {
                Logger.this.resetParams(left, top);
            }

            @Override // androidx.customview.widget.ViewDragHelper.Callback
            public int getViewHorizontalDragRange(View child) {
                return Logger.this.getMeasuredWidth() - child.getMeasuredWidth();
            }

            @Override // androidx.customview.widget.ViewDragHelper.Callback
            public int getViewVerticalDragRange(View child) {
                return Logger.this.getMeasuredHeight() - child.getMeasuredHeight();
            }
        });
        this.handler = new Handler(Looper.getMainLooper()) { // from class: com.gyh.wifidata.view.Logger.6
            @Override // android.os.Handler
            public void handleMessage(Message msg) {
                String text = (String) msg.obj;
                Logger.this.addText(msg.what, text);
            }
        };
        this.mContext = context;
        this.sendClickListener = sendClickListener;
        tag = context.getApplicationInfo().packageName;
        final float v = TypedValue.applyDimension(2, 4.0f, getResources().getDisplayMetrics());
        LinearLayout linearLayout = new LinearLayout(context);
        this.mLogContainer = linearLayout;
        linearLayout.setOrientation(1);
        this.mLogContainer.setBackgroundColor(Color.argb(51, 0, 0, 0));
        int widthPixels = context.getResources().getDisplayMetrics().widthPixels;
        int heightPixels = context.getResources().getDisplayMetrics().heightPixels;
        FrameLayout.LayoutParams layoutParams = new FrameLayout.LayoutParams(widthPixels / 2, heightPixels / 3, 17);
        this.mLogContainer.setLayoutParams(layoutParams);
        this.mLogContainer.setVisibility(8);
        TextView textView = new TextView(context);
        this.mTvTitle = textView;
        textView.setTextSize(1.5f * v);
        this.mTvTitle.setText("Logcat(此处可拖动)");
        this.mTvTitle.setTextColor(-1);
        this.mTvTitle.setBackgroundColor(Color.argb(85, 0, 0, 0));
        this.mTvTitle.setOnClickListener($$Lambda$Logger$DRM8oWDiorYCDVimsfz_1Fhf9uQ.INSTANCE);
        this.mTvTitle.setOnLongClickListener($$Lambda$Logger$Xhd7oD0WFzdJxuTX0Jp1QqPEMt0.INSTANCE);
        this.mLogContainer.addView(this.mTvTitle);
        this.mLvLog = new ListView(context) { // from class: com.gyh.wifidata.view.Logger.1
            @Override // android.widget.AbsListView, android.view.View
            public boolean onTouchEvent(MotionEvent ev) {
                getParent().requestDisallowInterceptTouchEvent(true);
                return super.onTouchEvent(ev);
            }
        };
        int height = (int) (6.0f * v);
        FrameLayout.LayoutParams mLvLogParams = new FrameLayout.LayoutParams(widthPixels / 2, (heightPixels / 3) - (height * 2));
        this.mLvLog.setLayoutParams(mLvLogParams);
        this.mLvLog.setFastScrollEnabled(true);
        this.mLogContainer.addView(this.mLvLog);
        EditText editText = new EditText(context);
        this.mEdit = editText;
        editText.setInputType(1);
        this.mEdit.setImeOptions(4);
        this.mEdit.setTextSize(12.0f);
        this.mEdit.setBackground(null);
        this.mEdit.setPadding(0, 0, 0, 0);
        this.mEdit.setHeight(height);
        this.mEdit.setOnEditorActionListener(new TextView.OnEditorActionListener() { // from class: com.gyh.wifidata.view.-$$Lambda$Logger$mqQYJ2dliEN5QxpZVK_d2DrzMVM
            @Override // android.widget.TextView.OnEditorActionListener
            public final boolean onEditorAction(TextView textView2, int i, KeyEvent keyEvent) {
                return Logger.this.lambda$new$2$Logger(sendClickListener, textView2, i, keyEvent);
            }
        });
        this.mEdit.setBackgroundColor(Color.argb(85, 0, 0, 0));
        this.mEdit.setHint("十六进制，空格分开");
        this.mLogContainer.addView(this.mEdit);
        ArrayAdapter<String> arrayAdapter = new ArrayAdapter<String>(context, 17367043, this.mFilterList) { // from class: com.gyh.wifidata.view.Logger.2
            @Override // android.widget.ArrayAdapter, android.widget.Adapter
            public View getView(int position, View convertView, ViewGroup parent) {
                if (convertView == null) {
                    convertView = new TextView(parent.getContext());
                }
                TextView textView2 = (TextView) convertView;
                textView2.setTextSize(v);
                textView2.setText(Html.fromHtml((String) Logger.this.mFilterList.get(position)));
                textView2.setShadowLayer(1.0f, 1.0f, 1.0f, ViewCompat.MEASURED_STATE_MASK);
                return textView2;
            }
        };
        this.mLogAdapter = arrayAdapter;
        this.mLvLog.setAdapter((ListAdapter) arrayAdapter);
        this.mLvLog.setOnScrollListener(new AbsListView.OnScrollListener() { // from class: com.gyh.wifidata.view.Logger.3
            @Override // android.widget.AbsListView.OnScrollListener
            public void onScrollStateChanged(AbsListView view, int scrollState) {
            }

            @Override // android.widget.AbsListView.OnScrollListener
            public void onScroll(AbsListView view, int firstVisibleItem, int visibleItemCount, int totalItemCount) {
                Logger.this.mAutoScroll = firstVisibleItem + visibleItemCount == totalItemCount;
            }
        });
        this.mLvLog.setOnItemClickListener(new AdapterView.OnItemClickListener() { // from class: com.gyh.wifidata.view.-$$Lambda$Logger$mOdLAV_OP3ZbSIm6s8tIEQEeR7U
            @Override // android.widget.AdapterView.OnItemClickListener
            public final void onItemClick(AdapterView adapterView, View view, int i, long j) {
                Logger.this.lambda$new$4$Logger(adapterView, view, i, j);
            }
        });
        this.mLeakCheck = new LeakCheck();
        final Handler handler = new Handler(Looper.getMainLooper());
        handler.postDelayed(new Runnable() { // from class: com.gyh.wifidata.view.Logger.4
            @Override // java.lang.Runnable
            public void run() {
                handler.removeCallbacks(this);
                handler.postDelayed(this, 10000L);
                String s = null;
                try {
                    s = Logger.this.mLeakCheck.checkLeak();
                } catch (InterruptedException e) {
                    e.printStackTrace();
                }
                if (TextUtils.isEmpty(s)) {
                }
            }
        }, 10000L);
    }

    public /* synthetic */ boolean lambda$new$2$Logger(OnSendClickListener sendClickListener, TextView v13, int actionId, KeyEvent event) {
        if (actionId != 4) {
            return false;
        }
        if (sendClickListener != null) {
            sendClickListener.onClick(this, this.mEdit.getText().toString().getBytes());
        }
        return true;
    }

    public /* synthetic */ void lambda$new$4$Logger(AdapterView parent, View view, int position, long id) {
        AlertDialog.Builder builder = new AlertDialog.Builder(this.mCurrentActivity);
        String message = this.mFilterList.get(position);
        builder.setMessage(Html.fromHtml(message.replace("FFFFFF", "000000")));
        builder.setPositiveButton("确定", (DialogInterface.OnClickListener) null);
        builder.setNegativeButton("清空日志", new DialogInterface.OnClickListener() { // from class: com.gyh.wifidata.view.-$$Lambda$Logger$8JJaTgECiRtHuBWWYb-ZoL8_Imc
            @Override // android.content.DialogInterface.OnClickListener
            public final void onClick(DialogInterface dialogInterface, int i) {
                Logger.this.lambda$null$3$Logger(dialogInterface, i);
            }
        });
        builder.show();
    }

    public /* synthetic */ void lambda$null$3$Logger(DialogInterface dialog, int which) {
        this.mLogList.clear();
        refreshList();
    }

    public static LinearLayout getmLogContainer() {
        return me.mLogContainer;
    }

    public static void init(Application application, OnSendClickListener sendClickListener) {
        if (debuggable && me == null) {
            synchronized (Logger.class) {
                if (me == null) {
                    Logger logger = new Logger(application.getApplicationContext(), sendClickListener);
                    me = logger;
                    application.registerActivityLifecycleCallbacks(logger);
                    mDefaultHandler = Thread.getDefaultUncaughtExceptionHandler();
                    Looper.myQueue().addIdleHandler($$Lambda$Logger$koRq2y0zcKFGMdby3AH2WyG7tI.INSTANCE);
                }
            }
        }
    }

    public static void v(String msg) {
        v(tag, msg);
    }

    public static void d(String msg) {
        d(tag, msg);
    }

    public static void i(String msg) {
        i(tag, msg);
    }

    public static void w(String msg) {
        w(tag, msg);
    }

    public static void e(String msg) {
        e(tag, msg);
    }

    public static void s(String msg) {
        s(tag, msg);
    }

    public static void v(String tag2, String msg) {
        Logger logger = me;
        if (logger != null) {
            logger.print(2, tag2, msg);
        }
    }

    public static void d(String tag2, String msg) {
        Logger logger = me;
        if (logger != null) {
            logger.print(3, tag2, msg);
        }
    }

    public static void i(String tag2, String msg) {
        Logger logger = me;
        if (logger != null) {
            logger.print(4, tag2, msg);
        }
    }

    public static void w(String tag2, String msg) {
        Logger logger = me;
        if (logger != null) {
            logger.print(5, tag2, msg);
        }
    }

    public static void e(String tag2, String msg) {
        Logger logger = me;
        if (logger != null) {
            logger.print(6, tag2, msg);
        }
    }

    public static void s(String tag2, String msg) {
        Logger logger = me;
        if (logger != null) {
            logger.print(8, tag2, msg);
        }
    }

    private void print(int type, String tag2, String msg) {
        if (!debuggable || me == null || type < this.mFilterLevel + 2) {
            return;
        }
        String str = "[" + getTime() + "] " + msg;
        if (TextUtils.isEmpty(this.mFilterText) || str.contains(this.mFilterText)) {
            this.handler.obtainMessage(type, str).sendToTarget();
            int start = 0;
            int end = 0;
            while (end < msg.length()) {
                end = start + PathInterpolatorCompat.MAX_NUM_POINTS > msg.length() ? msg.length() : start + PathInterpolatorCompat.MAX_NUM_POINTS;
                String subMsg = msg.substring(start, end);
                start = end;
                if (type == 2) {
                    Log.v(tag2, subMsg);
                } else if (type == 3) {
                    Log.d(tag2, subMsg);
                } else if (type == 4) {
                    Log.i(tag2, subMsg);
                } else if (type == 5) {
                    Log.w(tag2, subMsg);
                } else if (type == 6) {
                    Log.e(tag2, subMsg);
                } else if (type == 8) {
                    System.out.println(tag2 + ":" + subMsg);
                }
            }
        }
    }

    private String getLevel(int type) {
        String[] level = {"S", "", "V", "D", "I", "W", "E"};
        return level[type];
    }

    private String getTime() {
        return new SimpleDateFormat("MM-dd HH:mm:ss.SSS", Locale.getDefault()).format(new Date());
    }

    /* JADX INFO: Access modifiers changed from: private */
    public void addText(int type, String text) {
        String[] level = {"#FFFFFF", "", "#FFFFFF", "#2FB1FE", "#00ff00", "#EFC429", "#FF0000", "", ""};
        String str = String.format("<font color=\"" + level[type] + "\">%s</font>", text);
        this.mLogList.add(str);
        while (this.mLogList.size() > 100) {
            this.mLogList.remove(0);
        }
        refreshList();
    }

    private void refreshList() {
        String str;
        this.mFilterList.clear();
        for (int i = 0; i < this.mLogList.size(); i++) {
            String s = this.mLogList.get(i);
            int l = 2;
            int j = 2;
            while (true) {
                if (j >= 7) {
                    break;
                }
                String level1 = getLevel(j);
                if (!s.contains("]" + level1 + "/")) {
                    j++;
                } else {
                    l = j;
                    break;
                }
            }
            int j2 = this.mFilterLevel;
            if (l >= j2 + 2 && ((str = this.mFilterText) == null || s.contains(str))) {
                this.mFilterList.add(s);
            }
        }
        this.mLogAdapter.notifyDataSetChanged();
        if (this.mAutoScroll) {
            this.mLvLog.smoothScrollToPosition(this.mLogList.size());
        }
    }

    @Override // android.app.Application.ActivityLifecycleCallbacks
    public void onActivityCreated(Activity activity, Bundle savedInstanceState) {
        this.mLeakCheck.add(activity);
    }

    @Override // android.app.Application.ActivityLifecycleCallbacks
    public void onActivityStarted(Activity activity) {
    }

    @Override // android.app.Application.ActivityLifecycleCallbacks
    public void onActivityResumed(Activity activity) {
        this.mCurrentActivity = activity;
        if (!debuggable || checkIgnore(activity)) {
            return;
        }
        ViewGroup decorView = (ViewGroup) activity.getWindow().getDecorView();
        View childAt = decorView.getChildAt(0);
        this.mSrcView = childAt;
        decorView.removeView(childAt);
        me.addView(this.mSrcView, 0);
        me.addView(this.mLogContainer, 1);
        decorView.addView(me);
    }

    @Override // android.app.Application.ActivityLifecycleCallbacks
    public void onActivityPaused(Activity activity) {
        this.mCurrentActivity = null;
        if (checkIgnore(activity)) {
            return;
        }
        ViewGroup decorView = (ViewGroup) activity.getWindow().getDecorView();
        me.removeView(this.mSrcView);
        me.removeView(this.mLogContainer);
        decorView.removeView(me);
        View view = this.mSrcView;
        if (view != null) {
            decorView.addView(view, 0);
        }
    }

    private boolean checkIgnore(Activity activity) {
        return activity.getClass().isAnnotationPresent(IgnoreLoggerView.class);
    }

    @Override // android.app.Application.ActivityLifecycleCallbacks
    public void onActivityStopped(Activity activity) {
    }

    @Override // android.app.Application.ActivityLifecycleCallbacks
    public void onActivitySaveInstanceState(Activity activity, Bundle outState) {
    }

    @Override // android.app.Application.ActivityLifecycleCallbacks
    public void onActivityDestroyed(Activity activity) {
        this.mLeakCheck.remove(activity);
    }

    /* JADX INFO: Access modifiers changed from: private */
    public void resetParams(int x, int y) {
        ViewGroup.MarginLayoutParams margin = new ViewGroup.MarginLayoutParams(this.mLogContainer.getLayoutParams());
        margin.setMargins(x, y, margin.width + x, margin.height + y);
        FrameLayout.LayoutParams layoutParams = new FrameLayout.LayoutParams(margin);
        this.mLogContainer.setLayoutParams(layoutParams);
    }

    @Override // android.view.ViewGroup
    public boolean onInterceptTouchEvent(MotionEvent ev) {
        return this.dragHelper.shouldInterceptTouchEvent(ev);
    }

    @Override // android.view.View
    public boolean onTouchEvent(MotionEvent event) {
        this.dragHelper.processTouchEvent(event);
        return true;
    }

    public static void loggerSwitch() {
        if (me.mLogContainer.getVisibility() == 8) {
            me.mLogContainer.setVisibility(0);
        } else {
            me.mLogContainer.setVisibility(8);
        }
    }

    public static void showFilterDialog() {
        Context context = me.mCurrentActivity;
        if (context == null) {
            return;
        }
        AlertDialog.Builder builder = new AlertDialog.Builder(context);
        builder.setTitle("日志过滤器");
        builder.setView(me.initDialogView());
        builder.setCancelable(false);
        AlertDialog alertDialog = me.mFilterDialog;
        if (alertDialog != null) {
            alertDialog.dismiss();
        }
        me.mFilterDialog = builder.show();
    }

    private View initDialogView() {
        LinearLayout linearLayout = new LinearLayout(this.mCurrentActivity);
        linearLayout.setOrientation(1);
        linearLayout.setGravity(1);
        Spinner spinner = new Spinner(this.mCurrentActivity, 1);
        spinner.setAdapter((SpinnerAdapter) new ArrayAdapter(this.mCurrentActivity, 17367049, new String[]{"Verbose", "Debug", "Info", "Warn", "Error"}));
        spinner.setSelection(this.mFilterLevel);
        spinner.setOnItemSelectedListener(new AdapterView.OnItemSelectedListener() { // from class: com.gyh.wifidata.view.Logger.7
            @Override // android.widget.AdapterView.OnItemSelectedListener
            public void onItemSelected(AdapterView<?> parent, View view, int position, long id) {
                Logger.this.mFilterLevel = position;
            }

            @Override // android.widget.AdapterView.OnItemSelectedListener
            public void onNothingSelected(AdapterView<?> parent) {
            }
        });
        final EditText editText = new EditText(this.mCurrentActivity);
        editText.setHint("筛选关键字");
        String str = this.mFilterText;
        if (str != null) {
            editText.setText(str);
            editText.setSelection(this.mFilterText.length());
        }
        Button button = new Button(this.mCurrentActivity);
        button.setText("确定");
        button.setOnClickListener(new View.OnClickListener() { // from class: com.gyh.wifidata.view.-$$Lambda$Logger$ecRxHbuZFhzmOmdUMOB3-5OAoRI
            @Override // android.view.View.OnClickListener
            public final void onClick(View view) {
                Logger.this.lambda$initDialogView$6$Logger(editText, view);
            }
        });
        linearLayout.addView(spinner);
        linearLayout.addView(editText);
        linearLayout.addView(button);
        return linearLayout;
    }

    public /* synthetic */ void lambda$initDialogView$6$Logger(EditText editText, View v) {
        this.mFilterText = editText.getText().toString();
        this.mFilterDialog.dismiss();
        refreshList();
    }

    @Override // java.lang.Thread.UncaughtExceptionHandler
    public void uncaughtException(Thread t, Throwable e) {
        Thread.UncaughtExceptionHandler uncaughtExceptionHandler;
        e.printStackTrace();
        if (!handleException(t, e) && (uncaughtExceptionHandler = mDefaultHandler) != null) {
            uncaughtExceptionHandler.uncaughtException(t, e);
        }
    }

    private boolean handleException(final Thread t, final Throwable e) {
        if (e == null) {
            return false;
        }
        if (this.mCurrentActivity == null) {
            Uri content_url = Uri.parse("http://127.0.0.1:45678");
            Intent intent = new Intent();
            intent.setFlags(16384);
            intent.setAction("android.intent.action.VIEW");
            intent.setData(content_url);
            this.mContext.startActivity(intent);
        }
        ThreadManager.INSTANCE.execute(new Runnable() { // from class: com.gyh.wifidata.view.-$$Lambda$Logger$_dX2DSTnqGvk4uSkpXki5oGm4zA
            @Override // java.lang.Runnable
            public final void run() {
                Logger.this.lambda$handleException$8$Logger(e, t);
            }
        });
        return true;
    }

    public /* synthetic */ void lambda$handleException$8$Logger(final Throwable e, final Thread t) {
        ByteArrayOutputStream baos = new ByteArrayOutputStream();
        PrintStream printStream = new PrintStream(baos);
        e.printStackTrace(printStream);
        String s = baos.toString();
        String[] split = s.split("\t");
        StringBuilder sb = new StringBuilder();
        for (int i = 0; i < split.length; i++) {
            String s1 = split[i];
            if (!s1.contains("android.") && !s1.contains("java.") && s1.contains("at") && i > 0) {
                s1 = String.format("<br> <font color='#ff0000'>%s</font>", s1);
            }
            sb.append(s1);
            sb.append("\t ");
        }
        if (this.mCurrentActivity == null) {
            showInWeb(sb.toString(), t, e);
            return;
        }
        Spanned spanned = Html.fromHtml(sb.toString());
        Looper.prepare();
        Toast.makeText(this.mCurrentActivity, "APP 崩溃", 1).show();
        AlertDialog.Builder builder = new AlertDialog.Builder(this.mCurrentActivity);
        builder.setTitle("App Crash,Log:");
        builder.setMessage(spanned);
        builder.setPositiveButton("关闭app", new DialogInterface.OnClickListener() { // from class: com.gyh.wifidata.view.-$$Lambda$Logger$qnGSyV88JGzCeIMaaMT8SPoXEKk
            @Override // android.content.DialogInterface.OnClickListener
            public final void onClick(DialogInterface dialogInterface, int i2) {
                Logger.mDefaultHandler.uncaughtException(t, e);
            }
        });
        builder.setCancelable(false);
        builder.show();
        Looper.loop();
    }

    private void showInWeb(CharSequence msg, Thread t, Throwable ex) {
        try {
            ServerSocket serverSocket = new ServerSocket(45678);
            String sb = "HTTP/1.1 200 OK\n\n<head><meta name='viewport' content='width=240, target-densityDpi=device-dpi'></head><html><h1>APP Crash</h1>" + ((Object) msg) + "<br/></html>";
            byte[] bytes = sb.getBytes();
            while (true) {
                Socket accept = serverSocket.accept();
                OutputStream os = accept.getOutputStream();
                os.write(bytes);
                os.flush();
                os.close();
                accept.close();
                mDefaultHandler.uncaughtException(t, ex);
            }
        } catch (IOException e) {
            e.printStackTrace();
        }
    }

    /* loaded from: classes2.dex */
    private class LeakCheck {
        List<Integer> mList;
        WeakHashMap<Activity, Integer> mMap;
        WeakReference mPhantomReference;
        ReferenceQueue mQueue;

        private LeakCheck() {
            this.mList = Collections.synchronizedList(new ArrayList());
            this.mMap = new WeakHashMap<>();
            this.mQueue = new ReferenceQueue();
            this.mPhantomReference = new WeakReference(new Object(), this.mQueue);
        }

        void add(Activity activity) {
            int code = activity.hashCode();
            this.mList.add(Integer.valueOf(code));
            this.mMap.put(activity, Integer.valueOf(code));
        }

        void remove(Activity activity) {
            this.mList.remove(Integer.valueOf(activity.hashCode()));
        }

        String checkLeak() throws InterruptedException {
            if (this.mPhantomReference.isEnqueued()) {
                Log.e("Logger", "检测到GC");
                Log.e("Logger", "理论存活activity数：" + this.mList.size());
                StringBuilder stringBuilder = new StringBuilder();
                for (Activity activity : this.mMap.keySet()) {
                    int s = activity.hashCode();
                    String name = activity.getClass().getName();
                    if (!this.mList.contains(Integer.valueOf(s))) {
                        stringBuilder.append(name);
                        stringBuilder.append(MessageDecoder.PARTITION);
                        Log.e("Logger", name + " 可能发生内存泄漏,请检查");
                    }
                }
                this.mQueue.remove();
                this.mPhantomReference = new WeakReference(new Object(), this.mQueue);
                return stringBuilder.toString();
            }
            return null;
        }
    }
}
