package io.netty.buffer;
/* JADX INFO: Access modifiers changed from: package-private */
/* loaded from: classes.dex */
public final class PoolSubpage<T> implements PoolSubpageMetric {
    static final /* synthetic */ boolean $assertionsDisabled = false;
    private final long[] bitmap;
    private int bitmapLength;
    final PoolChunk<T> chunk;
    boolean doNotDestroy;
    int elemSize;
    private int maxNumElems;
    private final int memoryMapIdx;
    PoolSubpage<T> next;
    private int nextAvail;
    private int numAvail;
    private final int pageSize;
    PoolSubpage<T> prev;
    private final int runOffset;

    /* JADX INFO: Access modifiers changed from: package-private */
    public PoolSubpage(int pageSize) {
        this.chunk = null;
        this.memoryMapIdx = -1;
        this.runOffset = -1;
        this.elemSize = -1;
        this.pageSize = pageSize;
        this.bitmap = null;
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    public PoolSubpage(PoolSubpage<T> head, PoolChunk<T> chunk, int memoryMapIdx, int runOffset, int pageSize, int elemSize) {
        this.chunk = chunk;
        this.memoryMapIdx = memoryMapIdx;
        this.runOffset = runOffset;
        this.pageSize = pageSize;
        this.bitmap = new long[pageSize >>> 10];
        init(head, elemSize);
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    public void init(PoolSubpage<T> head, int elemSize) {
        this.doNotDestroy = true;
        this.elemSize = elemSize;
        if (elemSize != 0) {
            int i = this.pageSize / elemSize;
            this.numAvail = i;
            this.maxNumElems = i;
            this.nextAvail = 0;
            int i2 = i >>> 6;
            this.bitmapLength = i2;
            if ((i & 63) != 0) {
                this.bitmapLength = i2 + 1;
            }
            for (int i3 = 0; i3 < this.bitmapLength; i3++) {
                this.bitmap[i3] = 0;
            }
        }
        addToPool(head);
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    public long allocate() {
        if (this.elemSize == 0) {
            return toHandle(0);
        }
        if (this.numAvail == 0 || !this.doNotDestroy) {
            return -1L;
        }
        int bitmapIdx = getNextAvail();
        int q = bitmapIdx >>> 6;
        int r = bitmapIdx & 63;
        long[] jArr = this.bitmap;
        jArr[q] = jArr[q] | (1 << r);
        int i = this.numAvail - 1;
        this.numAvail = i;
        if (i == 0) {
            removeFromPool();
        }
        return toHandle(bitmapIdx);
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    public boolean free(PoolSubpage<T> head, int bitmapIdx) {
        if (this.elemSize == 0) {
            return true;
        }
        int q = bitmapIdx >>> 6;
        int r = bitmapIdx & 63;
        long[] jArr = this.bitmap;
        jArr[q] = jArr[q] ^ (1 << r);
        setNextAvail(bitmapIdx);
        int i = this.numAvail;
        int i2 = i + 1;
        this.numAvail = i2;
        if (i == 0) {
            addToPool(head);
            return true;
        } else if (i2 == this.maxNumElems && this.prev != this.next) {
            this.doNotDestroy = false;
            removeFromPool();
            return false;
        } else {
            return true;
        }
    }

    private void addToPool(PoolSubpage<T> head) {
        this.prev = head;
        PoolSubpage<T> poolSubpage = head.next;
        this.next = poolSubpage;
        poolSubpage.prev = this;
        head.next = this;
    }

    private void removeFromPool() {
        PoolSubpage<T> poolSubpage = this.prev;
        poolSubpage.next = this.next;
        this.next.prev = poolSubpage;
        this.next = null;
        this.prev = null;
    }

    private void setNextAvail(int bitmapIdx) {
        this.nextAvail = bitmapIdx;
    }

    private int getNextAvail() {
        int nextAvail = this.nextAvail;
        if (nextAvail >= 0) {
            this.nextAvail = -1;
            return nextAvail;
        }
        return findNextAvail();
    }

    private int findNextAvail() {
        long[] bitmap = this.bitmap;
        int bitmapLength = this.bitmapLength;
        for (int i = 0; i < bitmapLength; i++) {
            long bits = bitmap[i];
            if ((~bits) != 0) {
                return findNextAvail0(i, bits);
            }
        }
        return -1;
    }

    private int findNextAvail0(int i, long bits) {
        int maxNumElems = this.maxNumElems;
        int baseVal = i << 6;
        for (int j = 0; j < 64; j++) {
            if ((1 & bits) == 0) {
                int val = baseVal | j;
                if (val < maxNumElems) {
                    return val;
                }
                return -1;
            }
            bits >>>= 1;
        }
        return -1;
    }

    private long toHandle(int bitmapIdx) {
        return (bitmapIdx << 32) | 4611686018427387904L | this.memoryMapIdx;
    }

    public String toString() {
        boolean doNotDestroy;
        int maxNumElems;
        int elemSize;
        int numAvail;
        boolean doNotDestroy2;
        int maxNumElems2;
        int maxNumElems3;
        int numAvail2;
        PoolChunk<T> poolChunk = this.chunk;
        if (poolChunk == null) {
            doNotDestroy2 = true;
            maxNumElems2 = 0;
            maxNumElems3 = 0;
            numAvail2 = -1;
        } else {
            synchronized (poolChunk.arena) {
                if (!this.doNotDestroy) {
                    doNotDestroy = false;
                    maxNumElems = -1;
                    numAvail = -1;
                    elemSize = -1;
                } else {
                    doNotDestroy = true;
                    maxNumElems = this.maxNumElems;
                    elemSize = this.numAvail;
                    numAvail = this.elemSize;
                }
            }
            doNotDestroy2 = doNotDestroy;
            maxNumElems2 = maxNumElems;
            maxNumElems3 = elemSize;
            numAvail2 = numAvail;
        }
        if (!doNotDestroy2) {
            return "(" + this.memoryMapIdx + ": not in use)";
        }
        return "(" + this.memoryMapIdx + ": " + (maxNumElems2 - maxNumElems3) + '/' + maxNumElems2 + ", offset: " + this.runOffset + ", length: " + this.pageSize + ", elemSize: " + numAvail2 + ')';
    }

    @Override // io.netty.buffer.PoolSubpageMetric
    public int maxNumElements() {
        int i;
        PoolChunk<T> poolChunk = this.chunk;
        if (poolChunk == null) {
            return 0;
        }
        synchronized (poolChunk.arena) {
            i = this.maxNumElems;
        }
        return i;
    }

    @Override // io.netty.buffer.PoolSubpageMetric
    public int numAvailable() {
        int i;
        PoolChunk<T> poolChunk = this.chunk;
        if (poolChunk == null) {
            return 0;
        }
        synchronized (poolChunk.arena) {
            i = this.numAvail;
        }
        return i;
    }

    @Override // io.netty.buffer.PoolSubpageMetric
    public int elementSize() {
        int i;
        PoolChunk<T> poolChunk = this.chunk;
        if (poolChunk == null) {
            return -1;
        }
        synchronized (poolChunk.arena) {
            i = this.elemSize;
        }
        return i;
    }

    @Override // io.netty.buffer.PoolSubpageMetric
    public int pageSize() {
        return this.pageSize;
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    public void destroy() {
        PoolChunk<T> poolChunk = this.chunk;
        if (poolChunk != null) {
            poolChunk.destroy();
        }
    }
}
