package io.netty.channel.unix;

import io.netty.buffer.ByteBuf;
import io.netty.channel.ChannelOutboundBuffer;
import io.netty.util.internal.ObjectUtil;
import io.netty.util.internal.PlatformDependent;
import java.nio.ByteBuffer;
/* loaded from: classes.dex */
public final class IovArray implements ChannelOutboundBuffer.MessageProcessor {
    static final /* synthetic */ boolean $assertionsDisabled = false;
    private static final int ADDRESS_SIZE;
    private static final int CAPACITY;
    private static final int IOV_SIZE;
    private int count;
    private long maxBytes = Limits.SSIZE_MAX;
    private final ByteBuffer memory;
    private final long memoryAddress;
    private long size;

    static {
        int addressSize = Buffer.addressSize();
        ADDRESS_SIZE = addressSize;
        IOV_SIZE = addressSize * 2;
        CAPACITY = Limits.IOV_MAX * IOV_SIZE;
    }

    public IovArray() {
        ByteBuffer allocateDirectWithNativeOrder = Buffer.allocateDirectWithNativeOrder(CAPACITY);
        this.memory = allocateDirectWithNativeOrder;
        this.memoryAddress = Buffer.memoryAddress(allocateDirectWithNativeOrder);
    }

    public void clear() {
        this.count = 0;
        this.size = 0L;
    }

    @Deprecated
    public boolean add(ByteBuf buf) {
        return add(buf, buf.readerIndex(), buf.readableBytes());
    }

    public boolean add(ByteBuf buf, int offset, int len) {
        ByteBuffer nioBuffer;
        if (this.count == Limits.IOV_MAX) {
            return false;
        }
        if (buf.nioBufferCount() == 1) {
            if (len == 0) {
                return true;
            }
            if (buf.hasMemoryAddress()) {
                return add(buf.memoryAddress() + offset, len);
            }
            return add(Buffer.memoryAddress(buf.internalNioBuffer(offset, len)) + nioBuffer.position(), len);
        }
        ByteBuffer[] buffers = buf.nioBuffers(offset, len);
        for (ByteBuffer nioBuffer2 : buffers) {
            int remaining = nioBuffer2.remaining();
            if (remaining != 0 && (!add(Buffer.memoryAddress(nioBuffer2) + nioBuffer2.position(), remaining) || this.count == Limits.IOV_MAX)) {
                return false;
            }
        }
        return true;
    }

    private boolean add(long addr, int len) {
        if (this.maxBytes - len < this.size && this.count > 0) {
            return false;
        }
        int baseOffset = idx(this.count);
        int i = ADDRESS_SIZE;
        int lengthOffset = baseOffset + i;
        this.size += len;
        this.count++;
        if (i == 8) {
            if (PlatformDependent.hasUnsafe()) {
                PlatformDependent.putLong(baseOffset + this.memoryAddress, addr);
                PlatformDependent.putLong(lengthOffset + this.memoryAddress, len);
            } else {
                this.memory.putLong(baseOffset, addr);
                this.memory.putLong(lengthOffset, len);
            }
        } else if (PlatformDependent.hasUnsafe()) {
            PlatformDependent.putInt(baseOffset + this.memoryAddress, (int) addr);
            PlatformDependent.putInt(lengthOffset + this.memoryAddress, len);
        } else {
            this.memory.putInt(baseOffset, (int) addr);
            this.memory.putInt(lengthOffset, len);
        }
        return true;
    }

    public int count() {
        return this.count;
    }

    public long size() {
        return this.size;
    }

    public void maxBytes(long maxBytes) {
        this.maxBytes = Math.min(Limits.SSIZE_MAX, ObjectUtil.checkPositive(maxBytes, "maxBytes"));
    }

    public long maxBytes() {
        return this.maxBytes;
    }

    public long memoryAddress(int offset) {
        return this.memoryAddress + idx(offset);
    }

    public void release() {
        Buffer.free(this.memory);
    }

    @Override // io.netty.channel.ChannelOutboundBuffer.MessageProcessor
    public boolean processMessage(Object msg) throws Exception {
        if (msg instanceof ByteBuf) {
            ByteBuf buffer = (ByteBuf) msg;
            return add(buffer, buffer.readerIndex(), buffer.readableBytes());
        }
        return false;
    }

    private static int idx(int index) {
        return IOV_SIZE * index;
    }
}
