package io.netty.handler.codec.compression;

import io.netty.buffer.ByteBuf;
import io.netty.channel.ChannelHandlerContext;
import io.netty.handler.codec.ByteToMessageDecoder;
import java.util.List;
/* loaded from: classes.dex */
public class Bzip2Decoder extends ByteToMessageDecoder {
    private int blockCRC;
    private Bzip2BlockDecompressor blockDecompressor;
    private int blockSize;
    private Bzip2HuffmanStageDecoder huffmanStageDecoder;
    private int streamCRC;
    private State currentState = State.INIT;
    private final Bzip2BitReader reader = new Bzip2BitReader();

    /* loaded from: classes.dex */
    private enum State {
        INIT,
        INIT_BLOCK,
        INIT_BLOCK_PARAMS,
        RECEIVE_HUFFMAN_USED_MAP,
        RECEIVE_HUFFMAN_USED_BITMAPS,
        RECEIVE_SELECTORS_NUMBER,
        RECEIVE_SELECTORS,
        RECEIVE_HUFFMAN_LENGTH,
        DECODE_HUFFMAN_DATA,
        EOF
    }

    /* JADX WARN: Code restructure failed: missing block: B:105:0x01b5, code lost:
        r4[r12][r7] = (byte) r6;
        r7 = r7 + 1;
     */
    /* JADX WARN: Code restructure failed: missing block: B:148:0x025d, code lost:
        throw new io.netty.handler.codec.compression.DecompressionException("incorrect selectors number");
     */
    /* JADX WARN: Code restructure failed: missing block: B:152:0x0271, code lost:
        throw new io.netty.handler.codec.compression.DecompressionException("incorrect huffman groups number");
     */
    /* JADX WARN: Code restructure failed: missing block: B:154:0x027b, code lost:
        throw new io.netty.handler.codec.compression.DecompressionException("bad block header");
     */
    /* JADX WARN: Code restructure failed: missing block: B:156:0x0285, code lost:
        throw new io.netty.handler.codec.compression.DecompressionException("block size is invalid");
     */
    /* JADX WARN: Removed duplicated region for block: B:120:0x01ec  */
    /* JADX WARN: Removed duplicated region for block: B:124:0x0202  */
    /* JADX WARN: Removed duplicated region for block: B:183:0x013f A[SYNTHETIC] */
    /* JADX WARN: Removed duplicated region for block: B:190:0x00aa A[SYNTHETIC] */
    /* JADX WARN: Removed duplicated region for block: B:191:0x00cc A[SYNTHETIC] */
    /* JADX WARN: Removed duplicated region for block: B:192:0x01e3 A[SYNTHETIC] */
    /* JADX WARN: Removed duplicated region for block: B:193:0x00ed A[SYNTHETIC] */
    /* JADX WARN: Removed duplicated region for block: B:194:0x0201 A[SYNTHETIC] */
    /* JADX WARN: Removed duplicated region for block: B:207:0x01e1 A[SYNTHETIC] */
    /* JADX WARN: Removed duplicated region for block: B:42:0x00ab  */
    /* JADX WARN: Removed duplicated region for block: B:46:0x00cd  */
    /* JADX WARN: Removed duplicated region for block: B:50:0x00ee  */
    /* JADX WARN: Removed duplicated region for block: B:72:0x0140  */
    /* JADX WARN: Removed duplicated region for block: B:79:0x015f  */
    /* JADX WARN: Removed duplicated region for block: B:91:0x0191  */
    @Override // io.netty.handler.codec.ByteToMessageDecoder
    /*
        Code decompiled incorrectly, please refer to instructions dump.
    */
    protected void decode(ChannelHandlerContext ctx, ByteBuf in, List<Object> out) throws Exception {
        boolean decoded;
        Bzip2HuffmanStageDecoder huffmanStageDecoder;
        int totalTables;
        int currLength;
        int currAlpha;
        boolean modifyLength;
        boolean saveStateAndReturn;
        int currGroup;
        int totalSelectors;
        int currSelector;
        int bitNumber;
        boolean blockRandomised;
        if (!in.isReadable()) {
            return;
        }
        Bzip2BitReader reader = this.reader;
        reader.setByteBuf(in);
        while (true) {
            int i = 16;
            switch (AnonymousClass1.$SwitchMap$io$netty$handler$codec$compression$Bzip2Decoder$State[this.currentState.ordinal()]) {
                case 1:
                    if (in.readableBytes() < 4) {
                        return;
                    }
                    int magicNumber = in.readUnsignedMedium();
                    if (magicNumber != 4348520) {
                        throw new DecompressionException("Unexpected stream identifier contents. Mismatched bzip2 protocol version?");
                    }
                    int blockSize = in.readByte() - 48;
                    if (blockSize >= 1 && blockSize <= 9) {
                        this.blockSize = 100000 * blockSize;
                        this.streamCRC = 0;
                        this.currentState = State.INIT_BLOCK;
                    }
                    break;
                case 2:
                    if (!reader.hasReadableBytes(10)) {
                        return;
                    }
                    int magic1 = reader.readBits(24);
                    int magic2 = reader.readBits(24);
                    if (magic1 == 1536581 && magic2 == 3690640) {
                        int storedCombinedCRC = reader.readInt();
                        if (storedCombinedCRC == this.streamCRC) {
                            this.currentState = State.EOF;
                            break;
                        } else {
                            throw new DecompressionException("stream CRC error");
                        }
                    } else if (magic1 == 3227993 && magic2 == 2511705) {
                        this.blockCRC = reader.readInt();
                        this.currentState = State.INIT_BLOCK_PARAMS;
                        if (reader.hasReadableBits(25)) {
                            return;
                        }
                        boolean blockRandomised2 = reader.readBoolean();
                        int bwtStartPointer = reader.readBits(24);
                        this.blockDecompressor = new Bzip2BlockDecompressor(this.blockSize, this.blockCRC, blockRandomised2, bwtStartPointer, reader);
                        this.currentState = State.RECEIVE_HUFFMAN_USED_MAP;
                        blockRandomised = reader.hasReadableBits(16);
                        if (blockRandomised) {
                            return;
                        }
                        this.blockDecompressor.huffmanInUse16 = reader.readBits(16);
                        this.currentState = State.RECEIVE_HUFFMAN_USED_BITMAPS;
                        Bzip2BlockDecompressor blockDecompressor = this.blockDecompressor;
                        int inUse16 = blockDecompressor.huffmanInUse16;
                        bitNumber = Integer.bitCount(inUse16);
                        byte[] huffmanSymbolMap = blockDecompressor.huffmanSymbolMap;
                        if (reader.hasReadableBits((bitNumber * 16) + 3)) {
                            return;
                        }
                        int huffmanSymbolCount = 0;
                        if (bitNumber > 0) {
                            int i2 = 0;
                            while (i2 < i) {
                                if (((32768 >>> i2) & inUse16) != 0) {
                                    int j = 0;
                                    int k = i2 << 4;
                                    while (j < i) {
                                        if (reader.readBoolean()) {
                                            huffmanSymbolMap[huffmanSymbolCount] = (byte) k;
                                            huffmanSymbolCount++;
                                        }
                                        j++;
                                        k++;
                                        i = 16;
                                    }
                                }
                                i2++;
                                i = 16;
                            }
                        }
                        int i3 = huffmanSymbolCount + 1;
                        blockDecompressor.huffmanEndOfBlockSymbol = i3;
                        int totalTables2 = reader.readBits(3);
                        if (totalTables2 >= 2 && totalTables2 <= 6) {
                            int alphaSize = huffmanSymbolCount + 2;
                            if (alphaSize > 258) {
                                throw new DecompressionException("incorrect alphabet size");
                            }
                            this.huffmanStageDecoder = new Bzip2HuffmanStageDecoder(reader, totalTables2, alphaSize);
                            this.currentState = State.RECEIVE_SELECTORS_NUMBER;
                            if (reader.hasReadableBits(15)) {
                                return;
                            }
                            int totalSelectors2 = reader.readBits(15);
                            if (totalSelectors2 >= 1 && totalSelectors2 <= 18002) {
                                this.huffmanStageDecoder.selectors = new byte[totalSelectors2];
                                this.currentState = State.RECEIVE_SELECTORS;
                                Bzip2HuffmanStageDecoder huffmanStageDecoder2 = this.huffmanStageDecoder;
                                byte[] selectors = huffmanStageDecoder2.selectors;
                                totalSelectors = selectors.length;
                                Bzip2MoveToFrontTable tableMtf = huffmanStageDecoder2.tableMTF;
                                for (currSelector = huffmanStageDecoder2.currentSelector; currSelector < totalSelectors; currSelector++) {
                                    if (!reader.hasReadableBits(6)) {
                                        huffmanStageDecoder2.currentSelector = currSelector;
                                        return;
                                    }
                                    int index = 0;
                                    while (reader.readBoolean()) {
                                        index++;
                                    }
                                    selectors[currSelector] = tableMtf.indexToFront(index);
                                }
                                this.currentState = State.RECEIVE_HUFFMAN_LENGTH;
                                huffmanStageDecoder = this.huffmanStageDecoder;
                                totalTables = huffmanStageDecoder.totalTables;
                                byte[][] codeLength = huffmanStageDecoder.tableCodeLengths;
                                int alphaSize2 = huffmanStageDecoder.alphabetSize;
                                currLength = huffmanStageDecoder.currentLength;
                                currAlpha = 0;
                                modifyLength = huffmanStageDecoder.modifyLength;
                                saveStateAndReturn = false;
                                currGroup = huffmanStageDecoder.currentGroup;
                                while (true) {
                                    if (currGroup < totalTables) {
                                        if (!reader.hasReadableBits(5)) {
                                            saveStateAndReturn = true;
                                        } else {
                                            if (currLength < 0) {
                                                currLength = reader.readBits(5);
                                            }
                                            currAlpha = huffmanStageDecoder.currentAlpha;
                                            while (currAlpha < alphaSize2) {
                                                if (reader.isReadable()) {
                                                    while (true) {
                                                        if (modifyLength || reader.readBoolean()) {
                                                            if (!reader.isReadable()) {
                                                                modifyLength = true;
                                                                saveStateAndReturn = true;
                                                            } else {
                                                                currLength += reader.readBoolean() ? -1 : 1;
                                                                modifyLength = false;
                                                                if (!reader.isReadable()) {
                                                                    saveStateAndReturn = true;
                                                                }
                                                            }
                                                        }
                                                    }
                                                } else {
                                                    saveStateAndReturn = true;
                                                }
                                            }
                                            currLength = -1;
                                            huffmanStageDecoder.currentAlpha = 0;
                                            currAlpha = 0;
                                            modifyLength = false;
                                            currGroup++;
                                        }
                                    }
                                }
                                if (saveStateAndReturn) {
                                    huffmanStageDecoder.currentGroup = currGroup;
                                    huffmanStageDecoder.currentLength = currLength;
                                    huffmanStageDecoder.currentAlpha = currAlpha;
                                    huffmanStageDecoder.modifyLength = modifyLength;
                                    return;
                                }
                                huffmanStageDecoder.createHuffmanDecodingTables();
                                this.currentState = State.DECODE_HUFFMAN_DATA;
                                Bzip2BlockDecompressor blockDecompressor2 = this.blockDecompressor;
                                int oldReaderIndex = in.readerIndex();
                                decoded = blockDecompressor2.decodeHuffmanData(this.huffmanStageDecoder);
                                if (decoded) {
                                    return;
                                }
                                if (in.readerIndex() == oldReaderIndex && in.isReadable()) {
                                    reader.refill();
                                }
                                int blockLength = blockDecompressor2.blockLength();
                                ByteBuf uncompressed = ctx.alloc().buffer(blockLength);
                                while (true) {
                                    try {
                                        int uncByte = blockDecompressor2.read();
                                        if (uncByte >= 0) {
                                            uncompressed.writeByte(uncByte);
                                        } else {
                                            int currentBlockCRC = blockDecompressor2.checkCRC();
                                            this.streamCRC = ((this.streamCRC << 1) | (this.streamCRC >>> 31)) ^ currentBlockCRC;
                                            try {
                                                out.add(uncompressed);
                                                if (1 == 0) {
                                                    uncompressed.release();
                                                }
                                                this.currentState = State.INIT_BLOCK;
                                                break;
                                            } catch (Throwable th) {
                                                th = th;
                                                if (0 == 0) {
                                                    uncompressed.release();
                                                }
                                                throw th;
                                            }
                                        }
                                    } catch (Throwable th2) {
                                        th = th2;
                                    }
                                }
                            }
                        }
                    }
                    break;
                case 3:
                    if (reader.hasReadableBits(25)) {
                    }
                    break;
                case 4:
                    blockRandomised = reader.hasReadableBits(16);
                    if (blockRandomised) {
                    }
                    break;
                case 5:
                    Bzip2BlockDecompressor blockDecompressor3 = this.blockDecompressor;
                    int inUse162 = blockDecompressor3.huffmanInUse16;
                    bitNumber = Integer.bitCount(inUse162);
                    byte[] huffmanSymbolMap2 = blockDecompressor3.huffmanSymbolMap;
                    if (reader.hasReadableBits((bitNumber * 16) + 3)) {
                    }
                    break;
                case 6:
                    if (reader.hasReadableBits(15)) {
                    }
                    break;
                case 7:
                    Bzip2HuffmanStageDecoder huffmanStageDecoder22 = this.huffmanStageDecoder;
                    byte[] selectors2 = huffmanStageDecoder22.selectors;
                    totalSelectors = selectors2.length;
                    Bzip2MoveToFrontTable tableMtf2 = huffmanStageDecoder22.tableMTF;
                    while (currSelector < totalSelectors) {
                    }
                    this.currentState = State.RECEIVE_HUFFMAN_LENGTH;
                    huffmanStageDecoder = this.huffmanStageDecoder;
                    totalTables = huffmanStageDecoder.totalTables;
                    byte[][] codeLength2 = huffmanStageDecoder.tableCodeLengths;
                    int alphaSize22 = huffmanStageDecoder.alphabetSize;
                    currLength = huffmanStageDecoder.currentLength;
                    currAlpha = 0;
                    modifyLength = huffmanStageDecoder.modifyLength;
                    saveStateAndReturn = false;
                    currGroup = huffmanStageDecoder.currentGroup;
                    while (true) {
                        if (currGroup < totalTables) {
                        }
                        currLength = -1;
                        huffmanStageDecoder.currentAlpha = 0;
                        currAlpha = 0;
                        modifyLength = false;
                        currGroup++;
                    }
                    if (saveStateAndReturn) {
                    }
                    break;
                case 8:
                    huffmanStageDecoder = this.huffmanStageDecoder;
                    totalTables = huffmanStageDecoder.totalTables;
                    byte[][] codeLength22 = huffmanStageDecoder.tableCodeLengths;
                    int alphaSize222 = huffmanStageDecoder.alphabetSize;
                    currLength = huffmanStageDecoder.currentLength;
                    currAlpha = 0;
                    modifyLength = huffmanStageDecoder.modifyLength;
                    saveStateAndReturn = false;
                    currGroup = huffmanStageDecoder.currentGroup;
                    while (true) {
                        if (currGroup < totalTables) {
                        }
                        currLength = -1;
                        huffmanStageDecoder.currentAlpha = 0;
                        currAlpha = 0;
                        modifyLength = false;
                        currGroup++;
                    }
                    if (saveStateAndReturn) {
                    }
                    break;
                case 9:
                    Bzip2BlockDecompressor blockDecompressor22 = this.blockDecompressor;
                    int oldReaderIndex2 = in.readerIndex();
                    decoded = blockDecompressor22.decodeHuffmanData(this.huffmanStageDecoder);
                    if (decoded) {
                    }
                    break;
                case 10:
                    in.skipBytes(in.readableBytes());
                    return;
                default:
                    throw new IllegalStateException();
            }
        }
    }

    /* renamed from: io.netty.handler.codec.compression.Bzip2Decoder$1  reason: invalid class name */
    /* loaded from: classes.dex */
    static /* synthetic */ class AnonymousClass1 {
        static final /* synthetic */ int[] $SwitchMap$io$netty$handler$codec$compression$Bzip2Decoder$State;

        static {
            int[] iArr = new int[State.values().length];
            $SwitchMap$io$netty$handler$codec$compression$Bzip2Decoder$State = iArr;
            try {
                iArr[State.INIT.ordinal()] = 1;
            } catch (NoSuchFieldError e) {
            }
            try {
                $SwitchMap$io$netty$handler$codec$compression$Bzip2Decoder$State[State.INIT_BLOCK.ordinal()] = 2;
            } catch (NoSuchFieldError e2) {
            }
            try {
                $SwitchMap$io$netty$handler$codec$compression$Bzip2Decoder$State[State.INIT_BLOCK_PARAMS.ordinal()] = 3;
            } catch (NoSuchFieldError e3) {
            }
            try {
                $SwitchMap$io$netty$handler$codec$compression$Bzip2Decoder$State[State.RECEIVE_HUFFMAN_USED_MAP.ordinal()] = 4;
            } catch (NoSuchFieldError e4) {
            }
            try {
                $SwitchMap$io$netty$handler$codec$compression$Bzip2Decoder$State[State.RECEIVE_HUFFMAN_USED_BITMAPS.ordinal()] = 5;
            } catch (NoSuchFieldError e5) {
            }
            try {
                $SwitchMap$io$netty$handler$codec$compression$Bzip2Decoder$State[State.RECEIVE_SELECTORS_NUMBER.ordinal()] = 6;
            } catch (NoSuchFieldError e6) {
            }
            try {
                $SwitchMap$io$netty$handler$codec$compression$Bzip2Decoder$State[State.RECEIVE_SELECTORS.ordinal()] = 7;
            } catch (NoSuchFieldError e7) {
            }
            try {
                $SwitchMap$io$netty$handler$codec$compression$Bzip2Decoder$State[State.RECEIVE_HUFFMAN_LENGTH.ordinal()] = 8;
            } catch (NoSuchFieldError e8) {
            }
            try {
                $SwitchMap$io$netty$handler$codec$compression$Bzip2Decoder$State[State.DECODE_HUFFMAN_DATA.ordinal()] = 9;
            } catch (NoSuchFieldError e9) {
            }
            try {
                $SwitchMap$io$netty$handler$codec$compression$Bzip2Decoder$State[State.EOF.ordinal()] = 10;
            } catch (NoSuchFieldError e10) {
            }
        }
    }

    public boolean isClosed() {
        return this.currentState == State.EOF;
    }
}
