package io.netty.handler.codec.compression;

import io.netty.buffer.ByteBuf;
import io.netty.channel.ChannelHandlerContext;
import io.netty.handler.codec.ByteToMessageDecoder;
import io.netty.handler.codec.memcache.binary.BinaryMemcacheOpcodes;
import io.netty.util.internal.EmptyArrays;
import java.util.List;
import java.util.zip.Adler32;
import java.util.zip.Checksum;
/* loaded from: classes.dex */
public class FastLzFrameDecoder extends ByteToMessageDecoder {
    private final Checksum checksum;
    private int chunkLength;
    private int currentChecksum;
    private State currentState;
    private boolean hasChecksum;
    private boolean isCompressed;
    private int originalLength;

    /* loaded from: classes.dex */
    private enum State {
        INIT_BLOCK,
        INIT_BLOCK_PARAMS,
        DECOMPRESS_DATA,
        CORRUPTED
    }

    public FastLzFrameDecoder() {
        this(false);
    }

    public FastLzFrameDecoder(boolean validateChecksums) {
        this(validateChecksums ? new Adler32() : null);
    }

    public FastLzFrameDecoder(Checksum checksum) {
        this.currentState = State.INIT_BLOCK;
        this.checksum = checksum;
    }

    /* renamed from: io.netty.handler.codec.compression.FastLzFrameDecoder$1  reason: invalid class name */
    /* loaded from: classes.dex */
    static /* synthetic */ class AnonymousClass1 {
        static final /* synthetic */ int[] $SwitchMap$io$netty$handler$codec$compression$FastLzFrameDecoder$State;

        static {
            int[] iArr = new int[State.values().length];
            $SwitchMap$io$netty$handler$codec$compression$FastLzFrameDecoder$State = iArr;
            try {
                iArr[State.INIT_BLOCK.ordinal()] = 1;
            } catch (NoSuchFieldError e) {
            }
            try {
                $SwitchMap$io$netty$handler$codec$compression$FastLzFrameDecoder$State[State.INIT_BLOCK_PARAMS.ordinal()] = 2;
            } catch (NoSuchFieldError e2) {
            }
            try {
                $SwitchMap$io$netty$handler$codec$compression$FastLzFrameDecoder$State[State.DECOMPRESS_DATA.ordinal()] = 3;
            } catch (NoSuchFieldError e3) {
            }
            try {
                $SwitchMap$io$netty$handler$codec$compression$FastLzFrameDecoder$State[State.CORRUPTED.ordinal()] = 4;
            } catch (NoSuchFieldError e4) {
            }
        }
    }

    /* JADX WARN: Removed duplicated region for block: B:104:0x01a1 A[ADDED_TO_REGION] */
    /* JADX WARN: Removed duplicated region for block: B:47:0x009d  */
    /* JADX WARN: Removed duplicated region for block: B:48:0x00a1 A[Catch: Exception -> 0x01b4, TryCatch #6 {Exception -> 0x01b4, blocks: (B:3:0x0004, B:9:0x001b, B:10:0x0026, B:11:0x002b, B:45:0x0094, B:48:0x00a1, B:50:0x00ab, B:51:0x00c4, B:26:0x005b, B:30:0x0066, B:34:0x006d, B:37:0x0074, B:39:0x0078, B:41:0x007e, B:43:0x008a, B:44:0x008e, B:12:0x002c, B:15:0x0036, B:17:0x003f, B:21:0x004a, B:25:0x0055), top: B:127:0x0004 }] */
    @Override // io.netty.handler.codec.ByteToMessageDecoder
    /*
        Code decompiled incorrectly, please refer to instructions dump.
    */
    protected void decode(ChannelHandlerContext ctx, ByteBuf in, List<Object> out) throws Exception {
        int i;
        int i2;
        int chunkLength;
        ByteBuf uncompressed;
        byte[] output;
        int outputPtr;
        byte[] input;
        int inputPtr;
        int outputPtr2;
        byte[] output2;
        try {
            i = AnonymousClass1.$SwitchMap$io$netty$handler$codec$compression$FastLzFrameDecoder$State[this.currentState.ordinal()];
            i2 = 4;
        } catch (Exception e) {
            e = e;
        }
        try {
            if (i != 1) {
                if (i != 2) {
                    if (i != 3) {
                        if (i != 4) {
                            throw new IllegalStateException();
                        }
                        in.skipBytes(in.readableBytes());
                        return;
                    }
                    chunkLength = this.chunkLength;
                    if (in.readableBytes() >= chunkLength) {
                        return;
                    }
                    int idx = in.readerIndex();
                    int originalLength = this.originalLength;
                    if (originalLength != 0) {
                        ByteBuf uncompressed2 = ctx.alloc().heapBuffer(originalLength, originalLength);
                        byte[] output3 = uncompressed2.array();
                        uncompressed = uncompressed2;
                        output = output3;
                        outputPtr = uncompressed2.arrayOffset() + uncompressed2.writerIndex();
                    } else {
                        byte[] output4 = EmptyArrays.EMPTY_BYTES;
                        uncompressed = null;
                        output = output4;
                        outputPtr = 0;
                    }
                    try {
                        if (this.isCompressed) {
                            try {
                                if (in.hasArray()) {
                                    try {
                                        input = in.array();
                                        inputPtr = in.arrayOffset() + idx;
                                    } catch (Throwable th) {
                                        th = th;
                                        if (0 == 0) {
                                            uncompressed.release();
                                        }
                                        throw th;
                                    }
                                } else {
                                    input = new byte[chunkLength];
                                    in.getBytes(idx, input);
                                    inputPtr = 0;
                                }
                                int outputPtr3 = outputPtr;
                                byte[] output5 = output;
                                try {
                                    int decompressedBytes = FastLz.decompress(input, inputPtr, chunkLength, output, outputPtr, originalLength);
                                    if (originalLength != decompressedBytes) {
                                        throw new DecompressionException(String.format("stream corrupted: originalLength(%d) and actual length(%d) mismatch", Integer.valueOf(originalLength), Integer.valueOf(decompressedBytes)));
                                    }
                                    outputPtr2 = outputPtr3;
                                    output2 = output5;
                                } catch (Throwable th2) {
                                    th = th2;
                                    if (0 == 0 && uncompressed != null) {
                                        uncompressed.release();
                                    }
                                    throw th;
                                }
                            } catch (Throwable th3) {
                                th = th3;
                            }
                        } else {
                            outputPtr2 = outputPtr;
                            output2 = output;
                            try {
                                in.getBytes(idx, output2, outputPtr2, chunkLength);
                            } catch (Throwable th4) {
                                th = th4;
                                if (0 == 0) {
                                }
                                throw th;
                            }
                        }
                        Checksum checksum = this.checksum;
                        if (this.hasChecksum && checksum != null) {
                            checksum.reset();
                            checksum.update(output2, outputPtr2, originalLength);
                            int checksumResult = (int) checksum.getValue();
                            if (checksumResult != this.currentChecksum) {
                                throw new DecompressionException(String.format("stream corrupted: mismatching checksum: %d (expected: %d)", Integer.valueOf(checksumResult), Integer.valueOf(this.currentChecksum)));
                            }
                        }
                        if (uncompressed != null) {
                            uncompressed.writerIndex(uncompressed.writerIndex() + originalLength);
                            try {
                                out.add(uncompressed);
                            } catch (Throwable th5) {
                                th = th5;
                                if (0 == 0) {
                                }
                                throw th;
                            }
                        }
                        in.skipBytes(chunkLength);
                        this.currentState = State.INIT_BLOCK;
                        if (1 != 0 || uncompressed == null) {
                            return;
                        }
                        uncompressed.release();
                        return;
                    } catch (Throwable th6) {
                        th = th6;
                    }
                }
            } else if (in.readableBytes() < 4) {
                return;
            } else {
                int magic = in.readUnsignedMedium();
                if (magic != 4607066) {
                    throw new DecompressionException("unexpected block identifier");
                }
                byte options = in.readByte();
                this.isCompressed = (options & 1) == 1;
                this.hasChecksum = (options & BinaryMemcacheOpcodes.STAT) == 16;
                this.currentState = State.INIT_BLOCK_PARAMS;
            }
            int magic2 = in.readableBytes();
            int i3 = (this.isCompressed ? 2 : 0) + 2;
            if (!this.hasChecksum) {
                i2 = 0;
            }
            if (magic2 < i3 + i2) {
                return;
            }
            this.currentChecksum = this.hasChecksum ? in.readInt() : 0;
            int readUnsignedShort = in.readUnsignedShort();
            this.chunkLength = readUnsignedShort;
            if (this.isCompressed) {
                readUnsignedShort = in.readUnsignedShort();
            }
            this.originalLength = readUnsignedShort;
            this.currentState = State.DECOMPRESS_DATA;
            chunkLength = this.chunkLength;
            if (in.readableBytes() >= chunkLength) {
            }
        } catch (Exception e2) {
            e = e2;
            this.currentState = State.CORRUPTED;
            throw e;
        }
    }
}
