package io.netty.handler.codec.compression;

import io.netty.buffer.ByteBuf;
import io.netty.channel.ChannelHandlerContext;
import io.netty.handler.codec.ByteToMessageDecoder;
import io.netty.util.internal.ObjectUtil;
import java.util.List;
import java.util.zip.Checksum;
import net.jpountz.lz4.LZ4Exception;
import net.jpountz.lz4.LZ4Factory;
import net.jpountz.lz4.LZ4FastDecompressor;
/* loaded from: classes.dex */
public class Lz4FrameDecoder extends ByteToMessageDecoder {
    private int blockType;
    private ByteBufChecksum checksum;
    private int compressedLength;
    private int currentChecksum;
    private State currentState;
    private int decompressedLength;
    private LZ4FastDecompressor decompressor;

    /* loaded from: classes.dex */
    private enum State {
        INIT_BLOCK,
        DECOMPRESS_DATA,
        FINISHED,
        CORRUPTED
    }

    public Lz4FrameDecoder() {
        this(false);
    }

    public Lz4FrameDecoder(boolean validateChecksums) {
        this(LZ4Factory.fastestInstance(), validateChecksums);
    }

    public Lz4FrameDecoder(LZ4Factory factory, boolean validateChecksums) {
        this(factory, validateChecksums ? new Lz4XXHash32(-1756908916) : null);
    }

    public Lz4FrameDecoder(LZ4Factory factory, Checksum checksum) {
        this.currentState = State.INIT_BLOCK;
        this.decompressor = ((LZ4Factory) ObjectUtil.checkNotNull(factory, "factory")).fastDecompressor();
        this.checksum = checksum == null ? null : ByteBufChecksum.wrapChecksum(checksum);
    }

    /* renamed from: io.netty.handler.codec.compression.Lz4FrameDecoder$1  reason: invalid class name */
    /* loaded from: classes.dex */
    static /* synthetic */ class AnonymousClass1 {
        static final /* synthetic */ int[] $SwitchMap$io$netty$handler$codec$compression$Lz4FrameDecoder$State;

        static {
            int[] iArr = new int[State.values().length];
            $SwitchMap$io$netty$handler$codec$compression$Lz4FrameDecoder$State = iArr;
            try {
                iArr[State.INIT_BLOCK.ordinal()] = 1;
            } catch (NoSuchFieldError e) {
            }
            try {
                $SwitchMap$io$netty$handler$codec$compression$Lz4FrameDecoder$State[State.DECOMPRESS_DATA.ordinal()] = 2;
            } catch (NoSuchFieldError e2) {
            }
            try {
                $SwitchMap$io$netty$handler$codec$compression$Lz4FrameDecoder$State[State.FINISHED.ordinal()] = 3;
            } catch (NoSuchFieldError e3) {
            }
            try {
                $SwitchMap$io$netty$handler$codec$compression$Lz4FrameDecoder$State[State.CORRUPTED.ordinal()] = 4;
            } catch (NoSuchFieldError e4) {
            }
        }
    }

    /* JADX WARN: Removed duplicated region for block: B:73:0x015c A[Catch: Exception -> 0x01a5, TRY_ENTER, TryCatch #4 {Exception -> 0x01a5, blocks: (B:59:0x0144, B:73:0x015c, B:75:0x0160, B:76:0x0161, B:77:0x017d, B:78:0x017e, B:79:0x019a, B:80:0x019b, B:81:0x01a4), top: B:92:0x0014 }] */
    @Override // io.netty.handler.codec.ByteToMessageDecoder
    /*
        Code decompiled incorrectly, please refer to instructions dump.
    */
    protected void decode(ChannelHandlerContext ctx, ByteBuf in, List<Object> out) throws Exception {
        int i;
        ByteBuf uncompressed;
        try {
            i = AnonymousClass1.$SwitchMap$io$netty$handler$codec$compression$Lz4FrameDecoder$State[this.currentState.ordinal()];
        } catch (Exception e) {
            e = e;
        }
        try {
            if (i != 1) {
                if (i != 2) {
                    if (i != 3 && i != 4) {
                        throw new IllegalStateException();
                    }
                    in.skipBytes(in.readableBytes());
                    return;
                }
            } else if (in.readableBytes() >= 21) {
                long magic = in.readLong();
                if (magic != 5501767354678207339L) {
                    throw new DecompressionException("unexpected block identifier");
                }
                int token = in.readByte();
                int compressionLevel = (token & 15) + 10;
                int blockType = token & 240;
                int compressedLength = Integer.reverseBytes(in.readInt());
                if (compressedLength < 0 || compressedLength > 33554432) {
                    throw new DecompressionException(String.format("invalid compressedLength: %d (expected: 0-%d)", Integer.valueOf(compressedLength), 33554432));
                }
                int decompressedLength = Integer.reverseBytes(in.readInt());
                int maxDecompressedLength = 1 << compressionLevel;
                if (decompressedLength < 0 || decompressedLength > maxDecompressedLength) {
                    throw new DecompressionException(String.format("invalid decompressedLength: %d (expected: 0-%d)", Integer.valueOf(decompressedLength), Integer.valueOf(maxDecompressedLength)));
                }
                if ((decompressedLength == 0 && compressedLength != 0) || ((decompressedLength != 0 && compressedLength == 0) || (blockType == 16 && decompressedLength != compressedLength))) {
                    throw new DecompressionException(String.format("stream corrupted: compressedLength(%d) and decompressedLength(%d) mismatch", Integer.valueOf(compressedLength), Integer.valueOf(decompressedLength)));
                }
                int currentChecksum = Integer.reverseBytes(in.readInt());
                if (decompressedLength == 0 && compressedLength == 0) {
                    if (currentChecksum != 0) {
                        throw new DecompressionException("stream corrupted: checksum error");
                    }
                    this.currentState = State.FINISHED;
                    this.decompressor = null;
                    this.checksum = null;
                    return;
                }
                this.blockType = blockType;
                this.compressedLength = compressedLength;
                this.decompressedLength = decompressedLength;
                this.currentChecksum = currentChecksum;
                this.currentState = State.DECOMPRESS_DATA;
            } else {
                return;
            }
            int token2 = this.blockType;
            int compressedLength2 = this.compressedLength;
            int decompressedLength2 = this.decompressedLength;
            int currentChecksum2 = this.currentChecksum;
            if (in.readableBytes() >= compressedLength2) {
                ByteBufChecksum checksum = this.checksum;
                ByteBuf uncompressed2 = null;
                try {
                    try {
                        if (token2 == 16) {
                            ByteBuf uncompressed3 = in.retainedSlice(in.readerIndex(), decompressedLength2);
                            uncompressed = uncompressed3;
                        } else if (token2 == 32) {
                            uncompressed = ctx.alloc().buffer(decompressedLength2, decompressedLength2);
                            this.decompressor.decompress(CompressionUtil.safeNioBuffer(in), uncompressed.internalNioBuffer(uncompressed.writerIndex(), decompressedLength2));
                            uncompressed.writerIndex(uncompressed.writerIndex() + decompressedLength2);
                        } else {
                            throw new DecompressionException(String.format("unexpected blockType: %d (expected: %d or %d)", Integer.valueOf(token2), 16, 32));
                        }
                        in.skipBytes(compressedLength2);
                        if (checksum != null) {
                            CompressionUtil.checkChecksum(checksum, uncompressed, currentChecksum2);
                        }
                        try {
                            out.add(uncompressed);
                            ByteBuf uncompressed4 = null;
                            this.currentState = State.INIT_BLOCK;
                            if (0 != 0) {
                                uncompressed4.release();
                            }
                        } catch (LZ4Exception e2) {
                            e = e2;
                            throw new DecompressionException((Throwable) e);
                        }
                    } catch (Throwable th) {
                        th = th;
                        if (0 != 0) {
                            uncompressed2.release();
                        }
                        throw th;
                    }
                } catch (LZ4Exception e3) {
                    e = e3;
                } catch (Throwable th2) {
                    th = th2;
                    if (0 != 0) {
                    }
                    throw th;
                }
            }
        } catch (Exception e4) {
            e = e4;
            this.currentState = State.CORRUPTED;
            throw e;
        }
    }

    public boolean isClosed() {
        return this.currentState == State.FINISHED;
    }
}
