package io.netty.handler.codec.compression;

import com.ning.compress.BufferRecycler;
import com.ning.compress.lzf.ChunkDecoder;
import com.ning.compress.lzf.util.ChunkDecoderFactory;
import io.netty.buffer.ByteBuf;
import io.netty.channel.ChannelHandlerContext;
import io.netty.handler.codec.ByteToMessageDecoder;
import java.util.List;
/* loaded from: classes.dex */
public class LzfDecoder extends ByteToMessageDecoder {
    private static final short MAGIC_NUMBER = 23126;
    private int chunkLength;
    private State currentState;
    private ChunkDecoder decoder;
    private boolean isCompressed;
    private int originalLength;
    private BufferRecycler recycler;

    /* loaded from: classes.dex */
    private enum State {
        INIT_BLOCK,
        INIT_ORIGINAL_LENGTH,
        DECOMPRESS_DATA,
        CORRUPTED
    }

    public LzfDecoder() {
        this(false);
    }

    public LzfDecoder(boolean safeInstance) {
        ChunkDecoder optimalInstance;
        this.currentState = State.INIT_BLOCK;
        if (safeInstance) {
            optimalInstance = ChunkDecoderFactory.safeInstance();
        } else {
            optimalInstance = ChunkDecoderFactory.optimalInstance();
        }
        this.decoder = optimalInstance;
        this.recycler = BufferRecycler.instance();
    }

    /* renamed from: io.netty.handler.codec.compression.LzfDecoder$1  reason: invalid class name */
    /* loaded from: classes.dex */
    static /* synthetic */ class AnonymousClass1 {
        static final /* synthetic */ int[] $SwitchMap$io$netty$handler$codec$compression$LzfDecoder$State;

        static {
            int[] iArr = new int[State.values().length];
            $SwitchMap$io$netty$handler$codec$compression$LzfDecoder$State = iArr;
            try {
                iArr[State.INIT_BLOCK.ordinal()] = 1;
            } catch (NoSuchFieldError e) {
            }
            try {
                $SwitchMap$io$netty$handler$codec$compression$LzfDecoder$State[State.INIT_ORIGINAL_LENGTH.ordinal()] = 2;
            } catch (NoSuchFieldError e2) {
            }
            try {
                $SwitchMap$io$netty$handler$codec$compression$LzfDecoder$State[State.DECOMPRESS_DATA.ordinal()] = 3;
            } catch (NoSuchFieldError e3) {
            }
            try {
                $SwitchMap$io$netty$handler$codec$compression$LzfDecoder$State[State.CORRUPTED.ordinal()] = 4;
            } catch (NoSuchFieldError e4) {
            }
        }
    }

    /* JADX WARN: Removed duplicated region for block: B:33:0x0098  */
    /* JADX WARN: Removed duplicated region for block: B:34:0x009a A[Catch: Exception -> 0x012a, TryCatch #2 {Exception -> 0x012a, blocks: (B:3:0x0006, B:9:0x001d, B:10:0x0026, B:11:0x002b, B:31:0x008f, B:34:0x009a, B:36:0x00a1, B:38:0x00ac, B:40:0x00c4, B:45:0x00f9, B:46:0x00fc, B:48:0x0102, B:57:0x011b, B:39:0x00b8, B:55:0x0112, B:27:0x007d, B:30:0x0085, B:12:0x002c, B:15:0x0035, B:17:0x003d, B:20:0x0045, B:24:0x0073, B:21:0x004c, B:22:0x006b, B:23:0x006c, B:60:0x0122, B:61:0x0129, B:42:0x00dd), top: B:65:0x0006 }] */
    @Override // io.netty.handler.codec.ByteToMessageDecoder
    /*
        Code decompiled incorrectly, please refer to instructions dump.
    */
    protected void decode(ChannelHandlerContext ctx, ByteBuf in, List<Object> out) throws Exception {
        int chunkLength;
        int inPos;
        byte[] inputArray;
        try {
            int i = AnonymousClass1.$SwitchMap$io$netty$handler$codec$compression$LzfDecoder$State[this.currentState.ordinal()];
            if (i != 1) {
                if (i != 2) {
                    if (i != 3) {
                        if (i == 4) {
                            in.skipBytes(in.readableBytes());
                            return;
                        }
                        throw new IllegalStateException();
                    }
                    chunkLength = this.chunkLength;
                    if (in.readableBytes() < chunkLength) {
                        int originalLength = this.originalLength;
                        if (this.isCompressed) {
                            int idx = in.readerIndex();
                            if (in.hasArray()) {
                                byte[] inputArray2 = in.array();
                                inPos = in.arrayOffset() + idx;
                                inputArray = inputArray2;
                            } else {
                                byte[] inputArray3 = this.recycler.allocInputBuffer(chunkLength);
                                in.getBytes(idx, inputArray3, 0, chunkLength);
                                inPos = 0;
                                inputArray = inputArray3;
                            }
                            ByteBuf uncompressed = ctx.alloc().heapBuffer(originalLength, originalLength);
                            byte[] outputArray = uncompressed.array();
                            int outPos = uncompressed.arrayOffset() + uncompressed.writerIndex();
                            this.decoder.decodeChunk(inputArray, inPos, outputArray, outPos, outPos + originalLength);
                            uncompressed.writerIndex(uncompressed.writerIndex() + originalLength);
                            out.add(uncompressed);
                            in.skipBytes(chunkLength);
                            if (1 == 0) {
                                uncompressed.release();
                            }
                            if (!in.hasArray()) {
                                this.recycler.releaseInputBuffer(inputArray);
                            }
                        } else if (chunkLength > 0) {
                            out.add(in.readRetainedSlice(chunkLength));
                        }
                        this.currentState = State.INIT_BLOCK;
                        return;
                    }
                    return;
                }
            } else if (in.readableBytes() >= 5) {
                int magic = in.readUnsignedShort();
                if (magic != 23126) {
                    throw new DecompressionException("unexpected block identifier");
                }
                int type = in.readByte();
                if (type == 0) {
                    this.isCompressed = false;
                    this.currentState = State.DECOMPRESS_DATA;
                } else if (type == 1) {
                    this.isCompressed = true;
                    this.currentState = State.INIT_ORIGINAL_LENGTH;
                } else {
                    throw new DecompressionException(String.format("unknown type of chunk: %d (expected: %d or %d)", Integer.valueOf(type), 0, 1));
                }
                this.chunkLength = in.readUnsignedShort();
                if (type != 1) {
                    return;
                }
            } else {
                return;
            }
            int magic2 = in.readableBytes();
            if (magic2 >= 2) {
                this.originalLength = in.readUnsignedShort();
                this.currentState = State.DECOMPRESS_DATA;
                chunkLength = this.chunkLength;
                if (in.readableBytes() < chunkLength) {
                }
            }
        } catch (Exception e) {
            this.currentState = State.CORRUPTED;
            this.decoder = null;
            this.recycler = null;
            throw e;
        }
    }
}
