package io.netty.handler.codec.compression;

import io.netty.buffer.ByteBuf;
/* loaded from: classes.dex */
public final class Snappy {
    private static final int COPY_1_BYTE_OFFSET = 1;
    private static final int COPY_2_BYTE_OFFSET = 2;
    private static final int COPY_4_BYTE_OFFSET = 3;
    private static final int LITERAL = 0;
    private static final int MAX_HT_SIZE = 16384;
    private static final int MIN_COMPRESSIBLE_BYTES = 15;
    private static final int NOT_ENOUGH_INPUT = -1;
    private static final int PREAMBLE_NOT_FULL = -1;
    private State state = State.READY;
    private byte tag;
    private int written;

    /* loaded from: classes.dex */
    private enum State {
        READY,
        READING_PREAMBLE,
        READING_TAG,
        READING_LITERAL,
        READING_COPY
    }

    public void reset() {
        this.state = State.READY;
        this.tag = (byte) 0;
        this.written = 0;
    }

    /* JADX WARN: Code restructure failed: missing block: B:15:0x0063, code lost:
        encodeLiteral(r20, r21, r3 - r9);
     */
    /* JADX WARN: Code restructure failed: missing block: B:16:0x0068, code lost:
        r7 = r3;
        r11 = findMatchingLength(r20, r13 + 4, r3 + 4, r22) + 4;
        r3 = r3 + r11;
        r14 = r7 - r13;
        encodeCopy(r21, r14, r11);
        r20.readerIndex(r20.readerIndex() + r11);
        r15 = r3 - 1;
        r9 = r3;
        r7 = r22 - 4;
     */
    /* JADX WARN: Code restructure failed: missing block: B:17:0x0088, code lost:
        if (r3 < r7) goto L19;
     */
    /* JADX WARN: Code restructure failed: missing block: B:18:0x008a, code lost:
        r7 = r9;
     */
    /* JADX WARN: Code restructure failed: missing block: B:19:0x008c, code lost:
        r7 = hash(r20, r15, r6);
        r18 = r8;
        r8 = (r3 - r3) - 1;
        r5[r7] = (short) r8;
        r8 = hash(r20, r15 + 1, r6);
        r13 = r3 + r5[r8];
        r7 = r3 - r3;
        r5[r8] = (short) r7;
     */
    /* JADX WARN: Code restructure failed: missing block: B:20:0x00b4, code lost:
        if (r20.getInt(r15 + 1) == r20.getInt(r13)) goto L21;
     */
    /* JADX WARN: Code restructure failed: missing block: B:22:0x00c1, code lost:
        r8 = r18;
     */
    /*
        Code decompiled incorrectly, please refer to instructions dump.
    */
    public void encode(ByteBuf in, ByteBuf out, int length) {
        int b;
        int inIndex;
        int insertTail;
        int i = 0;
        while (true) {
            b = length >>> (i * 7);
            if ((b & (-128)) == 0) {
                break;
            }
            out.writeByte((b & 127) | 128);
            i++;
        }
        out.writeByte(b);
        int inIndex2 = in.readerIndex();
        short[] table = getHashTable(length);
        int shift = Integer.numberOfLeadingZeros(table.length) + 1;
        int nextEmit = inIndex2;
        if (length - inIndex2 >= 15) {
            int inIndex3 = inIndex2 + 1;
            int nextHash = hash(in, inIndex3, shift);
            int nextEmit2 = nextEmit;
            loop1: while (true) {
                int skip = 32;
                int nextIndex = inIndex3;
                while (true) {
                    inIndex = nextIndex;
                    int hash = nextHash;
                    int skip2 = skip + 1;
                    int bytesBetweenHashLookups = skip >> 5;
                    nextIndex = inIndex + bytesBetweenHashLookups;
                    if (nextIndex > length - 4) {
                        nextEmit = nextEmit2;
                        break loop1;
                    }
                    nextHash = hash(in, nextIndex, shift);
                    int candidate = table[hash] + inIndex2;
                    table[hash] = (short) (inIndex - inIndex2);
                    int bytesBetweenHashLookups2 = in.getInt(inIndex);
                    if (bytesBetweenHashLookups2 == in.getInt(candidate)) {
                        break;
                    }
                    skip = skip2;
                }
                nextHash = hash(in, insertTail + 2, shift);
                inIndex3 = inIndex + 1;
            }
        }
        if (nextEmit < length) {
            encodeLiteral(in, out, length - nextEmit);
        }
    }

    private static int hash(ByteBuf in, int index, int shift) {
        return (in.getInt(index) * 506832829) >>> shift;
    }

    private static short[] getHashTable(int inputSize) {
        int htSize = 256;
        while (htSize < 16384 && htSize < inputSize) {
            htSize <<= 1;
        }
        return new short[htSize];
    }

    private static int findMatchingLength(ByteBuf in, int minIndex, int inIndex, int maxIndex) {
        int matched = 0;
        while (inIndex <= maxIndex - 4 && in.getInt(inIndex) == in.getInt(minIndex + matched)) {
            inIndex += 4;
            matched += 4;
        }
        while (inIndex < maxIndex && in.getByte(minIndex + matched) == in.getByte(inIndex)) {
            inIndex++;
            matched++;
        }
        return matched;
    }

    private static int bitsToEncode(int value) {
        int highestOneBit = Integer.highestOneBit(value);
        int bitLength = 0;
        while (true) {
            int i = highestOneBit >> 1;
            highestOneBit = i;
            if (i != 0) {
                bitLength++;
            } else {
                return bitLength;
            }
        }
    }

    static void encodeLiteral(ByteBuf in, ByteBuf out, int length) {
        if (length < 61) {
            out.writeByte((length - 1) << 2);
        } else {
            int bitLength = bitsToEncode(length - 1);
            int bytesToEncode = (bitLength / 8) + 1;
            out.writeByte((bytesToEncode + 59) << 2);
            for (int i = 0; i < bytesToEncode; i++) {
                out.writeByte(((length - 1) >> (i * 8)) & 255);
            }
        }
        out.writeBytes(in, length);
    }

    private static void encodeCopyWithOffset(ByteBuf out, int offset, int length) {
        if (length < 12 && offset < 2048) {
            out.writeByte(((length - 4) << 2) | 1 | ((offset >> 8) << 5));
            out.writeByte(offset & 255);
            return;
        }
        out.writeByte(((length - 1) << 2) | 2);
        out.writeByte(offset & 255);
        out.writeByte((offset >> 8) & 255);
    }

    private static void encodeCopy(ByteBuf out, int offset, int length) {
        while (length >= 68) {
            encodeCopyWithOffset(out, offset, 64);
            length -= 64;
        }
        if (length > 64) {
            encodeCopyWithOffset(out, offset, 60);
            length -= 60;
        }
        encodeCopyWithOffset(out, offset, length);
    }

    /* renamed from: io.netty.handler.codec.compression.Snappy$1  reason: invalid class name */
    /* loaded from: classes.dex */
    static /* synthetic */ class AnonymousClass1 {
        static final /* synthetic */ int[] $SwitchMap$io$netty$handler$codec$compression$Snappy$State;

        static {
            int[] iArr = new int[State.values().length];
            $SwitchMap$io$netty$handler$codec$compression$Snappy$State = iArr;
            try {
                iArr[State.READY.ordinal()] = 1;
            } catch (NoSuchFieldError e) {
            }
            try {
                $SwitchMap$io$netty$handler$codec$compression$Snappy$State[State.READING_PREAMBLE.ordinal()] = 2;
            } catch (NoSuchFieldError e2) {
            }
            try {
                $SwitchMap$io$netty$handler$codec$compression$Snappy$State[State.READING_TAG.ordinal()] = 3;
            } catch (NoSuchFieldError e3) {
            }
            try {
                $SwitchMap$io$netty$handler$codec$compression$Snappy$State[State.READING_LITERAL.ordinal()] = 4;
            } catch (NoSuchFieldError e4) {
            }
            try {
                $SwitchMap$io$netty$handler$codec$compression$Snappy$State[State.READING_COPY.ordinal()] = 5;
            } catch (NoSuchFieldError e5) {
            }
        }
    }

    /* JADX WARN: Removed duplicated region for block: B:45:0x009b  */
    /* JADX WARN: Removed duplicated region for block: B:78:0x009a A[SYNTHETIC] */
    /*
        Code decompiled incorrectly, please refer to instructions dump.
    */
    public void decode(ByteBuf in, ByteBuf out) {
        while (in.isReadable()) {
            int i = AnonymousClass1.$SwitchMap$io$netty$handler$codec$compression$Snappy$State[this.state.ordinal()];
            if (i == 1) {
                this.state = State.READING_PREAMBLE;
            } else if (i != 2) {
                if (i != 3) {
                    if (i == 4) {
                        int literalWritten = decodeLiteral(this.tag, in, out);
                        if (literalWritten != -1) {
                            this.state = State.READING_TAG;
                            this.written += literalWritten;
                        } else {
                            return;
                        }
                    } else if (i == 5) {
                        byte b = this.tag;
                        int i2 = b & 3;
                        if (i2 == 1) {
                            int decodeWritten = decodeCopyWith1ByteOffset(b, in, out, this.written);
                            if (decodeWritten != -1) {
                                this.state = State.READING_TAG;
                                this.written += decodeWritten;
                            } else {
                                return;
                            }
                        } else if (i2 == 2) {
                            int decodeWritten2 = decodeCopyWith2ByteOffset(b, in, out, this.written);
                            if (decodeWritten2 != -1) {
                                this.state = State.READING_TAG;
                                this.written += decodeWritten2;
                            } else {
                                return;
                            }
                        } else if (i2 == 3) {
                            int decodeWritten3 = decodeCopyWith4ByteOffset(b, in, out, this.written);
                            if (decodeWritten3 != -1) {
                                this.state = State.READING_TAG;
                                this.written += decodeWritten3;
                            } else {
                                return;
                            }
                        } else {
                            continue;
                        }
                    } else {
                        continue;
                    }
                } else if (in.isReadable()) {
                    return;
                } else {
                    byte readByte = in.readByte();
                    this.tag = readByte;
                    int i3 = readByte & 3;
                    if (i3 == 0) {
                        this.state = State.READING_LITERAL;
                    } else if (i3 == 1 || i3 == 2 || i3 == 3) {
                        this.state = State.READING_COPY;
                    }
                }
            }
            int uncompressedLength = readPreamble(in);
            if (uncompressedLength == -1) {
                return;
            }
            if (uncompressedLength == 0) {
                this.state = State.READY;
                return;
            }
            out.ensureWritable(uncompressedLength);
            this.state = State.READING_TAG;
            if (in.isReadable()) {
            }
        }
    }

    private static int readPreamble(ByteBuf in) {
        int length = 0;
        int byteIndex = 0;
        while (in.isReadable()) {
            int current = in.readUnsignedByte();
            int byteIndex2 = byteIndex + 1;
            length |= (current & 127) << (byteIndex * 7);
            if ((current & 128) == 0) {
                return length;
            }
            if (byteIndex2 >= 4) {
                throw new DecompressionException("Preamble is greater than 4 bytes");
            }
            byteIndex = byteIndex2;
        }
        return 0;
    }

    static int decodeLiteral(byte tag, ByteBuf in, ByteBuf out) {
        int length;
        in.markReaderIndex();
        switch ((tag >> 2) & 63) {
            case 60:
                if (in.isReadable()) {
                    length = in.readUnsignedByte();
                    break;
                } else {
                    return -1;
                }
            case 61:
                int length2 = in.readableBytes();
                if (length2 >= 2) {
                    length = in.readUnsignedShortLE();
                    break;
                } else {
                    return -1;
                }
            case 62:
                int length3 = in.readableBytes();
                if (length3 >= 3) {
                    length = in.readUnsignedMediumLE();
                    break;
                } else {
                    return -1;
                }
            case 63:
                int length4 = in.readableBytes();
                if (length4 >= 4) {
                    length = in.readIntLE();
                    break;
                } else {
                    return -1;
                }
            default:
                length = (tag >> 2) & 63;
                break;
        }
        int length5 = length + 1;
        if (in.readableBytes() < length5) {
            in.resetReaderIndex();
            return -1;
        }
        out.writeBytes(in, length5);
        return length5;
    }

    private static int decodeCopyWith1ByteOffset(byte tag, ByteBuf in, ByteBuf out, int writtenSoFar) {
        if (!in.isReadable()) {
            return -1;
        }
        int initialIndex = out.writerIndex();
        int length = ((tag & 28) >> 2) + 4;
        int offset = (((tag & 224) << 8) >> 5) | in.readUnsignedByte();
        validateOffset(offset, writtenSoFar);
        out.markReaderIndex();
        if (offset < length) {
            for (int copies = length / offset; copies > 0; copies--) {
                out.readerIndex(initialIndex - offset);
                out.readBytes(out, offset);
            }
            if (length % offset != 0) {
                out.readerIndex(initialIndex - offset);
                out.readBytes(out, length % offset);
            }
        } else {
            out.readerIndex(initialIndex - offset);
            out.readBytes(out, length);
        }
        out.resetReaderIndex();
        return length;
    }

    private static int decodeCopyWith2ByteOffset(byte tag, ByteBuf in, ByteBuf out, int writtenSoFar) {
        if (in.readableBytes() < 2) {
            return -1;
        }
        int initialIndex = out.writerIndex();
        int length = ((tag >> 2) & 63) + 1;
        int offset = in.readUnsignedShortLE();
        validateOffset(offset, writtenSoFar);
        out.markReaderIndex();
        if (offset < length) {
            for (int copies = length / offset; copies > 0; copies--) {
                out.readerIndex(initialIndex - offset);
                out.readBytes(out, offset);
            }
            if (length % offset != 0) {
                out.readerIndex(initialIndex - offset);
                out.readBytes(out, length % offset);
            }
        } else {
            out.readerIndex(initialIndex - offset);
            out.readBytes(out, length);
        }
        out.resetReaderIndex();
        return length;
    }

    private static int decodeCopyWith4ByteOffset(byte tag, ByteBuf in, ByteBuf out, int writtenSoFar) {
        if (in.readableBytes() < 4) {
            return -1;
        }
        int initialIndex = out.writerIndex();
        int length = ((tag >> 2) & 63) + 1;
        int offset = in.readIntLE();
        validateOffset(offset, writtenSoFar);
        out.markReaderIndex();
        if (offset < length) {
            for (int copies = length / offset; copies > 0; copies--) {
                out.readerIndex(initialIndex - offset);
                out.readBytes(out, offset);
            }
            if (length % offset != 0) {
                out.readerIndex(initialIndex - offset);
                out.readBytes(out, length % offset);
            }
        } else {
            out.readerIndex(initialIndex - offset);
            out.readBytes(out, length);
        }
        out.resetReaderIndex();
        return length;
    }

    private static void validateOffset(int offset, int chunkSizeSoFar) {
        if (offset == 0) {
            throw new DecompressionException("Offset is less than minimum permissible value");
        }
        if (offset < 0) {
            throw new DecompressionException("Offset is greater than maximum value supported by this implementation");
        }
        if (offset > chunkSizeSoFar) {
            throw new DecompressionException("Offset exceeds size of chunk");
        }
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    public static int calculateChecksum(ByteBuf data) {
        return calculateChecksum(data, data.readerIndex(), data.readableBytes());
    }

    static int calculateChecksum(ByteBuf data, int offset, int length) {
        Crc32c crc32 = new Crc32c();
        try {
            crc32.update(data, offset, length);
            return maskChecksum((int) crc32.getValue());
        } finally {
            crc32.reset();
        }
    }

    static void validateChecksum(int expectedChecksum, ByteBuf data) {
        validateChecksum(expectedChecksum, data, data.readerIndex(), data.readableBytes());
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    public static void validateChecksum(int expectedChecksum, ByteBuf data, int offset, int length) {
        int actualChecksum = calculateChecksum(data, offset, length);
        if (actualChecksum != expectedChecksum) {
            throw new DecompressionException("mismatching checksum: " + Integer.toHexString(actualChecksum) + " (expected: " + Integer.toHexString(expectedChecksum) + ')');
        }
    }

    static int maskChecksum(int checksum) {
        return ((checksum >> 15) | (checksum << 17)) - 1568478504;
    }
}
