package io.netty.handler.codec.dns;

import io.netty.channel.AddressedEnvelope;
import io.netty.util.internal.StringUtil;
import java.net.SocketAddress;
/* loaded from: classes.dex */
final class DnsMessageUtil {
    /* JADX INFO: Access modifiers changed from: package-private */
    public static StringBuilder appendQuery(StringBuilder buf, DnsQuery query) {
        appendQueryHeader(buf, query);
        appendAllRecords(buf, query);
        return buf;
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    public static StringBuilder appendResponse(StringBuilder buf, DnsResponse response) {
        appendResponseHeader(buf, response);
        appendAllRecords(buf, response);
        return buf;
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    public static StringBuilder appendRecordClass(StringBuilder buf, int dnsClass) {
        String name;
        int dnsClass2 = 65535 & dnsClass;
        if (dnsClass2 == 1) {
            name = "IN";
        } else if (dnsClass2 == 2) {
            name = "CSNET";
        } else if (dnsClass2 == 3) {
            name = "CHAOS";
        } else if (dnsClass2 == 4) {
            name = "HESIOD";
        } else if (dnsClass2 == 254) {
            name = "NONE";
        } else if (dnsClass2 == 255) {
            name = "ANY";
        } else {
            name = null;
        }
        if (name != null) {
            buf.append(name);
        } else {
            buf.append("UNKNOWN(");
            buf.append(dnsClass2);
            buf.append(')');
        }
        return buf;
    }

    private static void appendQueryHeader(StringBuilder buf, DnsQuery msg) {
        buf.append(StringUtil.simpleClassName(msg));
        buf.append('(');
        StringBuilder appendAddresses = appendAddresses(buf, msg);
        appendAddresses.append(msg.id());
        appendAddresses.append(", ");
        appendAddresses.append(msg.opCode());
        if (msg.isRecursionDesired()) {
            buf.append(", RD");
        }
        if (msg.z() != 0) {
            buf.append(", Z: ");
            buf.append(msg.z());
        }
        buf.append(')');
    }

    private static void appendResponseHeader(StringBuilder buf, DnsResponse msg) {
        buf.append(StringUtil.simpleClassName(msg));
        buf.append('(');
        StringBuilder appendAddresses = appendAddresses(buf, msg);
        appendAddresses.append(msg.id());
        appendAddresses.append(", ");
        appendAddresses.append(msg.opCode());
        appendAddresses.append(", ");
        appendAddresses.append(msg.code());
        appendAddresses.append(StringUtil.COMMA);
        boolean hasComma = true;
        if (msg.isRecursionDesired()) {
            hasComma = false;
            buf.append(" RD");
        }
        if (msg.isAuthoritativeAnswer()) {
            hasComma = false;
            buf.append(" AA");
        }
        if (msg.isTruncated()) {
            hasComma = false;
            buf.append(" TC");
        }
        if (msg.isRecursionAvailable()) {
            hasComma = false;
            buf.append(" RA");
        }
        if (msg.z() != 0) {
            if (!hasComma) {
                buf.append(StringUtil.COMMA);
            }
            buf.append(" Z: ");
            buf.append(msg.z());
        }
        if (hasComma) {
            buf.setCharAt(buf.length() - 1, ')');
        } else {
            buf.append(')');
        }
    }

    private static StringBuilder appendAddresses(StringBuilder buf, DnsMessage msg) {
        if (!(msg instanceof AddressedEnvelope)) {
            return buf;
        }
        AddressedEnvelope<?, SocketAddress> envelope = (AddressedEnvelope) msg;
        SocketAddress addr = envelope.sender();
        if (addr != null) {
            buf.append("from: ");
            buf.append(addr);
            buf.append(", ");
        }
        SocketAddress addr2 = envelope.recipient();
        if (addr2 != null) {
            buf.append("to: ");
            buf.append(addr2);
            buf.append(", ");
        }
        return buf;
    }

    private static void appendAllRecords(StringBuilder buf, DnsMessage msg) {
        appendRecords(buf, msg, DnsSection.QUESTION);
        appendRecords(buf, msg, DnsSection.ANSWER);
        appendRecords(buf, msg, DnsSection.AUTHORITY);
        appendRecords(buf, msg, DnsSection.ADDITIONAL);
    }

    private static void appendRecords(StringBuilder buf, DnsMessage message, DnsSection section) {
        int count = message.count(section);
        for (int i = 0; i < count; i++) {
            buf.append(StringUtil.NEWLINE);
            buf.append('\t');
            buf.append(message.recordAt(section, i));
        }
    }

    private DnsMessageUtil() {
    }
}
