package io.netty.handler.codec.haproxy;

import io.netty.handler.codec.memcache.binary.BinaryMemcacheOpcodes;
import kotlin.UByte;
/* loaded from: classes.dex */
public enum HAProxyProxiedProtocol {
    UNKNOWN((byte) 0, AddressFamily.AF_UNSPEC, TransportProtocol.UNSPEC),
    TCP4(BinaryMemcacheOpcodes.SETQ, AddressFamily.AF_IPv4, TransportProtocol.STREAM),
    TCP6(BinaryMemcacheOpcodes.SASL_AUTH, AddressFamily.AF_IPv6, TransportProtocol.STREAM),
    UDP4(BinaryMemcacheOpcodes.ADDQ, AddressFamily.AF_IPv4, TransportProtocol.DGRAM),
    UDP6((byte) 34, AddressFamily.AF_IPv6, TransportProtocol.DGRAM),
    UNIX_STREAM((byte) 49, AddressFamily.AF_UNIX, TransportProtocol.STREAM),
    UNIX_DGRAM((byte) 50, AddressFamily.AF_UNIX, TransportProtocol.DGRAM);
    
    private final AddressFamily addressFamily;
    private final byte byteValue;
    private final TransportProtocol transportProtocol;

    HAProxyProxiedProtocol(byte byteValue, AddressFamily addressFamily, TransportProtocol transportProtocol) {
        this.byteValue = byteValue;
        this.addressFamily = addressFamily;
        this.transportProtocol = transportProtocol;
    }

    public static HAProxyProxiedProtocol valueOf(byte tpafByte) {
        if (tpafByte != 0) {
            if (tpafByte != 17) {
                if (tpafByte != 18) {
                    if (tpafByte != 33) {
                        if (tpafByte != 34) {
                            if (tpafByte != 49) {
                                if (tpafByte == 50) {
                                    return UNIX_DGRAM;
                                }
                                throw new IllegalArgumentException("unknown transport protocol + address family: " + (tpafByte & UByte.MAX_VALUE));
                            }
                            return UNIX_STREAM;
                        }
                        return UDP6;
                    }
                    return TCP6;
                }
                return UDP4;
            }
            return TCP4;
        }
        return UNKNOWN;
    }

    public byte byteValue() {
        return this.byteValue;
    }

    public AddressFamily addressFamily() {
        return this.addressFamily;
    }

    public TransportProtocol transportProtocol() {
        return this.transportProtocol;
    }

    /* loaded from: classes.dex */
    public enum AddressFamily {
        AF_UNSPEC((byte) 0),
        AF_IPv4(BinaryMemcacheOpcodes.STAT),
        AF_IPv6((byte) 32),
        AF_UNIX((byte) 48);
        
        private static final byte FAMILY_MASK = -16;
        private final byte byteValue;

        AddressFamily(byte byteValue) {
            this.byteValue = byteValue;
        }

        public static AddressFamily valueOf(byte tpafByte) {
            int addressFamily = tpafByte & FAMILY_MASK;
            byte b = (byte) addressFamily;
            if (b != 0) {
                if (b != 16) {
                    if (b != 32) {
                        if (b == 48) {
                            return AF_UNIX;
                        }
                        throw new IllegalArgumentException("unknown address family: " + addressFamily);
                    }
                    return AF_IPv6;
                }
                return AF_IPv4;
            }
            return AF_UNSPEC;
        }

        public byte byteValue() {
            return this.byteValue;
        }
    }

    /* loaded from: classes.dex */
    public enum TransportProtocol {
        UNSPEC((byte) 0),
        STREAM((byte) 1),
        DGRAM((byte) 2);
        
        private static final byte TRANSPORT_MASK = 15;
        private final byte transportByte;

        TransportProtocol(byte transportByte) {
            this.transportByte = transportByte;
        }

        public static TransportProtocol valueOf(byte tpafByte) {
            int transportProtocol = tpafByte & 15;
            byte b = (byte) transportProtocol;
            if (b != 0) {
                if (b != 1) {
                    if (b == 2) {
                        return DGRAM;
                    }
                    throw new IllegalArgumentException("unknown transport protocol: " + transportProtocol);
                }
                return STREAM;
            }
            return UNSPEC;
        }

        public byte byteValue() {
            return this.transportByte;
        }
    }
}
