package io.netty.handler.codec.http;

import io.netty.handler.codec.DateFormatter;
import io.netty.handler.codec.http.cookie.CookieHeaderNames;
import io.netty.util.internal.logging.InternalLogger;
import io.netty.util.internal.logging.InternalLoggerFactory;
import java.util.ArrayList;
import java.util.Collections;
import java.util.Date;
import java.util.List;
import java.util.Set;
import java.util.TreeSet;
@Deprecated
/* loaded from: classes.dex */
public final class CookieDecoder {
    private static final String COMMENT = "Comment";
    private static final String COMMENTURL = "CommentURL";
    private static final String DISCARD = "Discard";
    private static final String PORT = "Port";
    private static final String VERSION = "Version";
    private final InternalLogger logger = InternalLoggerFactory.getInstance(getClass());
    private final boolean strict;
    private static final CookieDecoder STRICT = new CookieDecoder(true);
    private static final CookieDecoder LAX = new CookieDecoder(false);

    public static Set<Cookie> decode(String header) {
        return decode(header, true);
    }

    public static Set<Cookie> decode(String header, boolean strict) {
        return (strict ? STRICT : LAX).doDecode(header);
    }

    private Set<Cookie> doDecode(String header) {
        int i;
        boolean discard;
        List<String> values;
        String commentURL;
        String domain;
        boolean httpOnly;
        String commentURL2;
        String domain2;
        List<String> names = new ArrayList<>(8);
        List<String> values2 = new ArrayList<>(8);
        extractKeyValuePairs(header, names, values2);
        if (names.isEmpty()) {
            return Collections.emptySet();
        }
        int i2 = 0;
        if (names.get(0).equalsIgnoreCase(VERSION)) {
            try {
                int version = Integer.parseInt(values2.get(0));
                i2 = version;
            } catch (NumberFormatException e) {
            }
            i = 1;
        } else {
            i = 0;
        }
        if (names.size() <= i) {
            return Collections.emptySet();
        }
        Set<Cookie> cookies = new TreeSet<>();
        while (i < names.size()) {
            String name = names.get(i);
            String value = values2.get(i);
            if (value == null) {
                value = "";
            }
            Cookie c = initCookie(name, value);
            if (c == null) {
                return cookies;
            }
            boolean discard2 = false;
            boolean secure = false;
            List<Integer> ports = new ArrayList<>(2);
            int i3 = i + 1;
            String domain3 = null;
            Set<Cookie> cookies2 = cookies;
            String path = null;
            boolean httpOnly2 = false;
            int i4 = i2;
            int version2 = i;
            String name2 = name;
            int j = i3;
            int version3 = i4;
            String value2 = value;
            String value3 = null;
            String comment = null;
            long maxAge = Long.MIN_VALUE;
            while (true) {
                discard = discard2;
                if (j >= names.size()) {
                    values = values2;
                    commentURL = value3;
                    domain = domain3;
                    break;
                }
                String name3 = names.get(j);
                values = values2;
                String value4 = values2.get(j);
                if (DISCARD.equalsIgnoreCase(name3)) {
                    discard = true;
                    value2 = value4;
                } else if (CookieHeaderNames.SECURE.equalsIgnoreCase(name3)) {
                    secure = true;
                    value2 = value4;
                } else if (CookieHeaderNames.HTTPONLY.equalsIgnoreCase(name3)) {
                    httpOnly2 = true;
                    value2 = value4;
                } else if (COMMENT.equalsIgnoreCase(name3)) {
                    comment = value4;
                    value2 = value4;
                } else if (COMMENTURL.equalsIgnoreCase(name3)) {
                    value3 = value4;
                    value2 = value4;
                } else if (CookieHeaderNames.DOMAIN.equalsIgnoreCase(name3)) {
                    domain3 = value4;
                    value2 = value4;
                } else if (CookieHeaderNames.PATH.equalsIgnoreCase(name3)) {
                    path = value4;
                    value2 = value4;
                } else if (!"Expires".equalsIgnoreCase(name3)) {
                    commentURL = value3;
                    domain = domain3;
                    if (CookieHeaderNames.MAX_AGE.equalsIgnoreCase(name3)) {
                        value2 = value4;
                        maxAge = Integer.parseInt(value4);
                        value3 = commentURL;
                        domain3 = domain;
                    } else if (VERSION.equalsIgnoreCase(name3)) {
                        version3 = Integer.parseInt(value4);
                        value2 = value4;
                        value3 = commentURL;
                        domain3 = domain;
                    } else if (!PORT.equalsIgnoreCase(name3)) {
                        break;
                    } else {
                        String[] portList = value4.split(",");
                        value2 = value4;
                        for (String s1 : portList) {
                            try {
                                ports.add(Integer.valueOf(s1));
                            } catch (NumberFormatException e2) {
                            }
                        }
                        value3 = commentURL;
                        domain3 = domain;
                    }
                } else {
                    Date date = DateFormatter.parseHttpDate(value4);
                    if (date != null) {
                        long maxAgeMillis = date.getTime() - System.currentTimeMillis();
                        commentURL2 = value3;
                        domain2 = domain3;
                        maxAge = (maxAgeMillis / 1000) + (maxAgeMillis % 1000 != 0 ? 1 : 0);
                    } else {
                        commentURL2 = value3;
                        domain2 = domain3;
                    }
                    value2 = value4;
                    value3 = commentURL2;
                    domain3 = domain2;
                }
                j++;
                version2++;
                name2 = name3;
                discard2 = discard;
                values2 = values;
            }
            c.setVersion(version3);
            c.setMaxAge(maxAge);
            c.setPath(path);
            c.setDomain(domain);
            c.setSecure(secure);
            c.setHttpOnly(httpOnly2);
            if (version3 > 0) {
                c.setComment(comment);
            }
            if (version3 > 1) {
                c.setCommentUrl(commentURL);
                c.setPorts(ports);
                httpOnly = discard;
                c.setDiscard(httpOnly);
            } else {
                httpOnly = discard;
            }
            cookies2.add(c);
            i = version2 + 1;
            cookies = cookies2;
            i2 = version3;
            values2 = values;
        }
        return cookies;
    }

    private static void extractKeyValuePairs(String header, List<String> names, List<String> values) {
        String name;
        String name2;
        int headerLen = header.length();
        int i = 0;
        while (i != headerLen) {
            char charAt = header.charAt(i);
            if (charAt != ' ' && charAt != ',' && charAt != ';') {
                switch (charAt) {
                    case '\t':
                    case '\n':
                    case 11:
                    case '\f':
                    case '\r':
                        break;
                    default:
                        while (i != headerLen) {
                            if (header.charAt(i) == '$') {
                                i++;
                            } else {
                                if (i == headerLen) {
                                    name = null;
                                    name2 = null;
                                } else {
                                    int newNameStart = i;
                                    while (true) {
                                        char charAt2 = header.charAt(i);
                                        if (charAt2 == ';') {
                                            String name3 = header.substring(newNameStart, i);
                                            name = name3;
                                            name2 = null;
                                        } else if (charAt2 == '=') {
                                            String name4 = header.substring(newNameStart, i);
                                            i++;
                                            if (i == headerLen) {
                                                name2 = "";
                                                name = name4;
                                            } else {
                                                char c = header.charAt(i);
                                                if (c == '\"' || c == '\'') {
                                                    StringBuilder newValueBuf = new StringBuilder(header.length() - i);
                                                    boolean hadBackslash = false;
                                                    i++;
                                                    while (true) {
                                                        if (i == headerLen) {
                                                            String value = newValueBuf.toString();
                                                            name = name4;
                                                            name2 = value;
                                                        } else if (hadBackslash) {
                                                            hadBackslash = false;
                                                            int i2 = i + 1;
                                                            char c2 = header.charAt(i);
                                                            if (c2 == '\"' || c2 == '\'' || c2 == '\\') {
                                                                newValueBuf.setCharAt(newValueBuf.length() - 1, c2);
                                                            } else {
                                                                newValueBuf.append(c2);
                                                            }
                                                            i = i2;
                                                        } else {
                                                            int i3 = i + 1;
                                                            char c3 = header.charAt(i);
                                                            if (c3 == c) {
                                                                String value2 = newValueBuf.toString();
                                                                name2 = value2;
                                                                name = name4;
                                                                i = i3;
                                                            } else {
                                                                newValueBuf.append(c3);
                                                                if (c3 != '\\') {
                                                                    i = i3;
                                                                } else {
                                                                    hadBackslash = true;
                                                                    i = i3;
                                                                }
                                                            }
                                                        }
                                                    }
                                                } else {
                                                    int semiPos = header.indexOf(59, i);
                                                    if (semiPos > 0) {
                                                        String value3 = header.substring(i, semiPos);
                                                        i = semiPos;
                                                        name2 = value3;
                                                    } else {
                                                        String value4 = header.substring(i);
                                                        i = headerLen;
                                                        name2 = value4;
                                                    }
                                                    name = name4;
                                                }
                                            }
                                        } else {
                                            i++;
                                            if (i == headerLen) {
                                                String name5 = header.substring(newNameStart);
                                                name = name5;
                                                name2 = null;
                                            }
                                        }
                                    }
                                }
                                names.add(name);
                                values.add(name2);
                                continue;
                            }
                        }
                        return;
                }
            }
            i++;
        }
    }

    private CookieDecoder(boolean strict) {
        this.strict = strict;
    }

    private DefaultCookie initCookie(String name, String value) {
        int invalidOctetPos;
        int invalidOctetPos2;
        if (name == null || name.length() == 0) {
            this.logger.debug("Skipping cookie with null name");
            return null;
        } else if (value == null) {
            this.logger.debug("Skipping cookie with null value");
            return null;
        } else {
            CharSequence unwrappedValue = CookieUtil.unwrapValue(value);
            if (unwrappedValue == null) {
                this.logger.debug("Skipping cookie because starting quotes are not properly balanced in '{}'", unwrappedValue);
                return null;
            } else if (this.strict && (invalidOctetPos2 = CookieUtil.firstInvalidCookieNameOctet(name)) >= 0) {
                if (this.logger.isDebugEnabled()) {
                    this.logger.debug("Skipping cookie because name '{}' contains invalid char '{}'", name, Character.valueOf(name.charAt(invalidOctetPos2)));
                }
                return null;
            } else {
                boolean wrap = unwrappedValue.length() != value.length();
                if (this.strict && (invalidOctetPos = CookieUtil.firstInvalidCookieValueOctet(unwrappedValue)) >= 0) {
                    if (this.logger.isDebugEnabled()) {
                        this.logger.debug("Skipping cookie because value '{}' contains invalid char '{}'", unwrappedValue, Character.valueOf(unwrappedValue.charAt(invalidOctetPos)));
                    }
                    return null;
                }
                DefaultCookie cookie = new DefaultCookie(name, unwrappedValue.toString());
                cookie.setWrap(wrap);
                return cookie;
            }
        }
    }
}
