package io.netty.handler.codec.http;

import io.netty.buffer.ByteBuf;
import io.netty.buffer.Unpooled;
import io.netty.channel.ChannelHandlerContext;
import io.netty.handler.codec.ByteToMessageDecoder;
import io.netty.handler.codec.DecoderResult;
import io.netty.handler.codec.PrematureChannelClosureException;
import io.netty.handler.codec.TooLongFrameException;
import io.netty.util.ByteProcessor;
import io.netty.util.internal.AppendableCharSequence;
import io.netty.util.internal.ObjectUtil;
import java.util.List;
import kotlin.UByte;
/* loaded from: classes.dex */
public abstract class HttpObjectDecoder extends ByteToMessageDecoder {
    static final /* synthetic */ boolean $assertionsDisabled = false;
    private static final String EMPTY_VALUE = "";
    private long chunkSize;
    private final boolean chunkedSupported;
    private long contentLength;
    private State currentState;
    private final HeaderParser headerParser;
    private final LineParser lineParser;
    private final int maxChunkSize;
    private HttpMessage message;
    private CharSequence name;
    private volatile boolean resetRequested;
    private LastHttpContent trailer;
    protected final boolean validateHeaders;
    private CharSequence value;

    /* JADX INFO: Access modifiers changed from: private */
    /* loaded from: classes.dex */
    public enum State {
        SKIP_CONTROL_CHARS,
        READ_INITIAL,
        READ_HEADER,
        READ_VARIABLE_LENGTH_CONTENT,
        READ_FIXED_LENGTH_CONTENT,
        READ_CHUNK_SIZE,
        READ_CHUNKED_CONTENT,
        READ_CHUNK_DELIMITER,
        READ_CHUNK_FOOTER,
        BAD_MESSAGE,
        UPGRADED
    }

    protected abstract HttpMessage createInvalidMessage();

    protected abstract HttpMessage createMessage(String[] strArr) throws Exception;

    protected abstract boolean isDecodingRequest();

    /* JADX INFO: Access modifiers changed from: protected */
    public HttpObjectDecoder() {
        this(4096, 8192, 8192, true);
    }

    /* JADX INFO: Access modifiers changed from: protected */
    public HttpObjectDecoder(int maxInitialLineLength, int maxHeaderSize, int maxChunkSize, boolean chunkedSupported) {
        this(maxInitialLineLength, maxHeaderSize, maxChunkSize, chunkedSupported, true);
    }

    /* JADX INFO: Access modifiers changed from: protected */
    public HttpObjectDecoder(int maxInitialLineLength, int maxHeaderSize, int maxChunkSize, boolean chunkedSupported, boolean validateHeaders) {
        this(maxInitialLineLength, maxHeaderSize, maxChunkSize, chunkedSupported, validateHeaders, 128);
    }

    /* JADX INFO: Access modifiers changed from: protected */
    public HttpObjectDecoder(int maxInitialLineLength, int maxHeaderSize, int maxChunkSize, boolean chunkedSupported, boolean validateHeaders, int initialBufferSize) {
        this.contentLength = Long.MIN_VALUE;
        this.currentState = State.SKIP_CONTROL_CHARS;
        ObjectUtil.checkPositive(maxInitialLineLength, "maxInitialLineLength");
        ObjectUtil.checkPositive(maxHeaderSize, "maxHeaderSize");
        ObjectUtil.checkPositive(maxChunkSize, "maxChunkSize");
        AppendableCharSequence seq = new AppendableCharSequence(initialBufferSize);
        this.lineParser = new LineParser(seq, maxInitialLineLength);
        this.headerParser = new HeaderParser(seq, maxHeaderSize);
        this.maxChunkSize = maxChunkSize;
        this.chunkedSupported = chunkedSupported;
        this.validateHeaders = validateHeaders;
    }

    /* JADX INFO: Access modifiers changed from: protected */
    /* JADX WARN: Removed duplicated region for block: B:113:0x0108 A[SYNTHETIC] */
    /* JADX WARN: Removed duplicated region for block: B:45:0x00ce A[RETURN] */
    /* JADX WARN: Removed duplicated region for block: B:46:0x00cf  */
    /* JADX WARN: Removed duplicated region for block: B:52:0x00f6  */
    /* JADX WARN: Removed duplicated region for block: B:67:0x0128 A[RETURN] */
    /* JADX WARN: Removed duplicated region for block: B:68:0x0129 A[Catch: Exception -> 0x01b1, TryCatch #3 {Exception -> 0x01b1, blocks: (B:65:0x0120, B:68:0x0129, B:70:0x0131, B:72:0x0136), top: B:112:0x0120 }] */
    /* JADX WARN: Removed duplicated region for block: B:75:0x0147 A[RETURN] */
    /* JADX WARN: Removed duplicated region for block: B:76:0x0148 A[Catch: Exception -> 0x01a8, TryCatch #2 {Exception -> 0x01a8, blocks: (B:73:0x0141, B:76:0x0148, B:80:0x0158, B:84:0x0166, B:87:0x016d, B:89:0x0177, B:91:0x017a, B:93:0x0188, B:95:0x018c, B:97:0x0192, B:98:0x0199, B:99:0x019a), top: B:111:0x0141 }] */
    @Override // io.netty.handler.codec.ByteToMessageDecoder
    /*
        Code decompiled incorrectly, please refer to instructions dump.
    */
    public void decode(ChannelHandlerContext ctx, ByteBuf buffer, List<Object> out) throws Exception {
        AppendableCharSequence line;
        State nextState;
        int wIdx;
        int rIdx;
        int rIdx2;
        int toRead;
        if (this.resetRequested) {
            resetNow();
        }
        switch (AnonymousClass1.$SwitchMap$io$netty$handler$codec$http$HttpObjectDecoder$State[this.currentState.ordinal()]) {
            case 1:
                if (!skipControlCharacters(buffer)) {
                    return;
                }
                this.currentState = State.READ_INITIAL;
                try {
                    line = this.lineParser.parse(buffer);
                    if (line != null) {
                        return;
                    }
                    String[] initialLine = splitInitialLine(line);
                    if (initialLine.length < 3) {
                        this.currentState = State.SKIP_CONTROL_CHARS;
                        return;
                    }
                    this.message = createMessage(initialLine);
                    this.currentState = State.READ_HEADER;
                    try {
                        nextState = readHeaders(buffer);
                        if (nextState != null) {
                            return;
                        }
                        this.currentState = nextState;
                        int i = AnonymousClass1.$SwitchMap$io$netty$handler$codec$http$HttpObjectDecoder$State[nextState.ordinal()];
                        if (i == 1) {
                            out.add(this.message);
                            out.add(LastHttpContent.EMPTY_LAST_CONTENT);
                            resetNow();
                            return;
                        } else if (i == 2) {
                            if (!this.chunkedSupported) {
                                throw new IllegalArgumentException("Chunked messages not supported");
                            }
                            out.add(this.message);
                            return;
                        } else {
                            long contentLength = contentLength();
                            if (contentLength != 0 && (contentLength != -1 || !isDecodingRequest())) {
                                out.add(this.message);
                                if (nextState == State.READ_FIXED_LENGTH_CONTENT) {
                                    this.chunkSize = contentLength;
                                    return;
                                }
                                return;
                            }
                            out.add(this.message);
                            out.add(LastHttpContent.EMPTY_LAST_CONTENT);
                            resetNow();
                            return;
                        }
                    } catch (Exception e) {
                        out.add(invalidMessage(buffer, e));
                        return;
                    }
                } catch (Exception e2) {
                    out.add(invalidMessage(buffer, e2));
                    return;
                }
            case 2:
                try {
                    AppendableCharSequence line2 = this.lineParser.parse(buffer);
                    if (line2 == null) {
                        return;
                    }
                    int chunkSize = getChunkSize(line2.toString());
                    this.chunkSize = chunkSize;
                    if (chunkSize == 0) {
                        this.currentState = State.READ_CHUNK_FOOTER;
                        return;
                    }
                    this.currentState = State.READ_CHUNKED_CONTENT;
                    toRead = Math.min(Math.min((int) this.chunkSize, this.maxChunkSize), buffer.readableBytes());
                    if (toRead != 0) {
                        return;
                    }
                    HttpContent chunk = new DefaultHttpContent(buffer.readRetainedSlice(toRead));
                    this.chunkSize -= toRead;
                    out.add(chunk);
                    if (this.chunkSize != 0) {
                        return;
                    }
                    this.currentState = State.READ_CHUNK_DELIMITER;
                    wIdx = buffer.writerIndex();
                    rIdx = buffer.readerIndex();
                    while (true) {
                        if (wIdx <= rIdx) {
                            rIdx2 = rIdx + 1;
                            byte next = buffer.getByte(rIdx);
                            if (next == 10) {
                                this.currentState = State.READ_CHUNK_SIZE;
                                rIdx = rIdx2;
                            } else {
                                rIdx = rIdx2;
                            }
                        }
                    }
                    buffer.readerIndex(rIdx);
                    return;
                } catch (Exception e3) {
                    out.add(invalidChunk(buffer, e3));
                    return;
                }
            case 3:
                line = this.lineParser.parse(buffer);
                if (line != null) {
                }
                break;
            case 4:
                nextState = readHeaders(buffer);
                if (nextState != null) {
                }
                break;
            case 5:
                int toRead2 = Math.min(buffer.readableBytes(), this.maxChunkSize);
                if (toRead2 > 0) {
                    out.add(new DefaultHttpContent(buffer.readRetainedSlice(toRead2)));
                    return;
                }
                return;
            case 6:
                int readLimit = buffer.readableBytes();
                if (readLimit == 0) {
                    return;
                }
                int toRead3 = Math.min(readLimit, this.maxChunkSize);
                long j = this.chunkSize;
                if (toRead3 > j) {
                    toRead3 = (int) j;
                }
                ByteBuf content = buffer.readRetainedSlice(toRead3);
                long j2 = this.chunkSize - toRead3;
                this.chunkSize = j2;
                if (j2 == 0) {
                    out.add(new DefaultLastHttpContent(content, this.validateHeaders));
                    resetNow();
                    return;
                }
                out.add(new DefaultHttpContent(content));
                return;
            case 7:
                toRead = Math.min(Math.min((int) this.chunkSize, this.maxChunkSize), buffer.readableBytes());
                if (toRead != 0) {
                }
                break;
            case 8:
                wIdx = buffer.writerIndex();
                rIdx = buffer.readerIndex();
                while (true) {
                    if (wIdx <= rIdx) {
                    }
                    rIdx = rIdx2;
                }
                buffer.readerIndex(rIdx);
                return;
            case 9:
                try {
                    LastHttpContent trailer = readTrailingHeaders(buffer);
                    if (trailer == null) {
                        return;
                    }
                    out.add(trailer);
                    resetNow();
                    return;
                } catch (Exception e4) {
                    out.add(invalidChunk(buffer, e4));
                    return;
                }
            case 10:
                buffer.skipBytes(buffer.readableBytes());
                return;
            case 11:
                int readableBytes = buffer.readableBytes();
                if (readableBytes > 0) {
                    out.add(buffer.readBytes(readableBytes));
                    return;
                }
                return;
            default:
                return;
        }
    }

    /* renamed from: io.netty.handler.codec.http.HttpObjectDecoder$1  reason: invalid class name */
    /* loaded from: classes.dex */
    static /* synthetic */ class AnonymousClass1 {
        static final /* synthetic */ int[] $SwitchMap$io$netty$handler$codec$http$HttpObjectDecoder$State;

        static {
            int[] iArr = new int[State.values().length];
            $SwitchMap$io$netty$handler$codec$http$HttpObjectDecoder$State = iArr;
            try {
                iArr[State.SKIP_CONTROL_CHARS.ordinal()] = 1;
            } catch (NoSuchFieldError e) {
            }
            try {
                $SwitchMap$io$netty$handler$codec$http$HttpObjectDecoder$State[State.READ_CHUNK_SIZE.ordinal()] = 2;
            } catch (NoSuchFieldError e2) {
            }
            try {
                $SwitchMap$io$netty$handler$codec$http$HttpObjectDecoder$State[State.READ_INITIAL.ordinal()] = 3;
            } catch (NoSuchFieldError e3) {
            }
            try {
                $SwitchMap$io$netty$handler$codec$http$HttpObjectDecoder$State[State.READ_HEADER.ordinal()] = 4;
            } catch (NoSuchFieldError e4) {
            }
            try {
                $SwitchMap$io$netty$handler$codec$http$HttpObjectDecoder$State[State.READ_VARIABLE_LENGTH_CONTENT.ordinal()] = 5;
            } catch (NoSuchFieldError e5) {
            }
            try {
                $SwitchMap$io$netty$handler$codec$http$HttpObjectDecoder$State[State.READ_FIXED_LENGTH_CONTENT.ordinal()] = 6;
            } catch (NoSuchFieldError e6) {
            }
            try {
                $SwitchMap$io$netty$handler$codec$http$HttpObjectDecoder$State[State.READ_CHUNKED_CONTENT.ordinal()] = 7;
            } catch (NoSuchFieldError e7) {
            }
            try {
                $SwitchMap$io$netty$handler$codec$http$HttpObjectDecoder$State[State.READ_CHUNK_DELIMITER.ordinal()] = 8;
            } catch (NoSuchFieldError e8) {
            }
            try {
                $SwitchMap$io$netty$handler$codec$http$HttpObjectDecoder$State[State.READ_CHUNK_FOOTER.ordinal()] = 9;
            } catch (NoSuchFieldError e9) {
            }
            try {
                $SwitchMap$io$netty$handler$codec$http$HttpObjectDecoder$State[State.BAD_MESSAGE.ordinal()] = 10;
            } catch (NoSuchFieldError e10) {
            }
            try {
                $SwitchMap$io$netty$handler$codec$http$HttpObjectDecoder$State[State.UPGRADED.ordinal()] = 11;
            } catch (NoSuchFieldError e11) {
            }
        }
    }

    /* JADX INFO: Access modifiers changed from: protected */
    @Override // io.netty.handler.codec.ByteToMessageDecoder
    public void decodeLast(ChannelHandlerContext ctx, ByteBuf in, List<Object> out) throws Exception {
        boolean prematureClosure;
        super.decodeLast(ctx, in, out);
        if (this.resetRequested) {
            resetNow();
        }
        HttpMessage httpMessage = this.message;
        if (httpMessage != null) {
            boolean chunked = HttpUtil.isTransferEncodingChunked(httpMessage);
            if (this.currentState == State.READ_VARIABLE_LENGTH_CONTENT && !in.isReadable() && !chunked) {
                out.add(LastHttpContent.EMPTY_LAST_CONTENT);
                resetNow();
            } else if (this.currentState == State.READ_HEADER) {
                out.add(invalidMessage(Unpooled.EMPTY_BUFFER, new PrematureChannelClosureException("Connection closed before received headers")));
                resetNow();
            } else {
                if (isDecodingRequest() || chunked) {
                    prematureClosure = true;
                } else {
                    prematureClosure = contentLength() > 0;
                }
                if (!prematureClosure) {
                    out.add(LastHttpContent.EMPTY_LAST_CONTENT);
                }
                resetNow();
            }
        }
    }

    @Override // io.netty.handler.codec.ByteToMessageDecoder, io.netty.channel.ChannelInboundHandlerAdapter, io.netty.channel.ChannelInboundHandler
    public void userEventTriggered(ChannelHandlerContext ctx, Object evt) throws Exception {
        int i;
        if ((evt instanceof HttpExpectationFailedEvent) && ((i = AnonymousClass1.$SwitchMap$io$netty$handler$codec$http$HttpObjectDecoder$State[this.currentState.ordinal()]) == 2 || i == 5 || i == 6)) {
            reset();
        }
        super.userEventTriggered(ctx, evt);
    }

    /* JADX INFO: Access modifiers changed from: protected */
    public boolean isContentAlwaysEmpty(HttpMessage msg) {
        if (msg instanceof HttpResponse) {
            HttpResponse res = (HttpResponse) msg;
            int code = res.status().code();
            if (code >= 100 && code < 200) {
                return (code == 101 && !res.headers().contains(HttpHeaderNames.SEC_WEBSOCKET_ACCEPT) && res.headers().contains((CharSequence) HttpHeaderNames.UPGRADE, (CharSequence) HttpHeaderValues.WEBSOCKET, true)) ? false : true;
            } else if (code == 204 || code == 304) {
                return true;
            }
        }
        return false;
    }

    protected boolean isSwitchingToNonHttp1Protocol(HttpResponse msg) {
        if (msg.status().code() != HttpResponseStatus.SWITCHING_PROTOCOLS.code()) {
            return false;
        }
        String newProtocol = msg.headers().get(HttpHeaderNames.UPGRADE);
        return newProtocol == null || !(newProtocol.contains(HttpVersion.HTTP_1_0.text()) || newProtocol.contains(HttpVersion.HTTP_1_1.text()));
    }

    public void reset() {
        this.resetRequested = true;
    }

    private void resetNow() {
        HttpResponse res;
        HttpMessage message = this.message;
        this.message = null;
        this.name = null;
        this.value = null;
        this.contentLength = Long.MIN_VALUE;
        this.lineParser.reset();
        this.headerParser.reset();
        this.trailer = null;
        if (!isDecodingRequest() && (res = (HttpResponse) message) != null && isSwitchingToNonHttp1Protocol(res)) {
            this.currentState = State.UPGRADED;
            return;
        }
        this.resetRequested = false;
        this.currentState = State.SKIP_CONTROL_CHARS;
    }

    private HttpMessage invalidMessage(ByteBuf in, Exception cause) {
        this.currentState = State.BAD_MESSAGE;
        in.skipBytes(in.readableBytes());
        if (this.message == null) {
            this.message = createInvalidMessage();
        }
        this.message.setDecoderResult(DecoderResult.failure(cause));
        HttpMessage ret = this.message;
        this.message = null;
        return ret;
    }

    private HttpContent invalidChunk(ByteBuf in, Exception cause) {
        this.currentState = State.BAD_MESSAGE;
        in.skipBytes(in.readableBytes());
        HttpContent chunk = new DefaultLastHttpContent(Unpooled.EMPTY_BUFFER);
        chunk.setDecoderResult(DecoderResult.failure(cause));
        this.message = null;
        this.trailer = null;
        return chunk;
    }

    private static boolean skipControlCharacters(ByteBuf buffer) {
        boolean skiped = false;
        int wIdx = buffer.writerIndex();
        int c = buffer.readerIndex();
        while (true) {
            if (wIdx <= c) {
                break;
            }
            int rIdx = c + 1;
            int c2 = buffer.getUnsignedByte(c);
            if (!Character.isISOControl(c2) && !Character.isWhitespace(c2)) {
                skiped = true;
                c = rIdx - 1;
                break;
            }
            c = rIdx;
        }
        buffer.readerIndex(c);
        return skiped;
    }

    /* JADX WARN: Removed duplicated region for block: B:25:0x0069  */
    /* JADX WARN: Removed duplicated region for block: B:28:0x007e  */
    /* JADX WARN: Removed duplicated region for block: B:38:0x00a4  */
    /* JADX WARN: Removed duplicated region for block: B:40:0x00aa  */
    /*
        Code decompiled incorrectly, please refer to instructions dump.
    */
    private State readHeaders(ByteBuf buffer) {
        CharSequence charSequence;
        int contentLengthValuesCount;
        HttpMessage message = this.message;
        HttpHeaders headers = message.headers();
        AppendableCharSequence line = this.headerParser.parse(buffer);
        if (line == null) {
            return null;
        }
        if (line.length() > 0) {
            do {
                char firstChar = line.charAtUnsafe(0);
                if (this.name != null && (firstChar == ' ' || firstChar == '\t')) {
                    String trimmedLine = line.toString().trim();
                    String valueStr = String.valueOf(this.value);
                    this.value = valueStr + ' ' + trimmedLine;
                } else {
                    CharSequence charSequence2 = this.name;
                    if (charSequence2 != null) {
                        headers.add(charSequence2, this.value);
                    }
                    splitHeader(line);
                }
                line = this.headerParser.parse(buffer);
                if (line == null) {
                    return null;
                }
            } while (line.length() > 0);
            charSequence = this.name;
            if (charSequence != null) {
                headers.add(charSequence, this.value);
            }
            this.name = null;
            this.value = null;
            List<String> values = headers.getAll(HttpHeaderNames.CONTENT_LENGTH);
            contentLengthValuesCount = values.size();
            if (contentLengthValuesCount > 0) {
                if (contentLengthValuesCount > 1 && message.protocolVersion() == HttpVersion.HTTP_1_1) {
                    throw new IllegalArgumentException("Multiple Content-Length headers found");
                }
                this.contentLength = Long.parseLong(values.get(0));
            }
            if (!isContentAlwaysEmpty(message)) {
                HttpUtil.setTransferEncodingChunked(message, false);
                return State.SKIP_CONTROL_CHARS;
            } else if (HttpUtil.isTransferEncodingChunked(message)) {
                if (contentLengthValuesCount > 0 && message.protocolVersion() == HttpVersion.HTTP_1_1) {
                    throw new IllegalArgumentException("Both 'Content-Length: " + this.contentLength + "' and 'Transfer-Encoding: chunked' found");
                }
                return State.READ_CHUNK_SIZE;
            } else if (contentLength() >= 0) {
                return State.READ_FIXED_LENGTH_CONTENT;
            } else {
                return State.READ_VARIABLE_LENGTH_CONTENT;
            }
        }
        charSequence = this.name;
        if (charSequence != null) {
        }
        this.name = null;
        this.value = null;
        List<String> values2 = headers.getAll(HttpHeaderNames.CONTENT_LENGTH);
        contentLengthValuesCount = values2.size();
        if (contentLengthValuesCount > 0) {
        }
        if (!isContentAlwaysEmpty(message)) {
        }
    }

    private long contentLength() {
        if (this.contentLength == Long.MIN_VALUE) {
            this.contentLength = HttpUtil.getContentLength(this.message, -1L);
        }
        return this.contentLength;
    }

    private LastHttpContent readTrailingHeaders(ByteBuf buffer) {
        AppendableCharSequence line = this.headerParser.parse(buffer);
        if (line == null) {
            return null;
        }
        LastHttpContent trailer = this.trailer;
        if (line.length() == 0 && trailer == null) {
            return LastHttpContent.EMPTY_LAST_CONTENT;
        }
        CharSequence lastHeader = null;
        if (trailer == null) {
            DefaultLastHttpContent defaultLastHttpContent = new DefaultLastHttpContent(Unpooled.EMPTY_BUFFER, this.validateHeaders);
            this.trailer = defaultLastHttpContent;
            trailer = defaultLastHttpContent;
        }
        while (line.length() > 0) {
            char firstChar = line.charAtUnsafe(0);
            if (lastHeader != null && (firstChar == ' ' || firstChar == '\t')) {
                List<String> current = trailer.trailingHeaders().getAll(lastHeader);
                if (!current.isEmpty()) {
                    int lastPos = current.size() - 1;
                    String lineTrimmed = line.toString().trim();
                    String currentLastPos = current.get(lastPos);
                    current.set(lastPos, currentLastPos + lineTrimmed);
                }
            } else {
                splitHeader(line);
                CharSequence headerName = this.name;
                if (!HttpHeaderNames.CONTENT_LENGTH.contentEqualsIgnoreCase(headerName) && !HttpHeaderNames.TRANSFER_ENCODING.contentEqualsIgnoreCase(headerName) && !HttpHeaderNames.TRAILER.contentEqualsIgnoreCase(headerName)) {
                    trailer.trailingHeaders().add(headerName, this.value);
                }
                lastHeader = this.name;
                this.name = null;
                this.value = null;
            }
            line = this.headerParser.parse(buffer);
            if (line == null) {
                return null;
            }
        }
        this.trailer = null;
        return trailer;
    }

    private static int getChunkSize(String hex) {
        String hex2 = hex.trim();
        for (int i = 0; i < hex2.length(); i++) {
            char c = hex2.charAt(i);
            if (c == ';' || Character.isWhitespace(c) || Character.isISOControl(c)) {
                hex2 = hex2.substring(0, i);
                break;
            }
        }
        return Integer.parseInt(hex2, 16);
    }

    private static String[] splitInitialLine(AppendableCharSequence sb) {
        int aStart = findNonWhitespace(sb, 0);
        int aEnd = findWhitespace(sb, aStart);
        int bStart = findNonWhitespace(sb, aEnd);
        int bEnd = findWhitespace(sb, bStart);
        int cStart = findNonWhitespace(sb, bEnd);
        int cEnd = findEndOfString(sb);
        String[] strArr = new String[3];
        strArr[0] = sb.subStringUnsafe(aStart, aEnd);
        strArr[1] = sb.subStringUnsafe(bStart, bEnd);
        strArr[2] = cStart < cEnd ? sb.subStringUnsafe(cStart, cEnd) : "";
        return strArr;
    }

    /* JADX WARN: Code restructure failed: missing block: B:14:0x0026, code lost:
        r4 = r2;
     */
    /* JADX WARN: Code restructure failed: missing block: B:15:0x0027, code lost:
        if (r4 >= r0) goto L26;
     */
    /* JADX WARN: Code restructure failed: missing block: B:17:0x002d, code lost:
        if (r8.charAtUnsafe(r4) != ':') goto L16;
     */
    /* JADX WARN: Code restructure failed: missing block: B:18:0x002f, code lost:
        r4 = r4 + 1;
     */
    /* JADX WARN: Code restructure failed: missing block: B:19:0x0032, code lost:
        r4 = r4 + 1;
     */
    /* JADX WARN: Code restructure failed: missing block: B:20:0x0035, code lost:
        r7.name = r8.subStringUnsafe(r1, r2);
        r3 = findNonWhitespace(r8, r4);
     */
    /* JADX WARN: Code restructure failed: missing block: B:21:0x003f, code lost:
        if (r3 != r0) goto L24;
     */
    /* JADX WARN: Code restructure failed: missing block: B:22:0x0041, code lost:
        r7.value = "";
     */
    /* JADX WARN: Code restructure failed: missing block: B:23:0x0046, code lost:
        r5 = findEndOfString(r8);
        r7.value = r8.subStringUnsafe(r3, r5);
     */
    /* JADX WARN: Code restructure failed: missing block: B:24:0x0050, code lost:
        return;
     */
    /* JADX WARN: Code restructure failed: missing block: B:34:?, code lost:
        return;
     */
    /*
        Code decompiled incorrectly, please refer to instructions dump.
    */
    private void splitHeader(AppendableCharSequence sb) {
        char ch;
        int length = sb.length();
        int nameStart = findNonWhitespace(sb, 0);
        int nameEnd = nameStart;
        while (nameEnd < length && (ch = sb.charAtUnsafe(nameEnd)) != ':' && (isDecodingRequest() || !Character.isWhitespace(ch))) {
            nameEnd++;
        }
        throw new IllegalArgumentException("No colon found");
    }

    private static int findNonWhitespace(AppendableCharSequence sb, int offset) {
        for (int result = offset; result < sb.length(); result++) {
            if (!Character.isWhitespace(sb.charAtUnsafe(result))) {
                return result;
            }
        }
        int result2 = sb.length();
        return result2;
    }

    private static int findWhitespace(AppendableCharSequence sb, int offset) {
        for (int result = offset; result < sb.length(); result++) {
            if (Character.isWhitespace(sb.charAtUnsafe(result))) {
                return result;
            }
        }
        int result2 = sb.length();
        return result2;
    }

    private static int findEndOfString(AppendableCharSequence sb) {
        for (int result = sb.length() - 1; result > 0; result--) {
            if (!Character.isWhitespace(sb.charAtUnsafe(result))) {
                return result + 1;
            }
        }
        return 0;
    }

    /* JADX INFO: Access modifiers changed from: private */
    /* loaded from: classes.dex */
    public static class HeaderParser implements ByteProcessor {
        private final int maxLength;
        private final AppendableCharSequence seq;
        private int size;

        HeaderParser(AppendableCharSequence seq, int maxLength) {
            this.seq = seq;
            this.maxLength = maxLength;
        }

        public AppendableCharSequence parse(ByteBuf buffer) {
            int oldSize = this.size;
            this.seq.reset();
            int i = buffer.forEachByte(this);
            if (i == -1) {
                this.size = oldSize;
                return null;
            }
            buffer.readerIndex(i + 1);
            return this.seq;
        }

        public void reset() {
            this.size = 0;
        }

        @Override // io.netty.util.ByteProcessor
        public boolean process(byte value) throws Exception {
            char nextByte = (char) (value & UByte.MAX_VALUE);
            if (nextByte == '\r') {
                return true;
            }
            if (nextByte != '\n') {
                int i = this.size + 1;
                this.size = i;
                int i2 = this.maxLength;
                if (i > i2) {
                    throw newException(i2);
                }
                this.seq.append(nextByte);
                return true;
            }
            return false;
        }

        protected TooLongFrameException newException(int maxLength) {
            return new TooLongFrameException("HTTP header is larger than " + maxLength + " bytes.");
        }
    }

    /* JADX INFO: Access modifiers changed from: private */
    /* loaded from: classes.dex */
    public static final class LineParser extends HeaderParser {
        LineParser(AppendableCharSequence seq, int maxLength) {
            super(seq, maxLength);
        }

        @Override // io.netty.handler.codec.http.HttpObjectDecoder.HeaderParser
        public AppendableCharSequence parse(ByteBuf buffer) {
            reset();
            return super.parse(buffer);
        }

        @Override // io.netty.handler.codec.http.HttpObjectDecoder.HeaderParser
        protected TooLongFrameException newException(int maxLength) {
            return new TooLongFrameException("An HTTP line is larger than " + maxLength + " bytes.");
        }
    }
}
