package io.netty.handler.codec.http;

import io.netty.buffer.ByteBuf;
import io.netty.buffer.ByteBufUtil;
import io.netty.buffer.Unpooled;
import io.netty.channel.ChannelHandlerContext;
import io.netty.channel.FileRegion;
import io.netty.handler.codec.MessageToMessageEncoder;
import io.netty.handler.codec.http.HttpMessage;
import io.netty.util.CharsetUtil;
import io.netty.util.internal.StringUtil;
import java.util.Iterator;
import java.util.List;
import java.util.Map;
/* loaded from: classes.dex */
public abstract class HttpObjectEncoder<H extends HttpMessage> extends MessageToMessageEncoder<Object> {
    static final int CRLF_SHORT = 3338;
    private static final float HEADERS_WEIGHT_HISTORICAL = 0.8f;
    private static final float HEADERS_WEIGHT_NEW = 0.2f;
    private static final int ST_CONTENT_ALWAYS_EMPTY = 3;
    private static final int ST_CONTENT_CHUNK = 2;
    private static final int ST_CONTENT_NON_CHUNK = 1;
    private static final int ST_INIT = 0;
    private static final float TRAILERS_WEIGHT_HISTORICAL = 0.8f;
    private static final float TRAILERS_WEIGHT_NEW = 0.2f;
    private static final int ZERO_CRLF_MEDIUM = 3149066;
    private static final byte[] ZERO_CRLF_CRLF = {48, 13, 10, 13, 10};
    private static final ByteBuf CRLF_BUF = Unpooled.unreleasableBuffer(Unpooled.directBuffer(2).writeByte(13).writeByte(10));
    private static final ByteBuf ZERO_CRLF_CRLF_BUF = Unpooled.unreleasableBuffer(Unpooled.directBuffer(ZERO_CRLF_CRLF.length).writeBytes(ZERO_CRLF_CRLF));
    private int state = 0;
    private float headersEncodedSizeAccumulator = 256.0f;
    private float trailersEncodedSizeAccumulator = 256.0f;

    protected abstract void encodeInitialLine(ByteBuf byteBuf, H h) throws Exception;

    /* JADX INFO: Access modifiers changed from: protected */
    /* JADX WARN: Multi-variable type inference failed */
    /* JADX WARN: Removed duplicated region for block: B:61:0x010a  */
    /* JADX WARN: Removed duplicated region for block: B:62:0x010e  */
    /* JADX WARN: Removed duplicated region for block: B:65:0x0118  */
    /* JADX WARN: Removed duplicated region for block: B:71:? A[RETURN, SYNTHETIC] */
    @Override // io.netty.handler.codec.MessageToMessageEncoder
    /*
        Code decompiled incorrectly, please refer to instructions dump.
    */
    public void encode(ChannelHandlerContext ctx, Object msg, List<Object> out) throws Exception {
        int i;
        ByteBuf buf = null;
        if (msg instanceof HttpMessage) {
            if (this.state != 0) {
                throw new IllegalStateException("unexpected message type: " + StringUtil.simpleClassName(msg) + ", state: " + this.state);
            }
            HttpMessage httpMessage = (HttpMessage) msg;
            buf = ctx.alloc().buffer((int) this.headersEncodedSizeAccumulator);
            encodeInitialLine(buf, httpMessage);
            if (isContentAlwaysEmpty(httpMessage)) {
                i = 3;
            } else {
                i = HttpUtil.isTransferEncodingChunked(httpMessage) ? 2 : 1;
            }
            this.state = i;
            sanitizeHeadersBeforeEncode(httpMessage, i == 3);
            encodeHeaders(httpMessage.headers(), buf);
            ByteBufUtil.writeShortBE(buf, CRLF_SHORT);
            this.headersEncodedSizeAccumulator = (padSizeForAccumulation(buf.readableBytes()) * 0.2f) + (this.headersEncodedSizeAccumulator * 0.8f);
        }
        if (msg instanceof ByteBuf) {
            ByteBuf potentialEmptyBuf = (ByteBuf) msg;
            if (!potentialEmptyBuf.isReadable()) {
                out.add(potentialEmptyBuf.retain());
                return;
            }
        }
        if ((msg instanceof HttpContent) || (msg instanceof ByteBuf) || (msg instanceof FileRegion)) {
            int i2 = this.state;
            if (i2 == 0) {
                throw new IllegalStateException("unexpected message type: " + StringUtil.simpleClassName(msg));
            } else if (i2 == 1) {
                long contentLength = contentLength(msg);
                if (contentLength > 0) {
                    if (buf != null && buf.writableBytes() >= contentLength && (msg instanceof HttpContent)) {
                        buf.writeBytes(((HttpContent) msg).content());
                        out.add(buf);
                    } else {
                        if (buf != null) {
                            out.add(buf);
                        }
                        out.add(encodeAndRetain(msg));
                    }
                    if (msg instanceof LastHttpContent) {
                        this.state = 0;
                    }
                    if (!(msg instanceof LastHttpContent)) {
                    }
                }
                if (buf == null) {
                }
                if (!(msg instanceof LastHttpContent)) {
                }
            } else if (i2 != 2) {
                if (i2 != 3) {
                    throw new Error();
                }
                if (buf == null) {
                    out.add(buf);
                } else {
                    out.add(Unpooled.EMPTY_BUFFER);
                }
                if (!(msg instanceof LastHttpContent)) {
                    this.state = 0;
                }
            } else {
                if (buf != null) {
                    out.add(buf);
                }
                encodeChunkedContent(ctx, msg, contentLength(msg), out);
                if (!(msg instanceof LastHttpContent)) {
                }
            }
        } else if (buf != null) {
            out.add(buf);
        }
    }

    protected void encodeHeaders(HttpHeaders headers, ByteBuf buf) {
        Iterator<Map.Entry<CharSequence, CharSequence>> iter = headers.iteratorCharSequence();
        while (iter.hasNext()) {
            Map.Entry<CharSequence, CharSequence> header = iter.next();
            HttpHeadersEncoder.encoderHeader(header.getKey(), header.getValue(), buf);
        }
    }

    private void encodeChunkedContent(ChannelHandlerContext ctx, Object msg, long contentLength, List<Object> out) {
        if (contentLength > 0) {
            String lengthHex = Long.toHexString(contentLength);
            ByteBuf buf = ctx.alloc().buffer(lengthHex.length() + 2);
            buf.writeCharSequence(lengthHex, CharsetUtil.US_ASCII);
            ByteBufUtil.writeShortBE(buf, CRLF_SHORT);
            out.add(buf);
            out.add(encodeAndRetain(msg));
            out.add(CRLF_BUF.duplicate());
        }
        if (msg instanceof LastHttpContent) {
            HttpHeaders headers = ((LastHttpContent) msg).trailingHeaders();
            if (headers.isEmpty()) {
                out.add(ZERO_CRLF_CRLF_BUF.duplicate());
                return;
            }
            ByteBuf buf2 = ctx.alloc().buffer((int) this.trailersEncodedSizeAccumulator);
            ByteBufUtil.writeMediumBE(buf2, ZERO_CRLF_MEDIUM);
            encodeHeaders(headers, buf2);
            ByteBufUtil.writeShortBE(buf2, CRLF_SHORT);
            this.trailersEncodedSizeAccumulator = (padSizeForAccumulation(buf2.readableBytes()) * 0.2f) + (this.trailersEncodedSizeAccumulator * 0.8f);
            out.add(buf2);
        } else if (contentLength == 0) {
            out.add(encodeAndRetain(msg));
        }
    }

    protected void sanitizeHeadersBeforeEncode(H msg, boolean isAlwaysEmpty) {
    }

    protected boolean isContentAlwaysEmpty(H msg) {
        return false;
    }

    @Override // io.netty.handler.codec.MessageToMessageEncoder
    public boolean acceptOutboundMessage(Object msg) throws Exception {
        return (msg instanceof HttpObject) || (msg instanceof ByteBuf) || (msg instanceof FileRegion);
    }

    private static Object encodeAndRetain(Object msg) {
        if (msg instanceof ByteBuf) {
            return ((ByteBuf) msg).retain();
        }
        if (msg instanceof HttpContent) {
            return ((HttpContent) msg).content().retain();
        }
        if (msg instanceof FileRegion) {
            return ((FileRegion) msg).retain();
        }
        throw new IllegalStateException("unexpected message type: " + StringUtil.simpleClassName(msg));
    }

    private static long contentLength(Object msg) {
        if (msg instanceof HttpContent) {
            return ((HttpContent) msg).content().readableBytes();
        }
        if (msg instanceof ByteBuf) {
            return ((ByteBuf) msg).readableBytes();
        }
        if (msg instanceof FileRegion) {
            return ((FileRegion) msg).count();
        }
        throw new IllegalStateException("unexpected message type: " + StringUtil.simpleClassName(msg));
    }

    private static int padSizeForAccumulation(int readableBytes) {
        return (readableBytes << 2) / 3;
    }

    @Deprecated
    protected static void encodeAscii(String s, ByteBuf buf) {
        buf.writeCharSequence(s, CharsetUtil.US_ASCII);
    }
}
