package io.netty.handler.codec.http.cookie;

import io.netty.util.internal.ObjectUtil;
/* loaded from: classes.dex */
public class DefaultCookie implements Cookie {
    private String domain;
    private boolean httpOnly;
    private long maxAge = Long.MIN_VALUE;
    private final String name;
    private String path;
    private boolean secure;
    private String value;
    private boolean wrap;

    public DefaultCookie(String name, String value) {
        String name2 = ((String) ObjectUtil.checkNotNull(name, "name")).trim();
        if (name2.isEmpty()) {
            throw new IllegalArgumentException("empty name");
        }
        this.name = name2;
        setValue(value);
    }

    @Override // io.netty.handler.codec.http.cookie.Cookie
    public String name() {
        return this.name;
    }

    @Override // io.netty.handler.codec.http.cookie.Cookie
    public String value() {
        return this.value;
    }

    @Override // io.netty.handler.codec.http.cookie.Cookie
    public void setValue(String value) {
        this.value = (String) ObjectUtil.checkNotNull(value, "value");
    }

    @Override // io.netty.handler.codec.http.cookie.Cookie
    public boolean wrap() {
        return this.wrap;
    }

    @Override // io.netty.handler.codec.http.cookie.Cookie
    public void setWrap(boolean wrap) {
        this.wrap = wrap;
    }

    @Override // io.netty.handler.codec.http.cookie.Cookie
    public String domain() {
        return this.domain;
    }

    @Override // io.netty.handler.codec.http.cookie.Cookie
    public void setDomain(String domain) {
        this.domain = CookieUtil.validateAttributeValue("domain", domain);
    }

    @Override // io.netty.handler.codec.http.cookie.Cookie
    public String path() {
        return this.path;
    }

    @Override // io.netty.handler.codec.http.cookie.Cookie
    public void setPath(String path) {
        this.path = CookieUtil.validateAttributeValue("path", path);
    }

    @Override // io.netty.handler.codec.http.cookie.Cookie
    public long maxAge() {
        return this.maxAge;
    }

    @Override // io.netty.handler.codec.http.cookie.Cookie
    public void setMaxAge(long maxAge) {
        this.maxAge = maxAge;
    }

    @Override // io.netty.handler.codec.http.cookie.Cookie
    public boolean isSecure() {
        return this.secure;
    }

    @Override // io.netty.handler.codec.http.cookie.Cookie
    public void setSecure(boolean secure) {
        this.secure = secure;
    }

    @Override // io.netty.handler.codec.http.cookie.Cookie
    public boolean isHttpOnly() {
        return this.httpOnly;
    }

    @Override // io.netty.handler.codec.http.cookie.Cookie
    public void setHttpOnly(boolean httpOnly) {
        this.httpOnly = httpOnly;
    }

    public int hashCode() {
        return name().hashCode();
    }

    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o instanceof Cookie) {
            Cookie that = (Cookie) o;
            if (name().equals(that.name())) {
                if (path() == null) {
                    if (that.path() != null) {
                        return false;
                    }
                } else if (that.path() == null || !path().equals(that.path())) {
                    return false;
                }
                if (domain() == null) {
                    return that.domain() == null;
                }
                return domain().equalsIgnoreCase(that.domain());
            }
            return false;
        }
        return false;
    }

    @Override // java.lang.Comparable
    public int compareTo(Cookie c) {
        int v = name().compareTo(c.name());
        if (v != 0) {
            return v;
        }
        if (path() == null) {
            if (c.path() != null) {
                return -1;
            }
        } else if (c.path() == null) {
            return 1;
        } else {
            int v2 = path().compareTo(c.path());
            if (v2 != 0) {
                return v2;
            }
        }
        if (domain() == null) {
            return c.domain() != null ? -1 : 0;
        } else if (c.domain() == null) {
            return 1;
        } else {
            return domain().compareToIgnoreCase(c.domain());
        }
    }

    /* JADX INFO: Access modifiers changed from: protected */
    @Deprecated
    public String validateValue(String name, String value) {
        return CookieUtil.validateAttributeValue(name, value);
    }

    public String toString() {
        StringBuilder stringBuilder = CookieUtil.stringBuilder();
        stringBuilder.append(name());
        stringBuilder.append('=');
        StringBuilder buf = stringBuilder.append(value());
        if (domain() != null) {
            buf.append(", domain=");
            buf.append(domain());
        }
        if (path() != null) {
            buf.append(", path=");
            buf.append(path());
        }
        if (maxAge() >= 0) {
            buf.append(", maxAge=");
            buf.append(maxAge());
            buf.append('s');
        }
        if (isSecure()) {
            buf.append(", secure");
        }
        if (isHttpOnly()) {
            buf.append(", HTTPOnly");
        }
        return buf.toString();
    }
}
