package io.netty.handler.codec.http.websocketx;

import io.netty.buffer.ByteBuf;
import io.netty.handler.codec.memcache.binary.BinaryMemcacheOpcodes;
import io.netty.util.ByteProcessor;
import kotlin.UByte;
/* loaded from: classes.dex */
final class Utf8Validator implements ByteProcessor {
    private static final int UTF8_ACCEPT = 0;
    private static final int UTF8_REJECT = 12;
    private boolean checking;
    private int codep;
    private int state = 0;
    private static final byte[] TYPES = {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 8, 8, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 10, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 4, 3, 3, BinaryMemcacheOpcodes.VERSION, 6, 6, 6, 5, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8};
    private static final byte[] STATES = {0, BinaryMemcacheOpcodes.GETK, BinaryMemcacheOpcodes.FLUSHQ, BinaryMemcacheOpcodes.GATKQ, 60, 96, 84, BinaryMemcacheOpcodes.GETK, BinaryMemcacheOpcodes.GETK, BinaryMemcacheOpcodes.GETK, 48, 72, BinaryMemcacheOpcodes.GETK, BinaryMemcacheOpcodes.GETK, BinaryMemcacheOpcodes.GETK, BinaryMemcacheOpcodes.GETK, BinaryMemcacheOpcodes.GETK, BinaryMemcacheOpcodes.GETK, BinaryMemcacheOpcodes.GETK, BinaryMemcacheOpcodes.GETK, BinaryMemcacheOpcodes.GETK, BinaryMemcacheOpcodes.GETK, BinaryMemcacheOpcodes.GETK, BinaryMemcacheOpcodes.GETK, BinaryMemcacheOpcodes.GETK, 0, BinaryMemcacheOpcodes.GETK, BinaryMemcacheOpcodes.GETK, BinaryMemcacheOpcodes.GETK, BinaryMemcacheOpcodes.GETK, BinaryMemcacheOpcodes.GETK, 0, BinaryMemcacheOpcodes.GETK, 0, BinaryMemcacheOpcodes.GETK, BinaryMemcacheOpcodes.GETK, BinaryMemcacheOpcodes.GETK, BinaryMemcacheOpcodes.FLUSHQ, BinaryMemcacheOpcodes.GETK, BinaryMemcacheOpcodes.GETK, BinaryMemcacheOpcodes.GETK, BinaryMemcacheOpcodes.GETK, BinaryMemcacheOpcodes.GETK, BinaryMemcacheOpcodes.FLUSHQ, BinaryMemcacheOpcodes.GETK, BinaryMemcacheOpcodes.FLUSHQ, BinaryMemcacheOpcodes.GETK, BinaryMemcacheOpcodes.GETK, BinaryMemcacheOpcodes.GETK, BinaryMemcacheOpcodes.GETK, BinaryMemcacheOpcodes.GETK, BinaryMemcacheOpcodes.GETK, BinaryMemcacheOpcodes.GETK, BinaryMemcacheOpcodes.GETK, BinaryMemcacheOpcodes.GETK, BinaryMemcacheOpcodes.FLUSHQ, BinaryMemcacheOpcodes.GETK, BinaryMemcacheOpcodes.GETK, BinaryMemcacheOpcodes.GETK, BinaryMemcacheOpcodes.GETK, BinaryMemcacheOpcodes.GETK, BinaryMemcacheOpcodes.FLUSHQ, BinaryMemcacheOpcodes.GETK, BinaryMemcacheOpcodes.GETK, BinaryMemcacheOpcodes.GETK, BinaryMemcacheOpcodes.GETK, BinaryMemcacheOpcodes.GETK, BinaryMemcacheOpcodes.GETK, BinaryMemcacheOpcodes.GETK, BinaryMemcacheOpcodes.FLUSHQ, BinaryMemcacheOpcodes.GETK, BinaryMemcacheOpcodes.GETK, BinaryMemcacheOpcodes.GETK, BinaryMemcacheOpcodes.GETK, BinaryMemcacheOpcodes.GETK, BinaryMemcacheOpcodes.GETK, BinaryMemcacheOpcodes.GETK, BinaryMemcacheOpcodes.GETK, BinaryMemcacheOpcodes.GETK, BinaryMemcacheOpcodes.GATKQ, BinaryMemcacheOpcodes.GETK, BinaryMemcacheOpcodes.GATKQ, BinaryMemcacheOpcodes.GETK, BinaryMemcacheOpcodes.GETK, BinaryMemcacheOpcodes.GETK, BinaryMemcacheOpcodes.GATKQ, BinaryMemcacheOpcodes.GETK, BinaryMemcacheOpcodes.GETK, BinaryMemcacheOpcodes.GETK, BinaryMemcacheOpcodes.GETK, BinaryMemcacheOpcodes.GETK, BinaryMemcacheOpcodes.GATKQ, BinaryMemcacheOpcodes.GETK, BinaryMemcacheOpcodes.GATKQ, BinaryMemcacheOpcodes.GETK, BinaryMemcacheOpcodes.GETK, BinaryMemcacheOpcodes.GETK, BinaryMemcacheOpcodes.GATKQ, BinaryMemcacheOpcodes.GETK, BinaryMemcacheOpcodes.GETK, BinaryMemcacheOpcodes.GETK, BinaryMemcacheOpcodes.GETK, BinaryMemcacheOpcodes.GETK, BinaryMemcacheOpcodes.GETK, BinaryMemcacheOpcodes.GETK, BinaryMemcacheOpcodes.GETK, BinaryMemcacheOpcodes.GETK, BinaryMemcacheOpcodes.GETK};

    public void check(ByteBuf buffer) {
        this.checking = true;
        buffer.forEachByte(this);
    }

    public void finish() {
        this.checking = false;
        this.codep = 0;
        if (this.state != 0) {
            this.state = 0;
            throw new CorruptedWebSocketFrameException(WebSocketCloseStatus.INVALID_PAYLOAD_DATA, "bytes are not UTF-8");
        }
    }

    @Override // io.netty.util.ByteProcessor
    public boolean process(byte b) throws Exception {
        byte type = TYPES[b & UByte.MAX_VALUE];
        this.codep = this.state != 0 ? (b & 63) | (this.codep << 6) : (255 >> type) & b;
        byte b2 = STATES[this.state + type];
        this.state = b2;
        if (b2 == 12) {
            this.checking = false;
            throw new CorruptedWebSocketFrameException(WebSocketCloseStatus.INVALID_PAYLOAD_DATA, "bytes are not UTF-8");
        }
        return true;
    }

    public boolean isChecking() {
        return this.checking;
    }
}
