package io.netty.handler.codec.http.websocketx;

import io.netty.buffer.ByteBuf;
import io.netty.buffer.ByteBufUtil;
import io.netty.buffer.Unpooled;
import io.netty.channel.ChannelFutureListener;
import io.netty.channel.ChannelHandlerContext;
import io.netty.handler.codec.ByteToMessageDecoder;
import io.netty.handler.codec.TooLongFrameException;
import io.netty.handler.codec.memcache.binary.BinaryMemcacheOpcodes;
import io.netty.util.concurrent.Future;
import io.netty.util.concurrent.GenericFutureListener;
import io.netty.util.internal.ObjectUtil;
import io.netty.util.internal.logging.InternalLogger;
import io.netty.util.internal.logging.InternalLoggerFactory;
import java.nio.ByteOrder;
import java.util.List;
import kotlin.UByte;
import kotlin.jvm.internal.ByteCompanionObject;
/* loaded from: classes.dex */
public class WebSocket08FrameDecoder extends ByteToMessageDecoder implements WebSocketFrameDecoder {
    private static final byte OPCODE_BINARY = 2;
    private static final byte OPCODE_CLOSE = 8;
    private static final byte OPCODE_CONT = 0;
    private static final byte OPCODE_PING = 9;
    private static final byte OPCODE_PONG = 10;
    private static final byte OPCODE_TEXT = 1;
    private static final InternalLogger logger = InternalLoggerFactory.getInstance(WebSocket08FrameDecoder.class);
    private final WebSocketDecoderConfig config;
    private int fragmentedFramesCount;
    private boolean frameFinalFlag;
    private boolean frameMasked;
    private int frameOpcode;
    private int framePayloadLen1;
    private long framePayloadLength;
    private int frameRsv;
    private byte[] maskingKey;
    private boolean receivedClosingHandshake;
    private State state;

    /* JADX INFO: Access modifiers changed from: package-private */
    /* loaded from: classes.dex */
    public enum State {
        READING_FIRST,
        READING_SECOND,
        READING_SIZE,
        MASKING_KEY,
        PAYLOAD,
        CORRUPT
    }

    public WebSocket08FrameDecoder(boolean expectMaskedFrames, boolean allowExtensions, int maxFramePayloadLength) {
        this(expectMaskedFrames, allowExtensions, maxFramePayloadLength, false);
    }

    public WebSocket08FrameDecoder(boolean expectMaskedFrames, boolean allowExtensions, int maxFramePayloadLength, boolean allowMaskMismatch) {
        this(WebSocketDecoderConfig.newBuilder().expectMaskedFrames(expectMaskedFrames).allowExtensions(allowExtensions).maxFramePayloadLength(maxFramePayloadLength).allowMaskMismatch(allowMaskMismatch).build());
    }

    public WebSocket08FrameDecoder(WebSocketDecoderConfig decoderConfig) {
        this.state = State.READING_FIRST;
        this.config = (WebSocketDecoderConfig) ObjectUtil.checkNotNull(decoderConfig, "decoderConfig");
    }

    /* JADX WARN: Removed duplicated region for block: B:105:0x019b  */
    /* JADX WARN: Removed duplicated region for block: B:107:0x01bd  */
    /* JADX WARN: Removed duplicated region for block: B:113:0x01da  */
    /* JADX WARN: Removed duplicated region for block: B:123:0x01fd A[RETURN] */
    /* JADX WARN: Removed duplicated region for block: B:124:0x01fe  */
    /* JADX WARN: Removed duplicated region for block: B:27:0x007d A[RETURN] */
    /* JADX WARN: Removed duplicated region for block: B:28:0x007e  */
    /* JADX WARN: Removed duplicated region for block: B:86:0x0157  */
    /* JADX WARN: Removed duplicated region for block: B:93:0x016f  */
    @Override // io.netty.handler.codec.ByteToMessageDecoder
    /*
        Code decompiled incorrectly, please refer to instructions dump.
    */
    protected void decode(ChannelHandlerContext ctx, ByteBuf in, List<Object> out) throws Exception {
        int i;
        int i2;
        if (this.receivedClosingHandshake) {
            in.skipBytes(actualReadableBytes());
            return;
        }
        switch (AnonymousClass1.$SwitchMap$io$netty$handler$codec$http$websocketx$WebSocket08FrameDecoder$State[this.state.ordinal()]) {
            case 1:
                if (in.isReadable()) {
                    this.framePayloadLength = 0L;
                    byte b = in.readByte();
                    this.frameFinalFlag = (b & 128) != 0;
                    this.frameRsv = (b & 112) >> 4;
                    this.frameOpcode = b & BinaryMemcacheOpcodes.PREPEND;
                    if (logger.isTraceEnabled()) {
                        logger.trace("Decoding WebSocket Frame opCode={}", Integer.valueOf(this.frameOpcode));
                    }
                    this.state = State.READING_SECOND;
                    if (in.isReadable()) {
                        return;
                    }
                    byte b2 = in.readByte();
                    this.frameMasked = (b2 & 128) != 0;
                    this.framePayloadLen1 = b2 & ByteCompanionObject.MAX_VALUE;
                    if (this.frameRsv != 0 && !this.config.allowExtensions()) {
                        protocolViolation(ctx, in, "RSV != 0 and no extension negotiated, RSV:" + this.frameRsv);
                        return;
                    } else if (!this.config.allowMaskMismatch() && this.config.expectMaskedFrames() != this.frameMasked) {
                        protocolViolation(ctx, in, "received a frame that is not masked as expected");
                        return;
                    } else {
                        int i3 = this.frameOpcode;
                        if (i3 > 7) {
                            if (!this.frameFinalFlag) {
                                protocolViolation(ctx, in, "fragmented control frame");
                                return;
                            } else if (this.framePayloadLen1 > 125) {
                                protocolViolation(ctx, in, "control frame with payload length > 125 octets");
                                return;
                            } else if (i3 != 8 && i3 != 9 && i3 != 10) {
                                protocolViolation(ctx, in, "control frame using reserved opcode " + this.frameOpcode);
                                return;
                            } else if (this.frameOpcode == 8 && this.framePayloadLen1 == 1) {
                                protocolViolation(ctx, in, "received close control frame with payload len 1");
                                return;
                            }
                        } else if (i3 != 0 && i3 != 1 && i3 != 2) {
                            protocolViolation(ctx, in, "data frame using reserved opcode " + this.frameOpcode);
                            return;
                        } else if (this.fragmentedFramesCount == 0 && this.frameOpcode == 0) {
                            protocolViolation(ctx, in, "received continuation data frame outside fragmented message");
                            return;
                        } else if (this.fragmentedFramesCount != 0 && (i2 = this.frameOpcode) != 0 && i2 != 9) {
                            protocolViolation(ctx, in, "received non-continuation data frame while inside fragmented message");
                            return;
                        }
                        this.state = State.READING_SIZE;
                        i = this.framePayloadLen1;
                        if (i != 126) {
                            if (in.readableBytes() < 2) {
                                return;
                            }
                            long readUnsignedShort = in.readUnsignedShort();
                            this.framePayloadLength = readUnsignedShort;
                            if (readUnsignedShort < 126) {
                                protocolViolation(ctx, in, "invalid data frame length (not using minimal length encoding)");
                                return;
                            }
                        } else if (i != 127) {
                            this.framePayloadLength = i;
                        } else if (in.readableBytes() < 8) {
                            return;
                        } else {
                            long readLong = in.readLong();
                            this.framePayloadLength = readLong;
                            if (readLong < 65536) {
                                protocolViolation(ctx, in, "invalid data frame length (not using minimal length encoding)");
                                return;
                            }
                        }
                        if (this.framePayloadLength <= this.config.maxFramePayloadLength()) {
                            protocolViolation(ctx, in, WebSocketCloseStatus.MESSAGE_TOO_BIG, "Max frame length of " + this.config.maxFramePayloadLength() + " has been exceeded.");
                            return;
                        }
                        if (logger.isTraceEnabled()) {
                            logger.trace("Decoding WebSocket Frame length={}", Long.valueOf(this.framePayloadLength));
                        }
                        this.state = State.MASKING_KEY;
                        if (this.frameMasked) {
                            if (in.readableBytes() < 4) {
                                return;
                            }
                            if (this.maskingKey == null) {
                                this.maskingKey = new byte[4];
                            }
                            in.readBytes(this.maskingKey);
                        }
                        this.state = State.PAYLOAD;
                        if (in.readableBytes() < this.framePayloadLength) {
                            return;
                        }
                        ByteBuf payloadBuffer = null;
                        try {
                            ByteBuf payloadBuffer2 = ByteBufUtil.readBytes(ctx.alloc(), in, toFrameLength(this.framePayloadLength));
                            this.state = State.READING_FIRST;
                            if (this.frameMasked) {
                                unmask(payloadBuffer2);
                            }
                            if (this.frameOpcode == 9) {
                                out.add(new PingWebSocketFrame(this.frameFinalFlag, this.frameRsv, payloadBuffer2));
                                payloadBuffer = null;
                                if (payloadBuffer != null) {
                                    return;
                                }
                                return;
                            } else if (this.frameOpcode == 10) {
                                out.add(new PongWebSocketFrame(this.frameFinalFlag, this.frameRsv, payloadBuffer2));
                                ByteBuf payloadBuffer3 = null;
                                if (0 != 0) {
                                    payloadBuffer3.release();
                                    return;
                                }
                                return;
                            } else if (this.frameOpcode == 8) {
                                this.receivedClosingHandshake = true;
                                checkCloseFrameBody(ctx, payloadBuffer2);
                                out.add(new CloseWebSocketFrame(this.frameFinalFlag, this.frameRsv, payloadBuffer2));
                                ByteBuf payloadBuffer4 = null;
                                if (0 != 0) {
                                    payloadBuffer4.release();
                                    return;
                                }
                                return;
                            } else {
                                if (!this.frameFinalFlag) {
                                    this.fragmentedFramesCount++;
                                } else if (this.frameOpcode != 9) {
                                    this.fragmentedFramesCount = 0;
                                }
                                if (this.frameOpcode == 1) {
                                    out.add(new TextWebSocketFrame(this.frameFinalFlag, this.frameRsv, payloadBuffer2));
                                    ByteBuf payloadBuffer5 = null;
                                    if (0 != 0) {
                                        payloadBuffer5.release();
                                        return;
                                    }
                                    return;
                                } else if (this.frameOpcode == 2) {
                                    out.add(new BinaryWebSocketFrame(this.frameFinalFlag, this.frameRsv, payloadBuffer2));
                                    ByteBuf payloadBuffer6 = null;
                                    if (0 != 0) {
                                        payloadBuffer6.release();
                                        return;
                                    }
                                    return;
                                } else if (this.frameOpcode != 0) {
                                    throw new UnsupportedOperationException("Cannot decode web socket frame with opcode: " + this.frameOpcode);
                                } else {
                                    out.add(new ContinuationWebSocketFrame(this.frameFinalFlag, this.frameRsv, payloadBuffer2));
                                    ByteBuf payloadBuffer7 = null;
                                    if (0 != 0) {
                                        payloadBuffer7.release();
                                        return;
                                    }
                                    return;
                                }
                            }
                        } finally {
                            if (payloadBuffer != null) {
                                payloadBuffer.release();
                            }
                        }
                    }
                }
                return;
            case 2:
                if (in.isReadable()) {
                }
                break;
            case 3:
                i = this.framePayloadLen1;
                if (i != 126) {
                }
                if (this.framePayloadLength <= this.config.maxFramePayloadLength()) {
                }
                break;
            case 4:
                if (this.frameMasked) {
                }
                this.state = State.PAYLOAD;
                if (in.readableBytes() < this.framePayloadLength) {
                }
                break;
            case 5:
                if (in.readableBytes() < this.framePayloadLength) {
                }
                break;
            case 6:
                if (in.isReadable()) {
                    in.readByte();
                    return;
                }
                return;
            default:
                throw new Error("Shouldn't reach here.");
        }
    }

    /* renamed from: io.netty.handler.codec.http.websocketx.WebSocket08FrameDecoder$1  reason: invalid class name */
    /* loaded from: classes.dex */
    static /* synthetic */ class AnonymousClass1 {
        static final /* synthetic */ int[] $SwitchMap$io$netty$handler$codec$http$websocketx$WebSocket08FrameDecoder$State;

        static {
            int[] iArr = new int[State.values().length];
            $SwitchMap$io$netty$handler$codec$http$websocketx$WebSocket08FrameDecoder$State = iArr;
            try {
                iArr[State.READING_FIRST.ordinal()] = 1;
            } catch (NoSuchFieldError e) {
            }
            try {
                $SwitchMap$io$netty$handler$codec$http$websocketx$WebSocket08FrameDecoder$State[State.READING_SECOND.ordinal()] = 2;
            } catch (NoSuchFieldError e2) {
            }
            try {
                $SwitchMap$io$netty$handler$codec$http$websocketx$WebSocket08FrameDecoder$State[State.READING_SIZE.ordinal()] = 3;
            } catch (NoSuchFieldError e3) {
            }
            try {
                $SwitchMap$io$netty$handler$codec$http$websocketx$WebSocket08FrameDecoder$State[State.MASKING_KEY.ordinal()] = 4;
            } catch (NoSuchFieldError e4) {
            }
            try {
                $SwitchMap$io$netty$handler$codec$http$websocketx$WebSocket08FrameDecoder$State[State.PAYLOAD.ordinal()] = 5;
            } catch (NoSuchFieldError e5) {
            }
            try {
                $SwitchMap$io$netty$handler$codec$http$websocketx$WebSocket08FrameDecoder$State[State.CORRUPT.ordinal()] = 6;
            } catch (NoSuchFieldError e6) {
            }
        }
    }

    private void unmask(ByteBuf frame) {
        int i = frame.readerIndex();
        int end = frame.writerIndex();
        ByteOrder order = frame.order();
        byte[] bArr = this.maskingKey;
        int intMask = (bArr[3] & UByte.MAX_VALUE) | ((bArr[0] & UByte.MAX_VALUE) << 24) | ((bArr[1] & UByte.MAX_VALUE) << 16) | ((bArr[2] & UByte.MAX_VALUE) << 8);
        if (order == ByteOrder.LITTLE_ENDIAN) {
            intMask = Integer.reverseBytes(intMask);
        }
        while (i + 3 < end) {
            int unmasked = frame.getInt(i) ^ intMask;
            frame.setInt(i, unmasked);
            i += 4;
        }
        while (i < end) {
            frame.setByte(i, frame.getByte(i) ^ this.maskingKey[i % 4]);
            i++;
        }
    }

    private void protocolViolation(ChannelHandlerContext ctx, ByteBuf in, String reason) {
        protocolViolation(ctx, in, WebSocketCloseStatus.PROTOCOL_ERROR, reason);
    }

    private void protocolViolation(ChannelHandlerContext ctx, ByteBuf in, WebSocketCloseStatus status, String reason) {
        protocolViolation(ctx, in, new CorruptedWebSocketFrameException(status, reason));
    }

    private void protocolViolation(ChannelHandlerContext ctx, ByteBuf in, CorruptedWebSocketFrameException ex) {
        Object closeMessage;
        this.state = State.CORRUPT;
        int readableBytes = in.readableBytes();
        if (readableBytes > 0) {
            in.skipBytes(readableBytes);
        }
        if (ctx.channel().isActive() && this.config.closeOnProtocolViolation()) {
            if (this.receivedClosingHandshake) {
                closeMessage = Unpooled.EMPTY_BUFFER;
            } else {
                WebSocketCloseStatus closeStatus = ex.closeStatus();
                String reasonText = ex.getMessage();
                if (reasonText == null) {
                    reasonText = closeStatus.reasonText();
                }
                closeMessage = new CloseWebSocketFrame(closeStatus, reasonText);
            }
            ctx.writeAndFlush(closeMessage).addListener((GenericFutureListener<? extends Future<? super Void>>) ChannelFutureListener.CLOSE);
        }
        throw ex;
    }

    private static int toFrameLength(long l) {
        if (l > 2147483647L) {
            throw new TooLongFrameException("Length:" + l);
        }
        return (int) l;
    }

    protected void checkCloseFrameBody(ChannelHandlerContext ctx, ByteBuf buffer) {
        if (buffer == null || !buffer.isReadable()) {
            return;
        }
        if (buffer.readableBytes() == 1) {
            protocolViolation(ctx, buffer, WebSocketCloseStatus.INVALID_PAYLOAD_DATA, "Invalid close frame body");
        }
        int idx = buffer.readerIndex();
        buffer.readerIndex(0);
        int statusCode = buffer.readShort();
        if (!WebSocketCloseStatus.isValidStatusCode(statusCode)) {
            protocolViolation(ctx, buffer, "Invalid close frame getStatus code: " + statusCode);
        }
        if (buffer.isReadable()) {
            try {
                new Utf8Validator().check(buffer);
            } catch (CorruptedWebSocketFrameException ex) {
                protocolViolation(ctx, buffer, ex);
            }
        }
        buffer.readerIndex(idx);
    }
}
