package io.netty.handler.codec.http2;

import io.netty.buffer.ByteBuf;
import io.netty.buffer.Unpooled;
import io.netty.channel.ChannelFuture;
import io.netty.channel.ChannelHandlerContext;
import io.netty.channel.ChannelPromise;
import io.netty.handler.codec.http2.Http2CodecUtil;
import io.netty.handler.codec.http2.Http2FrameWriter;
import io.netty.handler.codec.http2.Http2HeadersEncoder;
import io.netty.util.collection.CharObjectMap;
import io.netty.util.internal.ObjectUtil;
import io.netty.util.internal.PlatformDependent;
/* loaded from: classes.dex */
public class DefaultHttp2FrameWriter implements Http2FrameWriter, Http2FrameSizePolicy, Http2FrameWriter.Configuration {
    private static final String STREAM_DEPENDENCY = "Stream Dependency";
    private static final String STREAM_ID = "Stream ID";
    private static final ByteBuf ZERO_BUFFER = Unpooled.unreleasableBuffer(Unpooled.directBuffer(255).writeZero(255)).asReadOnly();
    private final Http2HeadersEncoder headersEncoder;
    private int maxFrameSize;

    public DefaultHttp2FrameWriter() {
        this(new DefaultHttp2HeadersEncoder());
    }

    public DefaultHttp2FrameWriter(Http2HeadersEncoder.SensitivityDetector headersSensitivityDetector) {
        this(new DefaultHttp2HeadersEncoder(headersSensitivityDetector));
    }

    public DefaultHttp2FrameWriter(Http2HeadersEncoder.SensitivityDetector headersSensitivityDetector, boolean ignoreMaxHeaderListSize) {
        this(new DefaultHttp2HeadersEncoder(headersSensitivityDetector, ignoreMaxHeaderListSize));
    }

    public DefaultHttp2FrameWriter(Http2HeadersEncoder headersEncoder) {
        this.headersEncoder = headersEncoder;
        this.maxFrameSize = 16384;
    }

    @Override // io.netty.handler.codec.http2.Http2FrameWriter
    public Http2FrameWriter.Configuration configuration() {
        return this;
    }

    @Override // io.netty.handler.codec.http2.Http2FrameWriter.Configuration
    public Http2HeadersEncoder.Configuration headersConfiguration() {
        return this.headersEncoder.configuration();
    }

    @Override // io.netty.handler.codec.http2.Http2FrameWriter.Configuration
    public Http2FrameSizePolicy frameSizePolicy() {
        return this;
    }

    @Override // io.netty.handler.codec.http2.Http2FrameSizePolicy
    public void maxFrameSize(int max) throws Http2Exception {
        if (!Http2CodecUtil.isMaxFrameSizeValid(max)) {
            throw Http2Exception.connectionError(Http2Error.FRAME_SIZE_ERROR, "Invalid MAX_FRAME_SIZE specified in sent settings: %d", Integer.valueOf(max));
        }
        this.maxFrameSize = max;
    }

    @Override // io.netty.handler.codec.http2.Http2FrameSizePolicy
    public int maxFrameSize() {
        return this.maxFrameSize;
    }

    @Override // io.netty.handler.codec.http2.Http2FrameWriter, java.io.Closeable, java.lang.AutoCloseable
    public void close() {
    }

    /* JADX WARN: Removed duplicated region for block: B:17:0x009a A[Catch: all -> 0x0171, TRY_ENTER, TryCatch #1 {all -> 0x0171, blocks: (B:3:0x001b, B:5:0x0039, B:6:0x0047, B:10:0x006a, B:11:0x006e, B:17:0x009a, B:20:0x00a0, B:22:0x00ac, B:24:0x00b1, B:26:0x00c4, B:28:0x00d3, B:25:0x00bf), top: B:77:0x001b }] */
    /* JADX WARN: Removed duplicated region for block: B:9:0x0068  */
    @Override // io.netty.handler.codec.http2.Http2DataWriter
    /*
        Code decompiled incorrectly, please refer to instructions dump.
    */
    public ChannelFuture writeData(ChannelHandlerContext ctx, int streamId, ByteBuf data, int padding, boolean endStream, ChannelPromise promise) {
        ByteBuf lastFrame;
        ByteBuf lastFrame2;
        int padding2;
        DefaultHttp2FrameWriter defaultHttp2FrameWriter = this;
        ByteBuf data2 = data;
        Http2CodecUtil.SimpleChannelPromiseAggregator promiseAggregator = new Http2CodecUtil.SimpleChannelPromiseAggregator(promise, ctx.channel(), ctx.executor());
        ByteBuf frameHeader = null;
        try {
            verifyStreamId(streamId, STREAM_ID);
            Http2CodecUtil.verifyPadding(padding);
            int remainingData = data.readableBytes();
            Http2Flags flags = new Http2Flags();
            byte b = 0;
            flags.endOfStream(false);
            flags.paddingPresent(false);
            if (remainingData > defaultHttp2FrameWriter.maxFrameSize) {
                frameHeader = ctx.alloc().buffer(9);
                Http2CodecUtil.writeFrameHeaderInternal(frameHeader, defaultHttp2FrameWriter.maxFrameSize, (byte) 0, flags, streamId);
                do {
                    ctx.write(frameHeader.retainedSlice(), promiseAggregator.newPromise());
                    ctx.write(data2.readRetainedSlice(defaultHttp2FrameWriter.maxFrameSize), promiseAggregator.newPromise());
                    remainingData -= defaultHttp2FrameWriter.maxFrameSize;
                } while (remainingData > defaultHttp2FrameWriter.maxFrameSize);
                try {
                    if (padding != 0) {
                        if (frameHeader != null) {
                            frameHeader.release();
                            frameHeader = null;
                        }
                        ByteBuf frameHeader2 = ctx.alloc().buffer(9);
                        flags.endOfStream(endStream);
                        Http2CodecUtil.writeFrameHeaderInternal(frameHeader2, remainingData, (byte) 0, flags, streamId);
                        ctx.write(frameHeader2, promiseAggregator.newPromise());
                        ByteBuf lastFrame3 = data2.readSlice(remainingData);
                        ctx.write(lastFrame3, promiseAggregator.newPromise());
                    } else {
                        if (remainingData != defaultHttp2FrameWriter.maxFrameSize) {
                            if (frameHeader == null) {
                                lastFrame = frameHeader;
                                padding2 = padding;
                            } else {
                                frameHeader.release();
                                lastFrame = null;
                                padding2 = padding;
                            }
                        } else {
                            remainingData -= defaultHttp2FrameWriter.maxFrameSize;
                            if (frameHeader == null) {
                                lastFrame2 = ctx.alloc().buffer(9);
                                Http2CodecUtil.writeFrameHeaderInternal(lastFrame2, defaultHttp2FrameWriter.maxFrameSize, (byte) 0, flags, streamId);
                            } else {
                                lastFrame2 = frameHeader.slice();
                                frameHeader = null;
                            }
                            ctx.write(lastFrame2, promiseAggregator.newPromise());
                            ByteBuf lastFrame4 = data.readableBytes() != defaultHttp2FrameWriter.maxFrameSize ? data2.readSlice(defaultHttp2FrameWriter.maxFrameSize) : data2;
                            data2 = null;
                            ctx.write(lastFrame4, promiseAggregator.newPromise());
                            lastFrame = frameHeader;
                            padding2 = padding;
                        }
                        while (true) {
                            try {
                                int frameDataBytes = Math.min(remainingData, defaultHttp2FrameWriter.maxFrameSize);
                                int framePaddingBytes = Math.min(padding2, Math.max((int) b, (defaultHttp2FrameWriter.maxFrameSize - 1) - frameDataBytes));
                                padding2 -= framePaddingBytes;
                                remainingData -= frameDataBytes;
                                ByteBuf frameHeader22 = ctx.alloc().buffer(10);
                                flags.endOfStream(endStream && remainingData == 0 && padding2 == 0);
                                flags.paddingPresent(framePaddingBytes > 0);
                                Http2CodecUtil.writeFrameHeaderInternal(frameHeader22, framePaddingBytes + frameDataBytes, b, flags, streamId);
                                writePaddingLength(frameHeader22, framePaddingBytes);
                                ctx.write(frameHeader22, promiseAggregator.newPromise());
                                if (frameDataBytes != 0) {
                                    if (remainingData == 0) {
                                        ByteBuf lastFrame5 = data2.readSlice(frameDataBytes);
                                        data2 = null;
                                        ctx.write(lastFrame5, promiseAggregator.newPromise());
                                    } else {
                                        ctx.write(data2.readRetainedSlice(frameDataBytes), promiseAggregator.newPromise());
                                    }
                                }
                                if (paddingBytes(framePaddingBytes) > 0) {
                                    ctx.write(ZERO_BUFFER.slice(0, paddingBytes(framePaddingBytes)), promiseAggregator.newPromise());
                                }
                                if (remainingData == 0 && padding2 == 0) {
                                    break;
                                }
                                b = 0;
                                defaultHttp2FrameWriter = this;
                            } catch (Throwable th) {
                                th = th;
                                Throwable cause = th;
                                if (lastFrame != null) {
                                    lastFrame.release();
                                }
                                if (data2 != null) {
                                    try {
                                        data2.release();
                                    } finally {
                                        promiseAggregator.setFailure(cause);
                                        promiseAggregator.doneAllocatingPromises();
                                    }
                                }
                                return promiseAggregator;
                            }
                        }
                    }
                    return promiseAggregator.doneAllocatingPromises();
                } catch (Throwable th2) {
                    th = th2;
                    lastFrame = frameHeader;
                }
            } else {
                if (padding != 0) {
                }
                return promiseAggregator.doneAllocatingPromises();
            }
        } catch (Throwable th3) {
            th = th3;
            lastFrame = null;
        }
    }

    @Override // io.netty.handler.codec.http2.Http2FrameWriter
    public ChannelFuture writeHeaders(ChannelHandlerContext ctx, int streamId, Http2Headers headers, int padding, boolean endStream, ChannelPromise promise) {
        return writeHeadersInternal(ctx, streamId, headers, padding, endStream, false, 0, (short) 0, false, promise);
    }

    @Override // io.netty.handler.codec.http2.Http2FrameWriter
    public ChannelFuture writeHeaders(ChannelHandlerContext ctx, int streamId, Http2Headers headers, int streamDependency, short weight, boolean exclusive, int padding, boolean endStream, ChannelPromise promise) {
        return writeHeadersInternal(ctx, streamId, headers, padding, endStream, true, streamDependency, weight, exclusive, promise);
    }

    @Override // io.netty.handler.codec.http2.Http2FrameWriter
    public ChannelFuture writePriority(ChannelHandlerContext ctx, int streamId, int streamDependency, short weight, boolean exclusive, ChannelPromise promise) {
        try {
            verifyStreamId(streamId, STREAM_ID);
            verifyStreamId(streamDependency, STREAM_DEPENDENCY);
            verifyWeight(weight);
            ByteBuf buf = ctx.alloc().buffer(14);
            Http2CodecUtil.writeFrameHeaderInternal(buf, 5, (byte) 2, new Http2Flags(), streamId);
            buf.writeInt(exclusive ? (int) (2147483648L | streamDependency) : streamDependency);
            buf.writeByte(weight - 1);
            return ctx.write(buf, promise);
        } catch (Throwable t) {
            return promise.setFailure(t);
        }
    }

    @Override // io.netty.handler.codec.http2.Http2FrameWriter
    public ChannelFuture writeRstStream(ChannelHandlerContext ctx, int streamId, long errorCode, ChannelPromise promise) {
        try {
            verifyStreamId(streamId, STREAM_ID);
            verifyErrorCode(errorCode);
            ByteBuf buf = ctx.alloc().buffer(13);
            Http2CodecUtil.writeFrameHeaderInternal(buf, 4, (byte) 3, new Http2Flags(), streamId);
            buf.writeInt((int) errorCode);
            return ctx.write(buf, promise);
        } catch (Throwable t) {
            return promise.setFailure(t);
        }
    }

    @Override // io.netty.handler.codec.http2.Http2FrameWriter
    public ChannelFuture writeSettings(ChannelHandlerContext ctx, Http2Settings settings, ChannelPromise promise) {
        try {
            ObjectUtil.checkNotNull(settings, "settings");
            int payloadLength = settings.size() * 6;
            ByteBuf buf = ctx.alloc().buffer((settings.size() * 6) + 9);
            Http2CodecUtil.writeFrameHeaderInternal(buf, payloadLength, (byte) 4, new Http2Flags(), 0);
            for (CharObjectMap.PrimitiveEntry<Long> entry : settings.entries()) {
                buf.writeChar(entry.key());
                buf.writeInt(entry.value().intValue());
            }
            return ctx.write(buf, promise);
        } catch (Throwable t) {
            return promise.setFailure(t);
        }
    }

    @Override // io.netty.handler.codec.http2.Http2FrameWriter
    public ChannelFuture writeSettingsAck(ChannelHandlerContext ctx, ChannelPromise promise) {
        try {
            ByteBuf buf = ctx.alloc().buffer(9);
            Http2CodecUtil.writeFrameHeaderInternal(buf, 0, (byte) 4, new Http2Flags().ack(true), 0);
            return ctx.write(buf, promise);
        } catch (Throwable t) {
            return promise.setFailure(t);
        }
    }

    @Override // io.netty.handler.codec.http2.Http2FrameWriter
    public ChannelFuture writePing(ChannelHandlerContext ctx, boolean ack, long data, ChannelPromise promise) {
        Http2Flags flags = ack ? new Http2Flags().ack(true) : new Http2Flags();
        ByteBuf buf = ctx.alloc().buffer(17);
        Http2CodecUtil.writeFrameHeaderInternal(buf, 8, (byte) 6, flags, 0);
        buf.writeLong(data);
        return ctx.write(buf, promise);
    }

    /* JADX WARN: Code restructure failed: missing block: B:33:0x00cb, code lost:
        if (r6 == null) goto L21;
     */
    @Override // io.netty.handler.codec.http2.Http2FrameWriter
    /*
        Code decompiled incorrectly, please refer to instructions dump.
    */
    public ChannelFuture writePushPromise(ChannelHandlerContext ctx, int streamId, int promisedStreamId, Http2Headers headers, int padding, ChannelPromise promise) {
        ByteBuf headerBlock = null;
        Http2CodecUtil.SimpleChannelPromiseAggregator promiseAggregator = new Http2CodecUtil.SimpleChannelPromiseAggregator(promise, ctx.channel(), ctx.executor());
        try {
            try {
                verifyStreamId(streamId, STREAM_ID);
                verifyStreamId(promisedStreamId, "Promised Stream ID");
                Http2CodecUtil.verifyPadding(padding);
                headerBlock = ctx.alloc().buffer();
            } finally {
                if (0 != 0) {
                    headerBlock.release();
                }
            }
        } catch (Http2Exception e) {
            e = e;
        } catch (Throwable th) {
            t = th;
        }
        try {
            this.headersEncoder.encodeHeaders(streamId, headers, headerBlock);
            boolean z = true;
            Http2Flags flags = new Http2Flags().paddingPresent(padding > 0);
            int nonFragmentLength = padding + 4;
            int maxFragmentLength = this.maxFrameSize - nonFragmentLength;
            ByteBuf fragment = headerBlock.readRetainedSlice(Math.min(headerBlock.readableBytes(), maxFragmentLength));
            if (headerBlock.isReadable()) {
                z = false;
            }
            flags.endOfHeaders(z);
            int payloadLength = fragment.readableBytes() + nonFragmentLength;
            ByteBuf buf = ctx.alloc().buffer(14);
            Http2CodecUtil.writeFrameHeaderInternal(buf, payloadLength, (byte) 5, flags, streamId);
            writePaddingLength(buf, padding);
            buf.writeInt(promisedStreamId);
            ctx.write(buf, promiseAggregator.newPromise());
            ctx.write(fragment, promiseAggregator.newPromise());
            if (paddingBytes(padding) > 0) {
                ctx.write(ZERO_BUFFER.slice(0, paddingBytes(padding)), promiseAggregator.newPromise());
            }
            if (!flags.endOfHeaders()) {
                writeContinuationFrames(ctx, streamId, headerBlock, promiseAggregator);
            }
        } catch (Http2Exception e2) {
            e = e2;
            promiseAggregator.setFailure((Throwable) e);
        } catch (Throwable th2) {
            t = th2;
            promiseAggregator.setFailure(t);
            promiseAggregator.doneAllocatingPromises();
            PlatformDependent.throwException(t);
            if (headerBlock != null) {
            }
            return promiseAggregator.doneAllocatingPromises();
        }
    }

    @Override // io.netty.handler.codec.http2.Http2FrameWriter
    public ChannelFuture writeGoAway(ChannelHandlerContext ctx, int lastStreamId, long errorCode, ByteBuf debugData, ChannelPromise promise) {
        Http2CodecUtil.SimpleChannelPromiseAggregator promiseAggregator = new Http2CodecUtil.SimpleChannelPromiseAggregator(promise, ctx.channel(), ctx.executor());
        try {
            verifyStreamOrConnectionId(lastStreamId, "Last Stream ID");
            verifyErrorCode(errorCode);
            int payloadLength = debugData.readableBytes() + 8;
            ByteBuf buf = ctx.alloc().buffer(17);
            Http2CodecUtil.writeFrameHeaderInternal(buf, payloadLength, (byte) 7, new Http2Flags(), 0);
            buf.writeInt(lastStreamId);
            buf.writeInt((int) errorCode);
            ctx.write(buf, promiseAggregator.newPromise());
            try {
                ctx.write(debugData, promiseAggregator.newPromise());
            } catch (Throwable t) {
                promiseAggregator.setFailure(t);
            }
            return promiseAggregator.doneAllocatingPromises();
        } catch (Throwable t2) {
            try {
                debugData.release();
                return promiseAggregator;
            } finally {
                promiseAggregator.setFailure(t2);
                promiseAggregator.doneAllocatingPromises();
            }
        }
    }

    @Override // io.netty.handler.codec.http2.Http2FrameWriter
    public ChannelFuture writeWindowUpdate(ChannelHandlerContext ctx, int streamId, int windowSizeIncrement, ChannelPromise promise) {
        try {
            verifyStreamOrConnectionId(streamId, STREAM_ID);
            verifyWindowSizeIncrement(windowSizeIncrement);
            ByteBuf buf = ctx.alloc().buffer(13);
            Http2CodecUtil.writeFrameHeaderInternal(buf, 4, (byte) 8, new Http2Flags(), streamId);
            buf.writeInt(windowSizeIncrement);
            return ctx.write(buf, promise);
        } catch (Throwable t) {
            return promise.setFailure(t);
        }
    }

    @Override // io.netty.handler.codec.http2.Http2FrameWriter
    public ChannelFuture writeFrame(ChannelHandlerContext ctx, byte frameType, int streamId, Http2Flags flags, ByteBuf payload, ChannelPromise promise) {
        Http2CodecUtil.SimpleChannelPromiseAggregator promiseAggregator = new Http2CodecUtil.SimpleChannelPromiseAggregator(promise, ctx.channel(), ctx.executor());
        try {
            verifyStreamOrConnectionId(streamId, STREAM_ID);
            ByteBuf buf = ctx.alloc().buffer(9);
            Http2CodecUtil.writeFrameHeaderInternal(buf, payload.readableBytes(), frameType, flags, streamId);
            ctx.write(buf, promiseAggregator.newPromise());
            try {
                ctx.write(payload, promiseAggregator.newPromise());
            } catch (Throwable t) {
                promiseAggregator.setFailure(t);
            }
            return promiseAggregator.doneAllocatingPromises();
        } catch (Throwable t2) {
            try {
                payload.release();
                return promiseAggregator;
            } finally {
                promiseAggregator.setFailure(t2);
                promiseAggregator.doneAllocatingPromises();
            }
        }
    }

    /* JADX WARN: Code restructure failed: missing block: B:42:0x00f3, code lost:
        if (r7 == null) goto L30;
     */
    /*
        Code decompiled incorrectly, please refer to instructions dump.
    */
    private ChannelFuture writeHeadersInternal(ChannelHandlerContext ctx, int streamId, Http2Headers headers, int padding, boolean endStream, boolean hasPriority, int streamDependency, short weight, boolean exclusive, ChannelPromise promise) {
        ByteBuf headerBlock = null;
        Http2CodecUtil.SimpleChannelPromiseAggregator promiseAggregator = new Http2CodecUtil.SimpleChannelPromiseAggregator(promise, ctx.channel(), ctx.executor());
        try {
            try {
                verifyStreamId(streamId, STREAM_ID);
                if (hasPriority) {
                    verifyStreamOrConnectionId(streamDependency, STREAM_DEPENDENCY);
                    Http2CodecUtil.verifyPadding(padding);
                    verifyWeight(weight);
                }
                headerBlock = ctx.alloc().buffer();
                this.headersEncoder.encodeHeaders(streamId, headers, headerBlock);
            } finally {
                if (0 != 0) {
                    headerBlock.release();
                }
            }
        } catch (Http2Exception e) {
            e = e;
        } catch (Throwable th) {
            t = th;
        }
        try {
            Http2Flags flags = new Http2Flags().endOfStream(endStream).priorityPresent(hasPriority).paddingPresent(padding > 0);
            int nonFragmentBytes = flags.getNumPriorityBytes() + padding;
            int maxFragmentLength = this.maxFrameSize - nonFragmentBytes;
            ByteBuf fragment = headerBlock.readRetainedSlice(Math.min(headerBlock.readableBytes(), maxFragmentLength));
            flags.endOfHeaders(!headerBlock.isReadable());
            int payloadLength = fragment.readableBytes() + nonFragmentBytes;
            ByteBuf buf = ctx.alloc().buffer(15);
            Http2CodecUtil.writeFrameHeaderInternal(buf, payloadLength, (byte) 1, flags, streamId);
            writePaddingLength(buf, padding);
            if (hasPriority) {
                buf.writeInt(exclusive ? (int) (streamDependency | 2147483648L) : streamDependency);
                buf.writeByte(weight - 1);
            }
            ctx.write(buf, promiseAggregator.newPromise());
            ctx.write(fragment, promiseAggregator.newPromise());
            if (paddingBytes(padding) > 0) {
                ctx.write(ZERO_BUFFER.slice(0, paddingBytes(padding)), promiseAggregator.newPromise());
            }
            if (!flags.endOfHeaders()) {
                writeContinuationFrames(ctx, streamId, headerBlock, promiseAggregator);
            }
        } catch (Http2Exception e2) {
            e = e2;
            promiseAggregator.setFailure((Throwable) e);
        } catch (Throwable th2) {
            t = th2;
            promiseAggregator.setFailure(t);
            promiseAggregator.doneAllocatingPromises();
            PlatformDependent.throwException(t);
            if (headerBlock != null) {
            }
            return promiseAggregator.doneAllocatingPromises();
        }
    }

    private ChannelFuture writeContinuationFrames(ChannelHandlerContext ctx, int streamId, ByteBuf headerBlock, Http2CodecUtil.SimpleChannelPromiseAggregator promiseAggregator) {
        Http2Flags flags = new Http2Flags();
        if (headerBlock.isReadable()) {
            int fragmentReadableBytes = Math.min(headerBlock.readableBytes(), this.maxFrameSize);
            ByteBuf buf = ctx.alloc().buffer(10);
            Http2CodecUtil.writeFrameHeaderInternal(buf, fragmentReadableBytes, (byte) 9, flags, streamId);
            do {
                int fragmentReadableBytes2 = Math.min(headerBlock.readableBytes(), this.maxFrameSize);
                ByteBuf fragment = headerBlock.readRetainedSlice(fragmentReadableBytes2);
                if (headerBlock.isReadable()) {
                    ctx.write(buf.retain(), promiseAggregator.newPromise());
                } else {
                    flags = flags.endOfHeaders(true);
                    buf.release();
                    buf = ctx.alloc().buffer(10);
                    Http2CodecUtil.writeFrameHeaderInternal(buf, fragmentReadableBytes2, (byte) 9, flags, streamId);
                    ctx.write(buf, promiseAggregator.newPromise());
                }
                ctx.write(fragment, promiseAggregator.newPromise());
            } while (headerBlock.isReadable());
            return promiseAggregator;
        }
        return promiseAggregator;
    }

    private static int paddingBytes(int padding) {
        return padding - 1;
    }

    private static void writePaddingLength(ByteBuf buf, int padding) {
        if (padding > 0) {
            buf.writeByte(padding - 1);
        }
    }

    private static void verifyStreamId(int streamId, String argumentName) {
        ObjectUtil.checkPositive(streamId, "streamId");
    }

    private static void verifyStreamOrConnectionId(int streamId, String argumentName) {
        ObjectUtil.checkPositiveOrZero(streamId, "streamId");
    }

    private static void verifyWeight(short weight) {
        if (weight < 1 || weight > 256) {
            throw new IllegalArgumentException("Invalid weight: " + ((int) weight));
        }
    }

    private static void verifyErrorCode(long errorCode) {
        if (errorCode < 0 || errorCode > 4294967295L) {
            throw new IllegalArgumentException("Invalid errorCode: " + errorCode);
        }
    }

    private static void verifyWindowSizeIncrement(int windowSizeIncrement) {
        ObjectUtil.checkPositiveOrZero(windowSizeIncrement, "windowSizeIncrement");
    }

    private static void verifyPingPayload(ByteBuf data) {
        if (data == null || data.readableBytes() != 8) {
            throw new IllegalArgumentException("Opaque data must be 8 bytes");
        }
    }
}
