package io.netty.handler.codec.http2;
/* loaded from: classes.dex */
final class HpackDynamicTable {
    private long capacity = -1;
    int head;
    HpackHeaderField[] hpackHeaderFields;
    private long size;
    int tail;

    /* JADX INFO: Access modifiers changed from: package-private */
    public HpackDynamicTable(long initialCapacity) {
        setCapacity(initialCapacity);
    }

    public int length() {
        int i = this.head;
        int i2 = this.tail;
        if (i < i2) {
            int length = (this.hpackHeaderFields.length - i2) + i;
            return length;
        }
        int length2 = i - i2;
        return length2;
    }

    public long size() {
        return this.size;
    }

    public long capacity() {
        return this.capacity;
    }

    public HpackHeaderField getEntry(int index) {
        if (index <= 0 || index > length()) {
            throw new IndexOutOfBoundsException();
        }
        int i = this.head - index;
        if (i < 0) {
            HpackHeaderField[] hpackHeaderFieldArr = this.hpackHeaderFields;
            return hpackHeaderFieldArr[hpackHeaderFieldArr.length + i];
        }
        return this.hpackHeaderFields[i];
    }

    public void add(HpackHeaderField header) {
        long j;
        int headerSize = header.size();
        if (headerSize > this.capacity) {
            clear();
            return;
        }
        while (true) {
            long j2 = this.capacity;
            j = this.size;
            if (j2 - j >= headerSize) {
                break;
            }
            remove();
        }
        HpackHeaderField[] hpackHeaderFieldArr = this.hpackHeaderFields;
        int i = this.head;
        this.head = i + 1;
        hpackHeaderFieldArr[i] = header;
        this.size = j + header.size();
        if (this.head == this.hpackHeaderFields.length) {
            this.head = 0;
        }
    }

    public HpackHeaderField remove() {
        HpackHeaderField removed = this.hpackHeaderFields[this.tail];
        if (removed == null) {
            return null;
        }
        this.size -= removed.size();
        HpackHeaderField[] hpackHeaderFieldArr = this.hpackHeaderFields;
        int i = this.tail;
        int i2 = i + 1;
        this.tail = i2;
        hpackHeaderFieldArr[i] = null;
        if (i2 == hpackHeaderFieldArr.length) {
            this.tail = 0;
        }
        return removed;
    }

    public void clear() {
        while (true) {
            int i = this.tail;
            if (i != this.head) {
                HpackHeaderField[] hpackHeaderFieldArr = this.hpackHeaderFields;
                int i2 = i + 1;
                this.tail = i2;
                hpackHeaderFieldArr[i] = null;
                if (i2 == hpackHeaderFieldArr.length) {
                    this.tail = 0;
                }
            } else {
                this.head = 0;
                this.tail = 0;
                this.size = 0L;
                return;
            }
        }
    }

    public void setCapacity(long capacity) {
        if (capacity < 0 || capacity > 4294967295L) {
            throw new IllegalArgumentException("capacity is invalid: " + capacity);
        } else if (this.capacity != capacity) {
            this.capacity = capacity;
            if (capacity == 0) {
                clear();
            } else {
                while (this.size > capacity) {
                    remove();
                }
            }
            int maxEntries = (int) (capacity / 32);
            if (capacity % 32 != 0) {
                maxEntries++;
            }
            HpackHeaderField[] hpackHeaderFieldArr = this.hpackHeaderFields;
            if (hpackHeaderFieldArr != null && hpackHeaderFieldArr.length == maxEntries) {
                return;
            }
            HpackHeaderField[] tmp = new HpackHeaderField[maxEntries];
            int len = length();
            int cursor = this.tail;
            for (int i = 0; i < len; i++) {
                HpackHeaderField[] hpackHeaderFieldArr2 = this.hpackHeaderFields;
                int cursor2 = cursor + 1;
                HpackHeaderField entry = hpackHeaderFieldArr2[cursor];
                tmp[i] = entry;
                if (cursor2 != hpackHeaderFieldArr2.length) {
                    cursor = cursor2;
                } else {
                    cursor = 0;
                }
            }
            this.tail = 0;
            this.head = 0 + len;
            this.hpackHeaderFields = tmp;
        }
    }
}
