package io.netty.handler.codec.memcache.binary;

import io.netty.buffer.ByteBuf;
import io.netty.buffer.Unpooled;
import io.netty.channel.ChannelHandlerContext;
import io.netty.handler.codec.DecoderResult;
import io.netty.handler.codec.memcache.AbstractMemcacheObjectDecoder;
import io.netty.handler.codec.memcache.DefaultLastMemcacheContent;
import io.netty.handler.codec.memcache.DefaultMemcacheContent;
import io.netty.handler.codec.memcache.LastMemcacheContent;
import io.netty.handler.codec.memcache.MemcacheContent;
import io.netty.handler.codec.memcache.binary.BinaryMemcacheMessage;
import io.netty.util.internal.ObjectUtil;
import java.util.List;
/* loaded from: classes.dex */
public abstract class AbstractBinaryMemcacheDecoder<M extends BinaryMemcacheMessage> extends AbstractMemcacheObjectDecoder {
    public static final int DEFAULT_MAX_CHUNK_SIZE = 8192;
    private int alreadyReadChunkSize;
    private final int chunkSize;
    private M currentMessage;
    private State state;

    /* JADX INFO: Access modifiers changed from: package-private */
    /* loaded from: classes.dex */
    public enum State {
        READ_HEADER,
        READ_EXTRAS,
        READ_KEY,
        READ_CONTENT,
        BAD_MESSAGE
    }

    protected abstract M buildInvalidMessage();

    protected abstract M decodeHeader(ByteBuf byteBuf);

    protected AbstractBinaryMemcacheDecoder() {
        this(8192);
    }

    /* JADX INFO: Access modifiers changed from: protected */
    public AbstractBinaryMemcacheDecoder(int chunkSize) {
        this.state = State.READ_HEADER;
        ObjectUtil.checkPositiveOrZero(chunkSize, "chunkSize");
        this.chunkSize = chunkSize;
    }

    /* renamed from: io.netty.handler.codec.memcache.binary.AbstractBinaryMemcacheDecoder$1  reason: invalid class name */
    /* loaded from: classes.dex */
    static /* synthetic */ class AnonymousClass1 {
        static final /* synthetic */ int[] $SwitchMap$io$netty$handler$codec$memcache$binary$AbstractBinaryMemcacheDecoder$State;

        static {
            int[] iArr = new int[State.values().length];
            $SwitchMap$io$netty$handler$codec$memcache$binary$AbstractBinaryMemcacheDecoder$State = iArr;
            try {
                iArr[State.READ_HEADER.ordinal()] = 1;
            } catch (NoSuchFieldError e) {
            }
            try {
                $SwitchMap$io$netty$handler$codec$memcache$binary$AbstractBinaryMemcacheDecoder$State[State.READ_EXTRAS.ordinal()] = 2;
            } catch (NoSuchFieldError e2) {
            }
            try {
                $SwitchMap$io$netty$handler$codec$memcache$binary$AbstractBinaryMemcacheDecoder$State[State.READ_KEY.ordinal()] = 3;
            } catch (NoSuchFieldError e3) {
            }
            try {
                $SwitchMap$io$netty$handler$codec$memcache$binary$AbstractBinaryMemcacheDecoder$State[State.READ_CONTENT.ordinal()] = 4;
            } catch (NoSuchFieldError e4) {
            }
            try {
                $SwitchMap$io$netty$handler$codec$memcache$binary$AbstractBinaryMemcacheDecoder$State[State.BAD_MESSAGE.ordinal()] = 5;
            } catch (NoSuchFieldError e5) {
            }
        }
    }

    /* JADX INFO: Access modifiers changed from: protected */
    /* JADX WARN: Removed duplicated region for block: B:29:0x0076 A[Catch: Exception -> 0x00f7, TryCatch #2 {Exception -> 0x00f7, blocks: (B:27:0x006e, B:29:0x0076, B:32:0x007d, B:33:0x0086), top: B:71:0x006e }] */
    /* JADX WARN: Removed duplicated region for block: B:36:0x00ae  */
    /* JADX WARN: Removed duplicated region for block: B:52:0x00de A[Catch: Exception -> 0x00eb, TryCatch #1 {Exception -> 0x00eb, blocks: (B:34:0x0094, B:38:0x00b1, B:40:0x00b5, B:41:0x00b8, B:44:0x00bf, B:46:0x00ca, B:48:0x00d5, B:53:0x00e3, B:47:0x00d0, B:52:0x00de), top: B:69:0x0094 }] */
    @Override // io.netty.handler.codec.ByteToMessageDecoder
    /*
        Code decompiled incorrectly, please refer to instructions dump.
    */
    public void decode(ChannelHandlerContext ctx, ByteBuf in, List<Object> out) throws Exception {
        short keyLength;
        int valueLength;
        MemcacheContent chunk;
        int i = AnonymousClass1.$SwitchMap$io$netty$handler$codec$memcache$binary$AbstractBinaryMemcacheDecoder$State[this.state.ordinal()];
        try {
            try {
                try {
                    if (i == 1) {
                        try {
                            if (in.readableBytes() < 24) {
                                return;
                            }
                            resetDecoder();
                            this.currentMessage = decodeHeader(in);
                            this.state = State.READ_EXTRAS;
                        } catch (Exception e) {
                            resetDecoder();
                            out.add(invalidMessage(e));
                            return;
                        }
                    } else if (i != 2) {
                        if (i != 3) {
                            if (i != 4) {
                                if (i == 5) {
                                    in.skipBytes(actualReadableBytes());
                                    return;
                                }
                                throw new Error("Unknown state reached: " + this.state);
                            }
                            valueLength = (this.currentMessage.totalBodyLength() - this.currentMessage.keyLength()) - this.currentMessage.extrasLength();
                            int toRead = in.readableBytes();
                            if (valueLength > 0) {
                                if (toRead == 0) {
                                    return;
                                }
                                if (toRead > this.chunkSize) {
                                    toRead = this.chunkSize;
                                }
                                int remainingLength = valueLength - this.alreadyReadChunkSize;
                                if (toRead > remainingLength) {
                                    toRead = remainingLength;
                                }
                                ByteBuf chunkBuffer = in.readRetainedSlice(toRead);
                                int i2 = this.alreadyReadChunkSize + toRead;
                                this.alreadyReadChunkSize = i2;
                                if (i2 >= valueLength) {
                                    chunk = new DefaultLastMemcacheContent(chunkBuffer);
                                } else {
                                    chunk = new DefaultMemcacheContent(chunkBuffer);
                                }
                                out.add(chunk);
                                if (this.alreadyReadChunkSize < valueLength) {
                                    return;
                                }
                            } else {
                                out.add(LastMemcacheContent.EMPTY_LAST_CONTENT);
                            }
                            resetDecoder();
                            this.state = State.READ_HEADER;
                            return;
                        }
                        keyLength = this.currentMessage.keyLength();
                        if (keyLength > 0) {
                            if (in.readableBytes() < keyLength) {
                                return;
                            }
                            this.currentMessage.setKey(in.readRetainedSlice(keyLength));
                        }
                        out.add(this.currentMessage.retain());
                        this.state = State.READ_CONTENT;
                        valueLength = (this.currentMessage.totalBodyLength() - this.currentMessage.keyLength()) - this.currentMessage.extrasLength();
                        int toRead2 = in.readableBytes();
                        if (valueLength > 0) {
                        }
                        resetDecoder();
                        this.state = State.READ_HEADER;
                        return;
                    }
                    valueLength = (this.currentMessage.totalBodyLength() - this.currentMessage.keyLength()) - this.currentMessage.extrasLength();
                    int toRead22 = in.readableBytes();
                    if (valueLength > 0) {
                    }
                    resetDecoder();
                    this.state = State.READ_HEADER;
                    return;
                } catch (Exception e2) {
                    resetDecoder();
                    out.add(invalidChunk(e2));
                    return;
                }
                keyLength = this.currentMessage.keyLength();
                if (keyLength > 0) {
                }
                out.add(this.currentMessage.retain());
                this.state = State.READ_CONTENT;
            } catch (Exception e3) {
                resetDecoder();
                out.add(invalidMessage(e3));
                return;
            }
            byte extrasLength = this.currentMessage.extrasLength();
            if (extrasLength > 0) {
                if (in.readableBytes() < extrasLength) {
                    return;
                }
                this.currentMessage.setExtras(in.readRetainedSlice(extrasLength));
            }
            this.state = State.READ_KEY;
        } catch (Exception e4) {
            resetDecoder();
            out.add(invalidMessage(e4));
        }
    }

    private M invalidMessage(Exception cause) {
        this.state = State.BAD_MESSAGE;
        M message = buildInvalidMessage();
        message.setDecoderResult(DecoderResult.failure(cause));
        return message;
    }

    private MemcacheContent invalidChunk(Exception cause) {
        this.state = State.BAD_MESSAGE;
        MemcacheContent chunk = new DefaultLastMemcacheContent(Unpooled.EMPTY_BUFFER);
        chunk.setDecoderResult(DecoderResult.failure(cause));
        return chunk;
    }

    @Override // io.netty.handler.codec.ByteToMessageDecoder, io.netty.channel.ChannelInboundHandlerAdapter, io.netty.channel.ChannelInboundHandler
    public void channelInactive(ChannelHandlerContext ctx) throws Exception {
        super.channelInactive(ctx);
        resetDecoder();
    }

    protected void resetDecoder() {
        M m = this.currentMessage;
        if (m != null) {
            m.release();
            this.currentMessage = null;
        }
        this.alreadyReadChunkSize = 0;
    }
}
