package io.netty.handler.codec.mqtt;

import io.netty.buffer.ByteBuf;
import io.netty.channel.ChannelHandlerContext;
import io.netty.handler.codec.DecoderException;
import io.netty.handler.codec.ReplayingDecoder;
import io.netty.util.CharsetUtil;
import java.util.ArrayList;
import java.util.List;
/* loaded from: classes.dex */
public final class MqttDecoder extends ReplayingDecoder<DecoderState> {
    private static final int DEFAULT_MAX_BYTES_IN_MESSAGE = 8092;
    private int bytesRemainingInVariablePart;
    private final int maxBytesInMessage;
    private MqttFixedHeader mqttFixedHeader;
    private Object variableHeader;

    /* JADX INFO: Access modifiers changed from: package-private */
    /* loaded from: classes.dex */
    public enum DecoderState {
        READ_FIXED_HEADER,
        READ_VARIABLE_HEADER,
        READ_PAYLOAD,
        BAD_MESSAGE
    }

    public MqttDecoder() {
        this(DEFAULT_MAX_BYTES_IN_MESSAGE);
    }

    public MqttDecoder(int maxBytesInMessage) {
        super(DecoderState.READ_FIXED_HEADER);
        this.maxBytesInMessage = maxBytesInMessage;
    }

    /* JADX WARN: Removed duplicated region for block: B:19:0x0074 A[Catch: Exception -> 0x00bb, TryCatch #1 {Exception -> 0x00bb, blocks: (B:17:0x005b, B:19:0x0074, B:21:0x008f, B:22:0x00ba), top: B:36:0x005b }] */
    /* JADX WARN: Removed duplicated region for block: B:21:0x008f A[Catch: Exception -> 0x00bb, TryCatch #1 {Exception -> 0x00bb, blocks: (B:17:0x005b, B:19:0x0074, B:21:0x008f, B:22:0x00ba), top: B:36:0x005b }] */
    @Override // io.netty.handler.codec.ByteToMessageDecoder
    /*
        Code decompiled incorrectly, please refer to instructions dump.
    */
    protected void decode(ChannelHandlerContext ctx, ByteBuf buffer, List<Object> out) throws Exception {
        int i;
        int i2 = AnonymousClass1.$SwitchMap$io$netty$handler$codec$mqtt$MqttDecoder$DecoderState[state().ordinal()];
        try {
            if (i2 == 1) {
                try {
                    MqttFixedHeader decodeFixedHeader = decodeFixedHeader(buffer);
                    this.mqttFixedHeader = decodeFixedHeader;
                    this.bytesRemainingInVariablePart = decodeFixedHeader.remainingLength();
                    checkpoint(DecoderState.READ_VARIABLE_HEADER);
                } catch (Exception cause) {
                    out.add(invalidMessage(cause));
                    return;
                }
            } else if (i2 != 2) {
                if (i2 != 3) {
                    if (i2 == 4) {
                        buffer.skipBytes(actualReadableBytes());
                        return;
                    }
                    throw new Error();
                }
                try {
                    Result<?> decodedPayload = decodePayload(buffer, this.mqttFixedHeader.messageType(), this.bytesRemainingInVariablePart, this.variableHeader);
                    i = this.bytesRemainingInVariablePart - ((Result) decodedPayload).numberOfBytesConsumed;
                    this.bytesRemainingInVariablePart = i;
                    if (i == 0) {
                        throw new DecoderException("non-zero remaining payload bytes: " + this.bytesRemainingInVariablePart + " (" + this.mqttFixedHeader.messageType() + ')');
                    }
                    checkpoint(DecoderState.READ_FIXED_HEADER);
                    MqttMessage message = MqttMessageFactory.newMessage(this.mqttFixedHeader, this.variableHeader, ((Result) decodedPayload).value);
                    this.mqttFixedHeader = null;
                    this.variableHeader = null;
                    out.add(message);
                    return;
                } catch (Exception cause2) {
                    out.add(invalidMessage(cause2));
                    return;
                }
            }
            Result<?> decodedVariableHeader = decodeVariableHeader(buffer, this.mqttFixedHeader);
            this.variableHeader = ((Result) decodedVariableHeader).value;
            if (this.bytesRemainingInVariablePart > this.maxBytesInMessage) {
                throw new DecoderException("too large message: " + this.bytesRemainingInVariablePart + " bytes");
            }
            this.bytesRemainingInVariablePart -= ((Result) decodedVariableHeader).numberOfBytesConsumed;
            checkpoint(DecoderState.READ_PAYLOAD);
            Result<?> decodedPayload2 = decodePayload(buffer, this.mqttFixedHeader.messageType(), this.bytesRemainingInVariablePart, this.variableHeader);
            i = this.bytesRemainingInVariablePart - ((Result) decodedPayload2).numberOfBytesConsumed;
            this.bytesRemainingInVariablePart = i;
            if (i == 0) {
            }
        } catch (Exception cause3) {
            out.add(invalidMessage(cause3));
        }
    }

    private MqttMessage invalidMessage(Throwable cause) {
        checkpoint(DecoderState.BAD_MESSAGE);
        return MqttMessageFactory.newInvalidMessage(this.mqttFixedHeader, this.variableHeader, cause);
    }

    private static MqttFixedHeader decodeFixedHeader(ByteBuf buffer) {
        short digit;
        int remainingLength;
        int loops;
        short b1 = buffer.readUnsignedByte();
        MqttMessageType messageType = MqttMessageType.valueOf(b1 >> 4);
        boolean dupFlag = (b1 & 8) == 8;
        int qosLevel = (b1 & 6) >> 1;
        boolean retain = (b1 & 1) != 0;
        int remainingLength2 = 0;
        int multiplier = 1;
        int loops2 = 0;
        while (true) {
            digit = buffer.readUnsignedByte();
            remainingLength = ((digit & 127) * multiplier) + remainingLength2;
            int multiplier2 = multiplier * 128;
            loops = loops2 + 1;
            if ((digit & 128) == 0 || loops >= 4) {
                break;
            }
            remainingLength2 = remainingLength;
            multiplier = multiplier2;
            loops2 = loops;
        }
        if (loops == 4 && (digit & 128) != 0) {
            throw new DecoderException("remaining length exceeds 4 digits (" + messageType + ')');
        }
        MqttFixedHeader decodedFixedHeader = new MqttFixedHeader(messageType, dupFlag, MqttQoS.valueOf(qosLevel), retain, remainingLength);
        return MqttCodecUtil.validateFixedHeader(MqttCodecUtil.resetUnusedFields(decodedFixedHeader));
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    /* renamed from: io.netty.handler.codec.mqtt.MqttDecoder$1  reason: invalid class name */
    /* loaded from: classes.dex */
    public static /* synthetic */ class AnonymousClass1 {
        static final /* synthetic */ int[] $SwitchMap$io$netty$handler$codec$mqtt$MqttDecoder$DecoderState;
        static final /* synthetic */ int[] $SwitchMap$io$netty$handler$codec$mqtt$MqttMessageType;

        static {
            int[] iArr = new int[MqttMessageType.values().length];
            $SwitchMap$io$netty$handler$codec$mqtt$MqttMessageType = iArr;
            try {
                iArr[MqttMessageType.CONNECT.ordinal()] = 1;
            } catch (NoSuchFieldError e) {
            }
            try {
                $SwitchMap$io$netty$handler$codec$mqtt$MqttMessageType[MqttMessageType.CONNACK.ordinal()] = 2;
            } catch (NoSuchFieldError e2) {
            }
            try {
                $SwitchMap$io$netty$handler$codec$mqtt$MqttMessageType[MqttMessageType.SUBSCRIBE.ordinal()] = 3;
            } catch (NoSuchFieldError e3) {
            }
            try {
                $SwitchMap$io$netty$handler$codec$mqtt$MqttMessageType[MqttMessageType.UNSUBSCRIBE.ordinal()] = 4;
            } catch (NoSuchFieldError e4) {
            }
            try {
                $SwitchMap$io$netty$handler$codec$mqtt$MqttMessageType[MqttMessageType.SUBACK.ordinal()] = 5;
            } catch (NoSuchFieldError e5) {
            }
            try {
                $SwitchMap$io$netty$handler$codec$mqtt$MqttMessageType[MqttMessageType.UNSUBACK.ordinal()] = 6;
            } catch (NoSuchFieldError e6) {
            }
            try {
                $SwitchMap$io$netty$handler$codec$mqtt$MqttMessageType[MqttMessageType.PUBACK.ordinal()] = 7;
            } catch (NoSuchFieldError e7) {
            }
            try {
                $SwitchMap$io$netty$handler$codec$mqtt$MqttMessageType[MqttMessageType.PUBREC.ordinal()] = 8;
            } catch (NoSuchFieldError e8) {
            }
            try {
                $SwitchMap$io$netty$handler$codec$mqtt$MqttMessageType[MqttMessageType.PUBCOMP.ordinal()] = 9;
            } catch (NoSuchFieldError e9) {
            }
            try {
                $SwitchMap$io$netty$handler$codec$mqtt$MqttMessageType[MqttMessageType.PUBREL.ordinal()] = 10;
            } catch (NoSuchFieldError e10) {
            }
            try {
                $SwitchMap$io$netty$handler$codec$mqtt$MqttMessageType[MqttMessageType.PUBLISH.ordinal()] = 11;
            } catch (NoSuchFieldError e11) {
            }
            try {
                $SwitchMap$io$netty$handler$codec$mqtt$MqttMessageType[MqttMessageType.PINGREQ.ordinal()] = 12;
            } catch (NoSuchFieldError e12) {
            }
            try {
                $SwitchMap$io$netty$handler$codec$mqtt$MqttMessageType[MqttMessageType.PINGRESP.ordinal()] = 13;
            } catch (NoSuchFieldError e13) {
            }
            try {
                $SwitchMap$io$netty$handler$codec$mqtt$MqttMessageType[MqttMessageType.DISCONNECT.ordinal()] = 14;
            } catch (NoSuchFieldError e14) {
            }
            int[] iArr2 = new int[DecoderState.values().length];
            $SwitchMap$io$netty$handler$codec$mqtt$MqttDecoder$DecoderState = iArr2;
            try {
                iArr2[DecoderState.READ_FIXED_HEADER.ordinal()] = 1;
            } catch (NoSuchFieldError e15) {
            }
            try {
                $SwitchMap$io$netty$handler$codec$mqtt$MqttDecoder$DecoderState[DecoderState.READ_VARIABLE_HEADER.ordinal()] = 2;
            } catch (NoSuchFieldError e16) {
            }
            try {
                $SwitchMap$io$netty$handler$codec$mqtt$MqttDecoder$DecoderState[DecoderState.READ_PAYLOAD.ordinal()] = 3;
            } catch (NoSuchFieldError e17) {
            }
            try {
                $SwitchMap$io$netty$handler$codec$mqtt$MqttDecoder$DecoderState[DecoderState.BAD_MESSAGE.ordinal()] = 4;
            } catch (NoSuchFieldError e18) {
            }
        }
    }

    private static Result<?> decodeVariableHeader(ByteBuf buffer, MqttFixedHeader mqttFixedHeader) {
        switch (AnonymousClass1.$SwitchMap$io$netty$handler$codec$mqtt$MqttMessageType[mqttFixedHeader.messageType().ordinal()]) {
            case 1:
                return decodeConnectionVariableHeader(buffer);
            case 2:
                return decodeConnAckVariableHeader(buffer);
            case 3:
            case 4:
            case 5:
            case 6:
            case 7:
            case 8:
            case 9:
            case 10:
                return decodeMessageIdVariableHeader(buffer);
            case 11:
                return decodePublishVariableHeader(buffer, mqttFixedHeader);
            case 12:
            case 13:
            case 14:
                return new Result<>(null, 0);
            default:
                return new Result<>(null, 0);
        }
    }

    private static Result<MqttConnectVariableHeader> decodeConnectionVariableHeader(ByteBuf buffer) {
        Result<String> protoString = decodeString(buffer);
        int numberOfBytesConsumed = ((Result) protoString).numberOfBytesConsumed;
        byte protocolLevel = buffer.readByte();
        MqttVersion mqttVersion = MqttVersion.fromProtocolNameAndLevel((String) ((Result) protoString).value, protocolLevel);
        int b1 = buffer.readUnsignedByte();
        Result<Integer> keepAlive = decodeMsbLsb(buffer);
        int numberOfBytesConsumed2 = numberOfBytesConsumed + 1 + 1 + ((Result) keepAlive).numberOfBytesConsumed;
        boolean hasUserName = (b1 & 128) == 128;
        boolean hasPassword = (b1 & 64) == 64;
        boolean willRetain = (b1 & 32) == 32;
        int willQos = (b1 & 24) >> 3;
        boolean willFlag = (b1 & 4) == 4;
        boolean cleanSession = (b1 & 2) == 2;
        if (mqttVersion == MqttVersion.MQTT_3_1_1) {
            boolean zeroReservedFlag = (b1 & 1) == 0;
            if (!zeroReservedFlag) {
                throw new DecoderException("non-zero reserved flag");
            }
        }
        MqttConnectVariableHeader mqttConnectVariableHeader = new MqttConnectVariableHeader(mqttVersion.protocolName(), mqttVersion.protocolLevel(), hasUserName, hasPassword, willRetain, willQos, willFlag, cleanSession, ((Integer) ((Result) keepAlive).value).intValue());
        return new Result<>(mqttConnectVariableHeader, numberOfBytesConsumed2);
    }

    private static Result<MqttConnAckVariableHeader> decodeConnAckVariableHeader(ByteBuf buffer) {
        boolean sessionPresent = (buffer.readUnsignedByte() & 1) == 1;
        byte returnCode = buffer.readByte();
        MqttConnAckVariableHeader mqttConnAckVariableHeader = new MqttConnAckVariableHeader(MqttConnectReturnCode.valueOf(returnCode), sessionPresent);
        return new Result<>(mqttConnAckVariableHeader, 2);
    }

    private static Result<MqttMessageIdVariableHeader> decodeMessageIdVariableHeader(ByteBuf buffer) {
        Result<Integer> messageId = decodeMessageId(buffer);
        return new Result<>(MqttMessageIdVariableHeader.from(((Integer) ((Result) messageId).value).intValue()), ((Result) messageId).numberOfBytesConsumed);
    }

    private static Result<MqttPublishVariableHeader> decodePublishVariableHeader(ByteBuf buffer, MqttFixedHeader mqttFixedHeader) {
        Result<String> decodedTopic = decodeString(buffer);
        if (MqttCodecUtil.isValidPublishTopicName((String) ((Result) decodedTopic).value)) {
            int numberOfBytesConsumed = ((Result) decodedTopic).numberOfBytesConsumed;
            int messageId = -1;
            if (mqttFixedHeader.qosLevel().value() > 0) {
                Result<Integer> decodedMessageId = decodeMessageId(buffer);
                messageId = ((Integer) ((Result) decodedMessageId).value).intValue();
                numberOfBytesConsumed += ((Result) decodedMessageId).numberOfBytesConsumed;
            }
            MqttPublishVariableHeader mqttPublishVariableHeader = new MqttPublishVariableHeader((String) ((Result) decodedTopic).value, messageId);
            return new Result<>(mqttPublishVariableHeader, numberOfBytesConsumed);
        }
        throw new DecoderException("invalid publish topic name: " + ((String) ((Result) decodedTopic).value) + " (contains wildcards)");
    }

    private static Result<Integer> decodeMessageId(ByteBuf buffer) {
        Result<Integer> messageId = decodeMsbLsb(buffer);
        if (MqttCodecUtil.isValidMessageId(((Integer) ((Result) messageId).value).intValue())) {
            return messageId;
        }
        throw new DecoderException("invalid messageId: " + ((Result) messageId).value);
    }

    private static Result<?> decodePayload(ByteBuf buffer, MqttMessageType messageType, int bytesRemainingInVariablePart, Object variableHeader) {
        int i = AnonymousClass1.$SwitchMap$io$netty$handler$codec$mqtt$MqttMessageType[messageType.ordinal()];
        if (i != 1) {
            if (i != 11) {
                if (i != 3) {
                    if (i != 4) {
                        if (i == 5) {
                            return decodeSubackPayload(buffer, bytesRemainingInVariablePart);
                        }
                        return new Result<>(null, 0);
                    }
                    return decodeUnsubscribePayload(buffer, bytesRemainingInVariablePart);
                }
                return decodeSubscribePayload(buffer, bytesRemainingInVariablePart);
            }
            return decodePublishPayload(buffer, bytesRemainingInVariablePart);
        }
        return decodeConnectionPayload(buffer, (MqttConnectVariableHeader) variableHeader);
    }

    private static Result<MqttConnectPayload> decodeConnectionPayload(ByteBuf buffer, MqttConnectVariableHeader mqttConnectVariableHeader) {
        Result<String> decodedClientId = decodeString(buffer);
        String decodedClientIdValue = (String) ((Result) decodedClientId).value;
        MqttVersion mqttVersion = MqttVersion.fromProtocolNameAndLevel(mqttConnectVariableHeader.name(), (byte) mqttConnectVariableHeader.version());
        if (!MqttCodecUtil.isValidClientId(mqttVersion, decodedClientIdValue)) {
            throw new MqttIdentifierRejectedException("invalid clientIdentifier: " + decodedClientIdValue);
        }
        int numberOfBytesConsumed = ((Result) decodedClientId).numberOfBytesConsumed;
        Result<String> decodedWillTopic = null;
        Result<byte[]> decodedWillMessage = null;
        if (mqttConnectVariableHeader.isWillFlag()) {
            decodedWillTopic = decodeString(buffer, 0, 32767);
            decodedWillMessage = decodeByteArray(buffer);
            numberOfBytesConsumed = numberOfBytesConsumed + ((Result) decodedWillTopic).numberOfBytesConsumed + ((Result) decodedWillMessage).numberOfBytesConsumed;
        }
        Result<String> decodedUserName = null;
        Result<byte[]> decodedPassword = null;
        if (mqttConnectVariableHeader.hasUserName()) {
            decodedUserName = decodeString(buffer);
            numberOfBytesConsumed += ((Result) decodedUserName).numberOfBytesConsumed;
        }
        if (mqttConnectVariableHeader.hasPassword()) {
            decodedPassword = decodeByteArray(buffer);
            numberOfBytesConsumed += ((Result) decodedPassword).numberOfBytesConsumed;
        }
        MqttConnectPayload mqttConnectPayload = new MqttConnectPayload((String) ((Result) decodedClientId).value, decodedWillTopic != null ? (String) ((Result) decodedWillTopic).value : null, decodedWillMessage != null ? (byte[]) ((Result) decodedWillMessage).value : null, decodedUserName != null ? (String) ((Result) decodedUserName).value : null, decodedPassword != null ? (byte[]) ((Result) decodedPassword).value : null);
        return new Result<>(mqttConnectPayload, numberOfBytesConsumed);
    }

    private static Result<MqttSubscribePayload> decodeSubscribePayload(ByteBuf buffer, int bytesRemainingInVariablePart) {
        List<MqttTopicSubscription> subscribeTopics = new ArrayList<>();
        int numberOfBytesConsumed = 0;
        while (numberOfBytesConsumed < bytesRemainingInVariablePart) {
            Result<String> decodedTopicName = decodeString(buffer);
            int numberOfBytesConsumed2 = numberOfBytesConsumed + ((Result) decodedTopicName).numberOfBytesConsumed;
            int qos = buffer.readUnsignedByte() & 3;
            numberOfBytesConsumed = numberOfBytesConsumed2 + 1;
            subscribeTopics.add(new MqttTopicSubscription((String) ((Result) decodedTopicName).value, MqttQoS.valueOf(qos)));
        }
        return new Result<>(new MqttSubscribePayload(subscribeTopics), numberOfBytesConsumed);
    }

    private static Result<MqttSubAckPayload> decodeSubackPayload(ByteBuf buffer, int bytesRemainingInVariablePart) {
        List<Integer> grantedQos = new ArrayList<>();
        int numberOfBytesConsumed = 0;
        while (numberOfBytesConsumed < bytesRemainingInVariablePart) {
            int qos = buffer.readUnsignedByte();
            if (qos != MqttQoS.FAILURE.value()) {
                qos &= 3;
            }
            numberOfBytesConsumed++;
            grantedQos.add(Integer.valueOf(qos));
        }
        return new Result<>(new MqttSubAckPayload(grantedQos), numberOfBytesConsumed);
    }

    private static Result<MqttUnsubscribePayload> decodeUnsubscribePayload(ByteBuf buffer, int bytesRemainingInVariablePart) {
        ArrayList arrayList = new ArrayList();
        int numberOfBytesConsumed = 0;
        while (numberOfBytesConsumed < bytesRemainingInVariablePart) {
            Result<String> decodedTopicName = decodeString(buffer);
            numberOfBytesConsumed += ((Result) decodedTopicName).numberOfBytesConsumed;
            arrayList.add(((Result) decodedTopicName).value);
        }
        return new Result<>(new MqttUnsubscribePayload(arrayList), numberOfBytesConsumed);
    }

    private static Result<ByteBuf> decodePublishPayload(ByteBuf buffer, int bytesRemainingInVariablePart) {
        ByteBuf b = buffer.readRetainedSlice(bytesRemainingInVariablePart);
        return new Result<>(b, bytesRemainingInVariablePart);
    }

    private static Result<String> decodeString(ByteBuf buffer) {
        return decodeString(buffer, 0, Integer.MAX_VALUE);
    }

    private static Result<String> decodeString(ByteBuf buffer, int minBytes, int maxBytes) {
        Result<Integer> decodedSize = decodeMsbLsb(buffer);
        int size = ((Integer) ((Result) decodedSize).value).intValue();
        int numberOfBytesConsumed = ((Result) decodedSize).numberOfBytesConsumed;
        if (size < minBytes || size > maxBytes) {
            buffer.skipBytes(size);
            return new Result<>(null, numberOfBytesConsumed + size);
        }
        String s = buffer.toString(buffer.readerIndex(), size, CharsetUtil.UTF_8);
        buffer.skipBytes(size);
        return new Result<>(s, numberOfBytesConsumed + size);
    }

    private static Result<byte[]> decodeByteArray(ByteBuf buffer) {
        Result<Integer> decodedSize = decodeMsbLsb(buffer);
        int size = ((Integer) ((Result) decodedSize).value).intValue();
        byte[] bytes = new byte[size];
        buffer.readBytes(bytes);
        return new Result<>(bytes, ((Result) decodedSize).numberOfBytesConsumed + size);
    }

    private static Result<Integer> decodeMsbLsb(ByteBuf buffer) {
        return decodeMsbLsb(buffer, 0, 65535);
    }

    private static Result<Integer> decodeMsbLsb(ByteBuf buffer, int min, int max) {
        short msbSize = buffer.readUnsignedByte();
        short lsbSize = buffer.readUnsignedByte();
        int result = (msbSize << 8) | lsbSize;
        result = (result < min || result > max) ? -1 : -1;
        return new Result<>(Integer.valueOf(result), 2);
    }

    /* JADX INFO: Access modifiers changed from: private */
    /* loaded from: classes.dex */
    public static final class Result<T> {
        private final int numberOfBytesConsumed;
        private final T value;

        Result(T value, int numberOfBytesConsumed) {
            this.value = value;
            this.numberOfBytesConsumed = numberOfBytesConsumed;
        }
    }
}
