package io.netty.handler.codec.redis;

import io.netty.buffer.ByteBuf;
import io.netty.channel.ChannelHandlerContext;
import io.netty.handler.codec.ByteToMessageDecoder;
import io.netty.util.ByteProcessor;
import io.netty.util.CharsetUtil;
import java.util.List;
/* loaded from: classes.dex */
public final class RedisDecoder extends ByteToMessageDecoder {
    private final boolean decodeInlineCommands;
    private final int maxInlineMessageLength;
    private final RedisMessagePool messagePool;
    private int remainingBulkLength;
    private State state;
    private final ToPositiveLongProcessor toPositiveLongProcessor;
    private RedisMessageType type;

    /* JADX INFO: Access modifiers changed from: private */
    /* loaded from: classes.dex */
    public enum State {
        DECODE_TYPE,
        DECODE_INLINE,
        DECODE_LENGTH,
        DECODE_BULK_STRING_EOL,
        DECODE_BULK_STRING_CONTENT
    }

    public RedisDecoder() {
        this(false);
    }

    public RedisDecoder(boolean decodeInlineCommands) {
        this(65536, FixedRedisMessagePool.INSTANCE, decodeInlineCommands);
    }

    public RedisDecoder(int maxInlineMessageLength, RedisMessagePool messagePool) {
        this(maxInlineMessageLength, messagePool, false);
    }

    public RedisDecoder(int maxInlineMessageLength, RedisMessagePool messagePool, boolean decodeInlineCommands) {
        this.toPositiveLongProcessor = new ToPositiveLongProcessor(null);
        this.state = State.DECODE_TYPE;
        if (maxInlineMessageLength <= 0 || maxInlineMessageLength > 536870912) {
            throw new RedisCodecException("maxInlineMessageLength: " + maxInlineMessageLength + " (expected: <= 536870912)");
        }
        this.maxInlineMessageLength = maxInlineMessageLength;
        this.messagePool = messagePool;
        this.decodeInlineCommands = decodeInlineCommands;
    }

    /* JADX WARN: Code restructure failed: missing block: B:16:0x0038, code lost:
        throw new io.netty.handler.codec.redis.RedisCodecException("Unknown state: " + r3.state);
     */
    @Override // io.netty.handler.codec.ByteToMessageDecoder
    /*
        Code decompiled incorrectly, please refer to instructions dump.
    */
    protected void decode(ChannelHandlerContext ctx, ByteBuf in, List<Object> out) throws Exception {
        while (true) {
            try {
                int i = AnonymousClass1.$SwitchMap$io$netty$handler$codec$redis$RedisDecoder$State[this.state.ordinal()];
                if (i != 1) {
                    if (i != 2) {
                        if (i != 3) {
                            if (i != 4) {
                                if (i != 5) {
                                    break;
                                } else if (!decodeBulkStringContent(in, out)) {
                                    return;
                                }
                            } else if (!decodeBulkStringEndOfLine(in, out)) {
                                return;
                            }
                        } else if (!decodeLength(in, out)) {
                            return;
                        }
                    } else if (!decodeInline(in, out)) {
                        return;
                    }
                } else if (!decodeType(in)) {
                    return;
                }
            } catch (RedisCodecException e) {
                resetDecoder();
                throw e;
            } catch (Exception e2) {
                resetDecoder();
                throw new RedisCodecException(e2);
            }
        }
    }

    private void resetDecoder() {
        this.state = State.DECODE_TYPE;
        this.remainingBulkLength = 0;
    }

    private boolean decodeType(ByteBuf in) throws Exception {
        if (!in.isReadable()) {
            return false;
        }
        RedisMessageType readFrom = RedisMessageType.readFrom(in, this.decodeInlineCommands);
        this.type = readFrom;
        this.state = readFrom.isInline() ? State.DECODE_INLINE : State.DECODE_LENGTH;
        return true;
    }

    private boolean decodeInline(ByteBuf in, List<Object> out) throws Exception {
        ByteBuf lineBytes = readLine(in);
        if (lineBytes == null) {
            if (in.readableBytes() > this.maxInlineMessageLength) {
                throw new RedisCodecException("length: " + in.readableBytes() + " (expected: <= " + this.maxInlineMessageLength + ")");
            }
            return false;
        }
        out.add(newInlineRedisMessage(this.type, lineBytes));
        resetDecoder();
        return true;
    }

    private boolean decodeLength(ByteBuf in, List<Object> out) throws Exception {
        ByteBuf lineByteBuf = readLine(in);
        if (lineByteBuf == null) {
            return false;
        }
        long length = parseRedisNumber(lineByteBuf);
        if (length < -1) {
            throw new RedisCodecException("length: " + length + " (expected: >= -1)");
        }
        int i = AnonymousClass1.$SwitchMap$io$netty$handler$codec$redis$RedisMessageType[this.type.ordinal()];
        if (i == 1) {
            out.add(new ArrayHeaderRedisMessage(length));
            resetDecoder();
            return true;
        } else if (i == 2) {
            if (length > 536870912) {
                throw new RedisCodecException("length: " + length + " (expected: <= 536870912)");
            }
            this.remainingBulkLength = (int) length;
            return decodeBulkString(in, out);
        } else {
            throw new RedisCodecException("bad type: " + this.type);
        }
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    /* renamed from: io.netty.handler.codec.redis.RedisDecoder$1  reason: invalid class name */
    /* loaded from: classes.dex */
    public static /* synthetic */ class AnonymousClass1 {
        static final /* synthetic */ int[] $SwitchMap$io$netty$handler$codec$redis$RedisDecoder$State;
        static final /* synthetic */ int[] $SwitchMap$io$netty$handler$codec$redis$RedisMessageType;

        static {
            int[] iArr = new int[RedisMessageType.values().length];
            $SwitchMap$io$netty$handler$codec$redis$RedisMessageType = iArr;
            try {
                iArr[RedisMessageType.ARRAY_HEADER.ordinal()] = 1;
            } catch (NoSuchFieldError e) {
            }
            try {
                $SwitchMap$io$netty$handler$codec$redis$RedisMessageType[RedisMessageType.BULK_STRING.ordinal()] = 2;
            } catch (NoSuchFieldError e2) {
            }
            try {
                $SwitchMap$io$netty$handler$codec$redis$RedisMessageType[RedisMessageType.INLINE_COMMAND.ordinal()] = 3;
            } catch (NoSuchFieldError e3) {
            }
            try {
                $SwitchMap$io$netty$handler$codec$redis$RedisMessageType[RedisMessageType.SIMPLE_STRING.ordinal()] = 4;
            } catch (NoSuchFieldError e4) {
            }
            try {
                $SwitchMap$io$netty$handler$codec$redis$RedisMessageType[RedisMessageType.ERROR.ordinal()] = 5;
            } catch (NoSuchFieldError e5) {
            }
            try {
                $SwitchMap$io$netty$handler$codec$redis$RedisMessageType[RedisMessageType.INTEGER.ordinal()] = 6;
            } catch (NoSuchFieldError e6) {
            }
            int[] iArr2 = new int[State.values().length];
            $SwitchMap$io$netty$handler$codec$redis$RedisDecoder$State = iArr2;
            try {
                iArr2[State.DECODE_TYPE.ordinal()] = 1;
            } catch (NoSuchFieldError e7) {
            }
            try {
                $SwitchMap$io$netty$handler$codec$redis$RedisDecoder$State[State.DECODE_INLINE.ordinal()] = 2;
            } catch (NoSuchFieldError e8) {
            }
            try {
                $SwitchMap$io$netty$handler$codec$redis$RedisDecoder$State[State.DECODE_LENGTH.ordinal()] = 3;
            } catch (NoSuchFieldError e9) {
            }
            try {
                $SwitchMap$io$netty$handler$codec$redis$RedisDecoder$State[State.DECODE_BULK_STRING_EOL.ordinal()] = 4;
            } catch (NoSuchFieldError e10) {
            }
            try {
                $SwitchMap$io$netty$handler$codec$redis$RedisDecoder$State[State.DECODE_BULK_STRING_CONTENT.ordinal()] = 5;
            } catch (NoSuchFieldError e11) {
            }
        }
    }

    private boolean decodeBulkString(ByteBuf in, List<Object> out) throws Exception {
        int i = this.remainingBulkLength;
        if (i == -1) {
            out.add(FullBulkStringRedisMessage.NULL_INSTANCE);
            resetDecoder();
            return true;
        } else if (i == 0) {
            this.state = State.DECODE_BULK_STRING_EOL;
            return decodeBulkStringEndOfLine(in, out);
        } else {
            out.add(new BulkStringHeaderRedisMessage(i));
            this.state = State.DECODE_BULK_STRING_CONTENT;
            return decodeBulkStringContent(in, out);
        }
    }

    private boolean decodeBulkStringEndOfLine(ByteBuf in, List<Object> out) throws Exception {
        if (in.readableBytes() < 2) {
            return false;
        }
        readEndOfLine(in);
        out.add(FullBulkStringRedisMessage.EMPTY_INSTANCE);
        resetDecoder();
        return true;
    }

    private boolean decodeBulkStringContent(ByteBuf in, List<Object> out) throws Exception {
        int readableBytes = in.readableBytes();
        if (readableBytes != 0) {
            if (this.remainingBulkLength == 0 && readableBytes < 2) {
                return false;
            }
            int i = this.remainingBulkLength;
            if (readableBytes >= i + 2) {
                ByteBuf content = in.readSlice(i);
                readEndOfLine(in);
                out.add(new DefaultLastBulkStringRedisContent(content.retain()));
                resetDecoder();
                return true;
            }
            int toRead = Math.min(i, readableBytes);
            this.remainingBulkLength -= toRead;
            out.add(new DefaultBulkStringRedisContent(in.readSlice(toRead).retain()));
            return true;
        }
        return false;
    }

    private static void readEndOfLine(ByteBuf in) {
        short delim = in.readShort();
        if (RedisConstants.EOL_SHORT == delim) {
            return;
        }
        byte[] bytes = RedisCodecUtil.shortToBytes(delim);
        throw new RedisCodecException("delimiter: [" + ((int) bytes[0]) + "," + ((int) bytes[1]) + "] (expected: \\r\\n)");
    }

    private RedisMessage newInlineRedisMessage(RedisMessageType messageType, ByteBuf content) {
        int i = AnonymousClass1.$SwitchMap$io$netty$handler$codec$redis$RedisMessageType[messageType.ordinal()];
        if (i != 3) {
            if (i == 4) {
                SimpleStringRedisMessage cached = this.messagePool.getSimpleString(content);
                return cached != null ? cached : new SimpleStringRedisMessage(content.toString(CharsetUtil.UTF_8));
            } else if (i == 5) {
                ErrorRedisMessage cached2 = this.messagePool.getError(content);
                return cached2 != null ? cached2 : new ErrorRedisMessage(content.toString(CharsetUtil.UTF_8));
            } else if (i == 6) {
                IntegerRedisMessage cached3 = this.messagePool.getInteger(content);
                return cached3 != null ? cached3 : new IntegerRedisMessage(parseRedisNumber(content));
            } else {
                throw new RedisCodecException("bad type: " + messageType);
            }
        }
        return new InlineCommandRedisMessage(content.toString(CharsetUtil.UTF_8));
    }

    private static ByteBuf readLine(ByteBuf in) {
        int lfIndex;
        if (in.isReadable(2) && (lfIndex = in.forEachByte(ByteProcessor.FIND_LF)) >= 0) {
            ByteBuf data = in.readSlice((lfIndex - in.readerIndex()) - 1);
            readEndOfLine(in);
            return data;
        }
        return null;
    }

    private long parseRedisNumber(ByteBuf byteBuf) {
        int readableBytes = byteBuf.readableBytes();
        boolean negative = readableBytes > 0 && byteBuf.getByte(byteBuf.readerIndex()) == 45;
        int extraOneByteForNegative = negative ? 1 : 0;
        if (readableBytes <= extraOneByteForNegative) {
            throw new RedisCodecException("no number to parse: " + byteBuf.toString(CharsetUtil.US_ASCII));
        } else if (readableBytes > extraOneByteForNegative + 19) {
            throw new RedisCodecException("too many characters to be a valid RESP Integer: " + byteBuf.toString(CharsetUtil.US_ASCII));
        } else if (negative) {
            return -parsePositiveNumber(byteBuf.skipBytes(extraOneByteForNegative));
        } else {
            return parsePositiveNumber(byteBuf);
        }
    }

    private long parsePositiveNumber(ByteBuf byteBuf) {
        this.toPositiveLongProcessor.reset();
        byteBuf.forEachByte(this.toPositiveLongProcessor);
        return this.toPositiveLongProcessor.content();
    }

    /* JADX INFO: Access modifiers changed from: private */
    /* loaded from: classes.dex */
    public static final class ToPositiveLongProcessor implements ByteProcessor {
        private long result;

        private ToPositiveLongProcessor() {
        }

        /* synthetic */ ToPositiveLongProcessor(AnonymousClass1 x0) {
            this();
        }

        @Override // io.netty.util.ByteProcessor
        public boolean process(byte value) throws Exception {
            if (value < 48 || value > 57) {
                throw new RedisCodecException("bad byte in number: " + ((int) value));
            }
            this.result = (this.result * 10) + (value - 48);
            return true;
        }

        public long content() {
            return this.result;
        }

        public void reset() {
            this.result = 0L;
        }
    }
}
