package io.netty.handler.codec.redis;

import com.gyh.wifidata.common.MessageDecoder;
import io.netty.buffer.ByteBuf;
import io.netty.handler.codec.http.HttpConstants;
import io.netty.handler.codec.memcache.binary.BinaryMemcacheOpcodes;
/* loaded from: classes.dex */
public enum RedisMessageType {
    INLINE_COMMAND(null, true),
    SIMPLE_STRING((byte) 43, true),
    ERROR((byte) 45, true),
    INTEGER(Byte.valueOf((byte) HttpConstants.COLON), true),
    BULK_STRING(Byte.valueOf((byte) BinaryMemcacheOpcodes.GATKQ), false),
    ARRAY_HEADER(Byte.valueOf((byte) MessageDecoder.END), false);
    
    private final boolean inline;
    private final Byte value;

    RedisMessageType(Byte value, boolean inline) {
        this.value = value;
        this.inline = inline;
    }

    public int length() {
        return this.value != null ? 1 : 0;
    }

    public boolean isInline() {
        return this.inline;
    }

    public static RedisMessageType readFrom(ByteBuf in, boolean decodeInlineCommands) {
        int initialIndex = in.readerIndex();
        RedisMessageType type = valueOf(in.readByte());
        if (type == INLINE_COMMAND) {
            if (!decodeInlineCommands) {
                throw new RedisCodecException("Decoding of inline commands is disabled");
            }
            in.readerIndex(initialIndex);
        }
        return type;
    }

    public void writeTo(ByteBuf out) {
        Byte b = this.value;
        if (b == null) {
            return;
        }
        out.writeByte(b.byteValue());
    }

    private static RedisMessageType valueOf(byte value) {
        if (value != 36) {
            if (value != 45) {
                if (value != 58) {
                    if (value != 42) {
                        if (value == 43) {
                            return SIMPLE_STRING;
                        }
                        return INLINE_COMMAND;
                    }
                    return ARRAY_HEADER;
                }
                return INTEGER;
            }
            return ERROR;
        }
        return BULK_STRING;
    }
}
