package io.netty.handler.codec.spdy;

import io.netty.buffer.ByteBuf;
import io.netty.buffer.Unpooled;
import io.netty.util.internal.ObjectUtil;
/* loaded from: classes.dex */
public class SpdyFrameDecoder {
    private final SpdyFrameDecoderDelegate delegate;
    private byte flags;
    private int length;
    private final int maxChunkSize;
    private int numSettings;
    private final int spdyVersion;
    private State state;
    private int streamId;

    /* JADX INFO: Access modifiers changed from: private */
    /* loaded from: classes.dex */
    public enum State {
        READ_COMMON_HEADER,
        READ_DATA_FRAME,
        READ_SYN_STREAM_FRAME,
        READ_SYN_REPLY_FRAME,
        READ_RST_STREAM_FRAME,
        READ_SETTINGS_FRAME,
        READ_SETTING,
        READ_PING_FRAME,
        READ_GOAWAY_FRAME,
        READ_HEADERS_FRAME,
        READ_WINDOW_UPDATE_FRAME,
        READ_HEADER_BLOCK,
        DISCARD_FRAME,
        FRAME_ERROR
    }

    public SpdyFrameDecoder(SpdyVersion spdyVersion, SpdyFrameDecoderDelegate delegate) {
        this(spdyVersion, delegate, 8192);
    }

    public SpdyFrameDecoder(SpdyVersion spdyVersion, SpdyFrameDecoderDelegate delegate, int maxChunkSize) {
        this.spdyVersion = ((SpdyVersion) ObjectUtil.checkNotNull(spdyVersion, "spdyVersion")).getVersion();
        this.delegate = (SpdyFrameDecoderDelegate) ObjectUtil.checkNotNull(delegate, "delegate");
        this.maxChunkSize = ObjectUtil.checkPositive(maxChunkSize, "maxChunkSize");
        this.state = State.READ_COMMON_HEADER;
    }

    /* renamed from: io.netty.handler.codec.spdy.SpdyFrameDecoder$1  reason: invalid class name */
    /* loaded from: classes.dex */
    static /* synthetic */ class AnonymousClass1 {
        static final /* synthetic */ int[] $SwitchMap$io$netty$handler$codec$spdy$SpdyFrameDecoder$State;

        static {
            int[] iArr = new int[State.values().length];
            $SwitchMap$io$netty$handler$codec$spdy$SpdyFrameDecoder$State = iArr;
            try {
                iArr[State.READ_COMMON_HEADER.ordinal()] = 1;
            } catch (NoSuchFieldError e) {
            }
            try {
                $SwitchMap$io$netty$handler$codec$spdy$SpdyFrameDecoder$State[State.READ_DATA_FRAME.ordinal()] = 2;
            } catch (NoSuchFieldError e2) {
            }
            try {
                $SwitchMap$io$netty$handler$codec$spdy$SpdyFrameDecoder$State[State.READ_SYN_STREAM_FRAME.ordinal()] = 3;
            } catch (NoSuchFieldError e3) {
            }
            try {
                $SwitchMap$io$netty$handler$codec$spdy$SpdyFrameDecoder$State[State.READ_SYN_REPLY_FRAME.ordinal()] = 4;
            } catch (NoSuchFieldError e4) {
            }
            try {
                $SwitchMap$io$netty$handler$codec$spdy$SpdyFrameDecoder$State[State.READ_RST_STREAM_FRAME.ordinal()] = 5;
            } catch (NoSuchFieldError e5) {
            }
            try {
                $SwitchMap$io$netty$handler$codec$spdy$SpdyFrameDecoder$State[State.READ_SETTINGS_FRAME.ordinal()] = 6;
            } catch (NoSuchFieldError e6) {
            }
            try {
                $SwitchMap$io$netty$handler$codec$spdy$SpdyFrameDecoder$State[State.READ_SETTING.ordinal()] = 7;
            } catch (NoSuchFieldError e7) {
            }
            try {
                $SwitchMap$io$netty$handler$codec$spdy$SpdyFrameDecoder$State[State.READ_PING_FRAME.ordinal()] = 8;
            } catch (NoSuchFieldError e8) {
            }
            try {
                $SwitchMap$io$netty$handler$codec$spdy$SpdyFrameDecoder$State[State.READ_GOAWAY_FRAME.ordinal()] = 9;
            } catch (NoSuchFieldError e9) {
            }
            try {
                $SwitchMap$io$netty$handler$codec$spdy$SpdyFrameDecoder$State[State.READ_HEADERS_FRAME.ordinal()] = 10;
            } catch (NoSuchFieldError e10) {
            }
            try {
                $SwitchMap$io$netty$handler$codec$spdy$SpdyFrameDecoder$State[State.READ_WINDOW_UPDATE_FRAME.ordinal()] = 11;
            } catch (NoSuchFieldError e11) {
            }
            try {
                $SwitchMap$io$netty$handler$codec$spdy$SpdyFrameDecoder$State[State.READ_HEADER_BLOCK.ordinal()] = 12;
            } catch (NoSuchFieldError e12) {
            }
            try {
                $SwitchMap$io$netty$handler$codec$spdy$SpdyFrameDecoder$State[State.DISCARD_FRAME.ordinal()] = 13;
            } catch (NoSuchFieldError e13) {
            }
            try {
                $SwitchMap$io$netty$handler$codec$spdy$SpdyFrameDecoder$State[State.FRAME_ERROR.ordinal()] = 14;
            } catch (NoSuchFieldError e14) {
            }
        }
    }

    public void decode(ByteBuf buffer) {
        int version;
        int type;
        while (true) {
            boolean last = false;
            switch (AnonymousClass1.$SwitchMap$io$netty$handler$codec$spdy$SpdyFrameDecoder$State[this.state.ordinal()]) {
                case 1:
                    if (buffer.readableBytes() < 8) {
                        return;
                    }
                    int frameOffset = buffer.readerIndex();
                    int flagsOffset = frameOffset + 4;
                    int lengthOffset = frameOffset + 5;
                    buffer.skipBytes(8);
                    boolean control = (buffer.getByte(frameOffset) & 128) != 0;
                    if (control) {
                        version = SpdyCodecUtil.getUnsignedShort(buffer, frameOffset) & 32767;
                        type = SpdyCodecUtil.getUnsignedShort(buffer, frameOffset + 2);
                        this.streamId = 0;
                    } else {
                        version = this.spdyVersion;
                        type = 0;
                        this.streamId = SpdyCodecUtil.getUnsignedInt(buffer, frameOffset);
                    }
                    this.flags = buffer.getByte(flagsOffset);
                    int unsignedMedium = SpdyCodecUtil.getUnsignedMedium(buffer, lengthOffset);
                    this.length = unsignedMedium;
                    if (version != this.spdyVersion) {
                        this.state = State.FRAME_ERROR;
                        this.delegate.readFrameError("Invalid SPDY Version");
                        break;
                    } else if (!isValidFrameHeader(this.streamId, type, this.flags, unsignedMedium)) {
                        this.state = State.FRAME_ERROR;
                        this.delegate.readFrameError("Invalid Frame Error");
                        break;
                    } else {
                        this.state = getNextState(type, this.length);
                        break;
                    }
                case 2:
                    int offset = this.length;
                    if (offset == 0) {
                        this.state = State.READ_COMMON_HEADER;
                        this.delegate.readDataFrame(this.streamId, hasFlag(this.flags, (byte) 1), Unpooled.buffer(0));
                        break;
                    } else {
                        int dataLength = Math.min(this.maxChunkSize, offset);
                        if (buffer.readableBytes() < dataLength) {
                            return;
                        }
                        ByteBuf data = buffer.alloc().buffer(dataLength);
                        data.writeBytes(buffer, dataLength);
                        int i = this.length - dataLength;
                        this.length = i;
                        if (i == 0) {
                            this.state = State.READ_COMMON_HEADER;
                        }
                        if (this.length == 0 && hasFlag(this.flags, (byte) 1)) {
                            last = true;
                        }
                        this.delegate.readDataFrame(this.streamId, last, data);
                        break;
                    }
                case 3:
                    if (buffer.readableBytes() < 10) {
                        return;
                    }
                    int offset2 = buffer.readerIndex();
                    this.streamId = SpdyCodecUtil.getUnsignedInt(buffer, offset2);
                    int associatedToStreamId = SpdyCodecUtil.getUnsignedInt(buffer, offset2 + 4);
                    byte priority = (byte) ((buffer.getByte(offset2 + 8) >> 5) & 7);
                    boolean last2 = hasFlag(this.flags, (byte) 1);
                    boolean unidirectional = hasFlag(this.flags, (byte) 2);
                    buffer.skipBytes(10);
                    this.length -= 10;
                    if (this.streamId == 0) {
                        this.state = State.FRAME_ERROR;
                        this.delegate.readFrameError("Invalid SYN_STREAM Frame");
                        break;
                    } else {
                        this.state = State.READ_HEADER_BLOCK;
                        this.delegate.readSynStreamFrame(this.streamId, associatedToStreamId, priority, last2, unidirectional);
                        break;
                    }
                case 4:
                    if (buffer.readableBytes() < 4) {
                        return;
                    }
                    this.streamId = SpdyCodecUtil.getUnsignedInt(buffer, buffer.readerIndex());
                    boolean last3 = hasFlag(this.flags, (byte) 1);
                    buffer.skipBytes(4);
                    this.length -= 4;
                    if (this.streamId == 0) {
                        this.state = State.FRAME_ERROR;
                        this.delegate.readFrameError("Invalid SYN_REPLY Frame");
                        break;
                    } else {
                        this.state = State.READ_HEADER_BLOCK;
                        this.delegate.readSynReplyFrame(this.streamId, last3);
                        break;
                    }
                case 5:
                    if (buffer.readableBytes() < 8) {
                        return;
                    }
                    this.streamId = SpdyCodecUtil.getUnsignedInt(buffer, buffer.readerIndex());
                    int statusCode = SpdyCodecUtil.getSignedInt(buffer, buffer.readerIndex() + 4);
                    buffer.skipBytes(8);
                    if (this.streamId == 0 || statusCode == 0) {
                        this.state = State.FRAME_ERROR;
                        this.delegate.readFrameError("Invalid RST_STREAM Frame");
                        break;
                    } else {
                        this.state = State.READ_COMMON_HEADER;
                        this.delegate.readRstStreamFrame(this.streamId, statusCode);
                        break;
                    }
                case 6:
                    if (buffer.readableBytes() < 4) {
                        return;
                    }
                    boolean clear = hasFlag(this.flags, (byte) 1);
                    this.numSettings = SpdyCodecUtil.getUnsignedInt(buffer, buffer.readerIndex());
                    buffer.skipBytes(4);
                    int i2 = this.length - 4;
                    this.length = i2;
                    if ((i2 & 7) != 0 || (i2 >> 3) != this.numSettings) {
                        this.state = State.FRAME_ERROR;
                        this.delegate.readFrameError("Invalid SETTINGS Frame");
                        break;
                    } else {
                        this.state = State.READ_SETTING;
                        this.delegate.readSettingsFrame(clear);
                        break;
                    }
                case 7:
                    int pingId = this.numSettings;
                    if (pingId == 0) {
                        this.state = State.READ_COMMON_HEADER;
                        this.delegate.readSettingsEnd();
                        break;
                    } else if (buffer.readableBytes() < 8) {
                        return;
                    } else {
                        byte settingsFlags = buffer.getByte(buffer.readerIndex());
                        int id = SpdyCodecUtil.getUnsignedMedium(buffer, buffer.readerIndex() + 1);
                        int value = SpdyCodecUtil.getSignedInt(buffer, buffer.readerIndex() + 4);
                        boolean persistValue = hasFlag(settingsFlags, (byte) 1);
                        boolean persisted = hasFlag(settingsFlags, (byte) 2);
                        buffer.skipBytes(8);
                        this.numSettings--;
                        this.delegate.readSetting(id, value, persistValue, persisted);
                        break;
                    }
                case 8:
                    int lastGoodStreamId = buffer.readableBytes();
                    if (lastGoodStreamId < 4) {
                        return;
                    }
                    int pingId2 = SpdyCodecUtil.getSignedInt(buffer, buffer.readerIndex());
                    buffer.skipBytes(4);
                    this.state = State.READ_COMMON_HEADER;
                    this.delegate.readPingFrame(pingId2);
                    break;
                case 9:
                    if (buffer.readableBytes() < 8) {
                        return;
                    }
                    int lastGoodStreamId2 = SpdyCodecUtil.getUnsignedInt(buffer, buffer.readerIndex());
                    int statusCode2 = SpdyCodecUtil.getSignedInt(buffer, buffer.readerIndex() + 4);
                    buffer.skipBytes(8);
                    this.state = State.READ_COMMON_HEADER;
                    this.delegate.readGoAwayFrame(lastGoodStreamId2, statusCode2);
                    break;
                case 10:
                    if (buffer.readableBytes() < 4) {
                        return;
                    }
                    this.streamId = SpdyCodecUtil.getUnsignedInt(buffer, buffer.readerIndex());
                    boolean last4 = hasFlag(this.flags, (byte) 1);
                    buffer.skipBytes(4);
                    this.length -= 4;
                    if (this.streamId == 0) {
                        this.state = State.FRAME_ERROR;
                        this.delegate.readFrameError("Invalid HEADERS Frame");
                        break;
                    } else {
                        this.state = State.READ_HEADER_BLOCK;
                        this.delegate.readHeadersFrame(this.streamId, last4);
                        break;
                    }
                case 11:
                    if (buffer.readableBytes() < 8) {
                        return;
                    }
                    this.streamId = SpdyCodecUtil.getUnsignedInt(buffer, buffer.readerIndex());
                    int deltaWindowSize = SpdyCodecUtil.getUnsignedInt(buffer, buffer.readerIndex() + 4);
                    buffer.skipBytes(8);
                    if (deltaWindowSize == 0) {
                        this.state = State.FRAME_ERROR;
                        this.delegate.readFrameError("Invalid WINDOW_UPDATE Frame");
                        break;
                    } else {
                        this.state = State.READ_COMMON_HEADER;
                        this.delegate.readWindowUpdateFrame(this.streamId, deltaWindowSize);
                        break;
                    }
                case 12:
                    if (this.length == 0) {
                        this.state = State.READ_COMMON_HEADER;
                        this.delegate.readHeaderBlockEnd();
                        break;
                    } else if (!buffer.isReadable()) {
                        return;
                    } else {
                        int compressedBytes = Math.min(buffer.readableBytes(), this.length);
                        ByteBuf headerBlock = buffer.alloc().buffer(compressedBytes);
                        headerBlock.writeBytes(buffer, compressedBytes);
                        this.length -= compressedBytes;
                        this.delegate.readHeaderBlock(headerBlock);
                        break;
                    }
                case 13:
                    int numBytes = Math.min(buffer.readableBytes(), this.length);
                    buffer.skipBytes(numBytes);
                    int i3 = this.length - numBytes;
                    this.length = i3;
                    if (i3 == 0) {
                        this.state = State.READ_COMMON_HEADER;
                        break;
                    } else {
                        return;
                    }
                case 14:
                    buffer.skipBytes(buffer.readableBytes());
                    return;
                default:
                    throw new Error("Shouldn't reach here.");
            }
        }
    }

    private static boolean hasFlag(byte flags, byte flag) {
        return (flags & flag) != 0;
    }

    private static State getNextState(int type, int length) {
        switch (type) {
            case 0:
                return State.READ_DATA_FRAME;
            case 1:
                return State.READ_SYN_STREAM_FRAME;
            case 2:
                return State.READ_SYN_REPLY_FRAME;
            case 3:
                return State.READ_RST_STREAM_FRAME;
            case 4:
                return State.READ_SETTINGS_FRAME;
            case 5:
            default:
                if (length != 0) {
                    return State.DISCARD_FRAME;
                }
                return State.READ_COMMON_HEADER;
            case 6:
                return State.READ_PING_FRAME;
            case 7:
                return State.READ_GOAWAY_FRAME;
            case 8:
                return State.READ_HEADERS_FRAME;
            case 9:
                return State.READ_WINDOW_UPDATE_FRAME;
        }
    }

    private static boolean isValidFrameHeader(int streamId, int type, byte flags, int length) {
        switch (type) {
            case 0:
                return streamId != 0;
            case 1:
                return length >= 10;
            case 2:
                return length >= 4;
            case 3:
                return flags == 0 && length == 8;
            case 4:
                return length >= 4;
            case 5:
            default:
                return true;
            case 6:
                return length == 4;
            case 7:
                return length == 8;
            case 8:
                return length >= 4;
            case 9:
                return length == 8;
        }
    }
}
