package io.netty.handler.codec.spdy;

import io.netty.buffer.ByteBuf;
import io.netty.buffer.ByteBufAllocator;
import io.netty.util.internal.ObjectUtil;
/* loaded from: classes.dex */
public class SpdyHeaderBlockRawDecoder extends SpdyHeaderBlockDecoder {
    private static final int LENGTH_FIELD_SIZE = 4;
    private ByteBuf cumulation;
    private int headerSize;
    private int length;
    private final int maxHeaderSize;
    private String name;
    private int numHeaders;
    private State state;

    /* JADX INFO: Access modifiers changed from: private */
    /* loaded from: classes.dex */
    public enum State {
        READ_NUM_HEADERS,
        READ_NAME_LENGTH,
        READ_NAME,
        SKIP_NAME,
        READ_VALUE_LENGTH,
        READ_VALUE,
        SKIP_VALUE,
        END_HEADER_BLOCK,
        ERROR
    }

    public SpdyHeaderBlockRawDecoder(SpdyVersion spdyVersion, int maxHeaderSize) {
        ObjectUtil.checkNotNull(spdyVersion, "spdyVersion");
        this.maxHeaderSize = maxHeaderSize;
        this.state = State.READ_NUM_HEADERS;
    }

    private static int readLengthField(ByteBuf buffer) {
        int length = SpdyCodecUtil.getSignedInt(buffer, buffer.readerIndex());
        buffer.skipBytes(4);
        return length;
    }

    @Override // io.netty.handler.codec.spdy.SpdyHeaderBlockDecoder
    void decode(ByteBufAllocator alloc, ByteBuf headerBlock, SpdyHeadersFrame frame) throws Exception {
        ObjectUtil.checkNotNull(headerBlock, "headerBlock");
        ObjectUtil.checkNotNull(frame, "frame");
        ByteBuf byteBuf = this.cumulation;
        if (byteBuf == null) {
            decodeHeaderBlock(headerBlock, frame);
            if (headerBlock.isReadable()) {
                ByteBuf buffer = alloc.buffer(headerBlock.readableBytes());
                this.cumulation = buffer;
                buffer.writeBytes(headerBlock);
                return;
            }
            return;
        }
        byteBuf.writeBytes(headerBlock);
        decodeHeaderBlock(this.cumulation, frame);
        if (this.cumulation.isReadable()) {
            this.cumulation.discardReadBytes();
        } else {
            releaseBuffer();
        }
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    /* renamed from: io.netty.handler.codec.spdy.SpdyHeaderBlockRawDecoder$1  reason: invalid class name */
    /* loaded from: classes.dex */
    public static /* synthetic */ class AnonymousClass1 {
        static final /* synthetic */ int[] $SwitchMap$io$netty$handler$codec$spdy$SpdyHeaderBlockRawDecoder$State;

        static {
            int[] iArr = new int[State.values().length];
            $SwitchMap$io$netty$handler$codec$spdy$SpdyHeaderBlockRawDecoder$State = iArr;
            try {
                iArr[State.READ_NUM_HEADERS.ordinal()] = 1;
            } catch (NoSuchFieldError e) {
            }
            try {
                $SwitchMap$io$netty$handler$codec$spdy$SpdyHeaderBlockRawDecoder$State[State.READ_NAME_LENGTH.ordinal()] = 2;
            } catch (NoSuchFieldError e2) {
            }
            try {
                $SwitchMap$io$netty$handler$codec$spdy$SpdyHeaderBlockRawDecoder$State[State.READ_NAME.ordinal()] = 3;
            } catch (NoSuchFieldError e3) {
            }
            try {
                $SwitchMap$io$netty$handler$codec$spdy$SpdyHeaderBlockRawDecoder$State[State.SKIP_NAME.ordinal()] = 4;
            } catch (NoSuchFieldError e4) {
            }
            try {
                $SwitchMap$io$netty$handler$codec$spdy$SpdyHeaderBlockRawDecoder$State[State.READ_VALUE_LENGTH.ordinal()] = 5;
            } catch (NoSuchFieldError e5) {
            }
            try {
                $SwitchMap$io$netty$handler$codec$spdy$SpdyHeaderBlockRawDecoder$State[State.READ_VALUE.ordinal()] = 6;
            } catch (NoSuchFieldError e6) {
            }
            try {
                $SwitchMap$io$netty$handler$codec$spdy$SpdyHeaderBlockRawDecoder$State[State.SKIP_VALUE.ordinal()] = 7;
            } catch (NoSuchFieldError e7) {
            }
            try {
                $SwitchMap$io$netty$handler$codec$spdy$SpdyHeaderBlockRawDecoder$State[State.END_HEADER_BLOCK.ordinal()] = 8;
            } catch (NoSuchFieldError e8) {
            }
            try {
                $SwitchMap$io$netty$handler$codec$spdy$SpdyHeaderBlockRawDecoder$State[State.ERROR.ordinal()] = 9;
            } catch (NoSuchFieldError e9) {
            }
        }
    }

    /* JADX INFO: Access modifiers changed from: protected */
    /* JADX WARN: Removed duplicated region for block: B:122:0x00be A[SYNTHETIC] */
    /* JADX WARN: Removed duplicated region for block: B:154:0x0000 A[SYNTHETIC] */
    /*
        Code decompiled incorrectly, please refer to instructions dump.
    */
    public void decodeHeaderBlock(ByteBuf headerBlock, SpdyHeadersFrame frame) throws Exception {
        int i;
        int i2;
        while (headerBlock.isReadable()) {
            switch (AnonymousClass1.$SwitchMap$io$netty$handler$codec$spdy$SpdyHeaderBlockRawDecoder$State[this.state.ordinal()]) {
                case 1:
                    if (headerBlock.readableBytes() < 4) {
                        return;
                    }
                    int readLengthField = readLengthField(headerBlock);
                    this.numHeaders = readLengthField;
                    if (readLengthField < 0) {
                        this.state = State.ERROR;
                        frame.setInvalid();
                        break;
                    } else if (readLengthField == 0) {
                        this.state = State.END_HEADER_BLOCK;
                        break;
                    } else {
                        this.state = State.READ_NAME_LENGTH;
                        break;
                    }
                case 2:
                    if (headerBlock.readableBytes() < 4) {
                        return;
                    }
                    int readLengthField2 = readLengthField(headerBlock);
                    this.length = readLengthField2;
                    if (readLengthField2 <= 0) {
                        this.state = State.ERROR;
                        frame.setInvalid();
                        break;
                    } else {
                        int i3 = this.maxHeaderSize;
                        if (readLengthField2 > i3 || (i = this.headerSize) > i3 - readLengthField2) {
                            this.headerSize = this.maxHeaderSize + 1;
                            this.state = State.SKIP_NAME;
                            frame.setTruncated();
                            break;
                        } else {
                            this.headerSize = i + readLengthField2;
                            this.state = State.READ_NAME;
                            break;
                        }
                    }
                case 3:
                    int skipLength = headerBlock.readableBytes();
                    int i4 = this.length;
                    if (skipLength < i4) {
                        return;
                    }
                    byte[] nameBytes = new byte[i4];
                    headerBlock.readBytes(nameBytes);
                    this.name = new String(nameBytes, "UTF-8");
                    if (frame.headers().contains(this.name)) {
                        this.state = State.ERROR;
                        frame.setInvalid();
                        break;
                    } else {
                        this.state = State.READ_VALUE_LENGTH;
                        break;
                    }
                case 4:
                    int skipLength2 = Math.min(headerBlock.readableBytes(), this.length);
                    headerBlock.skipBytes(skipLength2);
                    int i5 = this.length - skipLength2;
                    this.length = i5;
                    if (i5 != 0) {
                        break;
                    } else {
                        this.state = State.READ_VALUE_LENGTH;
                        break;
                    }
                case 5:
                    if (headerBlock.readableBytes() < 4) {
                        return;
                    }
                    int readLengthField3 = readLengthField(headerBlock);
                    this.length = readLengthField3;
                    if (readLengthField3 < 0) {
                        this.state = State.ERROR;
                        frame.setInvalid();
                        break;
                    } else if (readLengthField3 == 0) {
                        if (!frame.isTruncated()) {
                            frame.headers().add((SpdyHeaders) this.name, "");
                        }
                        this.name = null;
                        int i6 = this.numHeaders - 1;
                        this.numHeaders = i6;
                        if (i6 == 0) {
                            this.state = State.END_HEADER_BLOCK;
                            break;
                        } else {
                            this.state = State.READ_NAME_LENGTH;
                            break;
                        }
                    } else {
                        int i7 = this.maxHeaderSize;
                        if (readLengthField3 > i7 || (i2 = this.headerSize) > i7 - readLengthField3) {
                            this.headerSize = this.maxHeaderSize + 1;
                            this.name = null;
                            this.state = State.SKIP_VALUE;
                            frame.setTruncated();
                            break;
                        } else {
                            this.headerSize = i2 + readLengthField3;
                            this.state = State.READ_VALUE;
                            break;
                        }
                    }
                case 6:
                    int skipLength3 = headerBlock.readableBytes();
                    int i8 = this.length;
                    if (skipLength3 < i8) {
                        return;
                    }
                    byte[] valueBytes = new byte[i8];
                    headerBlock.readBytes(valueBytes);
                    int index = 0;
                    int offset = 0;
                    if (valueBytes[0] == 0) {
                        this.state = State.ERROR;
                        frame.setInvalid();
                        break;
                    } else {
                        while (index < this.length) {
                            while (index < valueBytes.length && valueBytes[index] != 0) {
                                index++;
                            }
                            if (index < valueBytes.length && (index + 1 == valueBytes.length || valueBytes[index + 1] == 0)) {
                                this.state = State.ERROR;
                                frame.setInvalid();
                            } else {
                                String value = new String(valueBytes, offset, index - offset, "UTF-8");
                                try {
                                    frame.headers().add((SpdyHeaders) this.name, value);
                                    index++;
                                    offset = index;
                                } catch (IllegalArgumentException e) {
                                    this.state = State.ERROR;
                                    frame.setInvalid();
                                }
                            }
                            this.name = null;
                            if (this.state == State.ERROR) {
                                int i9 = this.numHeaders - 1;
                                this.numHeaders = i9;
                                if (i9 == 0) {
                                    this.state = State.END_HEADER_BLOCK;
                                    break;
                                } else {
                                    this.state = State.READ_NAME_LENGTH;
                                    break;
                                }
                            } else {
                                break;
                            }
                        }
                        this.name = null;
                        if (this.state == State.ERROR) {
                        }
                    }
                    break;
                case 7:
                    int skipLength4 = Math.min(headerBlock.readableBytes(), this.length);
                    headerBlock.skipBytes(skipLength4);
                    int i10 = this.length - skipLength4;
                    this.length = i10;
                    if (i10 != 0) {
                        break;
                    } else {
                        int i11 = this.numHeaders - 1;
                        this.numHeaders = i11;
                        if (i11 == 0) {
                            this.state = State.END_HEADER_BLOCK;
                            break;
                        } else {
                            this.state = State.READ_NAME_LENGTH;
                            break;
                        }
                    }
                case 8:
                    this.state = State.ERROR;
                    frame.setInvalid();
                    break;
                case 9:
                    headerBlock.skipBytes(headerBlock.readableBytes());
                    return;
                default:
                    throw new Error("Shouldn't reach here.");
            }
        }
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    @Override // io.netty.handler.codec.spdy.SpdyHeaderBlockDecoder
    public void endHeaderBlock(SpdyHeadersFrame frame) throws Exception {
        if (this.state != State.END_HEADER_BLOCK) {
            frame.setInvalid();
        }
        releaseBuffer();
        this.headerSize = 0;
        this.name = null;
        this.state = State.READ_NUM_HEADERS;
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    @Override // io.netty.handler.codec.spdy.SpdyHeaderBlockDecoder
    public void end() {
        releaseBuffer();
    }

    private void releaseBuffer() {
        ByteBuf byteBuf = this.cumulation;
        if (byteBuf != null) {
            byteBuf.release();
            this.cumulation = null;
        }
    }
}
