package io.netty.handler.codec.stomp;

import io.netty.buffer.ByteBuf;
import io.netty.buffer.ByteBufUtil;
import io.netty.buffer.Unpooled;
import io.netty.channel.ChannelHandlerContext;
import io.netty.handler.codec.DecoderException;
import io.netty.handler.codec.DecoderResult;
import io.netty.handler.codec.ReplayingDecoder;
import io.netty.handler.codec.TooLongFrameException;
import io.netty.handler.codec.memcache.binary.BinaryMemcacheOpcodes;
import io.netty.util.ByteProcessor;
import io.netty.util.internal.AppendableCharSequence;
import io.netty.util.internal.ObjectUtil;
import io.netty.util.internal.StringUtil;
import java.util.List;
/* loaded from: classes.dex */
public class StompSubframeDecoder extends ReplayingDecoder<State> {
    private static final int DEFAULT_CHUNK_SIZE = 8132;
    private static final int DEFAULT_MAX_LINE_LENGTH = 1024;
    private int alreadyReadChunkSize;
    private final Utf8LineParser commandParser;
    private long contentLength;
    private final HeaderParser headerParser;
    private LastStompContentSubframe lastContent;
    private final int maxChunkSize;

    /* JADX INFO: Access modifiers changed from: package-private */
    /* loaded from: classes.dex */
    public enum State {
        SKIP_CONTROL_CHARACTERS,
        READ_HEADERS,
        READ_CONTENT,
        FINALIZE_FRAME_READ,
        BAD_FRAME,
        INVALID_CHUNK
    }

    public StompSubframeDecoder() {
        this(1024, DEFAULT_CHUNK_SIZE);
    }

    public StompSubframeDecoder(boolean validateHeaders) {
        this(1024, DEFAULT_CHUNK_SIZE, validateHeaders);
    }

    public StompSubframeDecoder(int maxLineLength, int maxChunkSize) {
        this(maxLineLength, maxChunkSize, false);
    }

    public StompSubframeDecoder(int maxLineLength, int maxChunkSize, boolean validateHeaders) {
        super(State.SKIP_CONTROL_CHARACTERS);
        this.contentLength = -1L;
        ObjectUtil.checkPositive(maxLineLength, "maxLineLength");
        ObjectUtil.checkPositive(maxChunkSize, "maxChunkSize");
        this.maxChunkSize = maxChunkSize;
        this.commandParser = new Utf8LineParser(new AppendableCharSequence(16), maxLineLength);
        this.headerParser = new HeaderParser(new AppendableCharSequence(128), maxLineLength, validateHeaders);
    }

    /* renamed from: io.netty.handler.codec.stomp.StompSubframeDecoder$1  reason: invalid class name */
    /* loaded from: classes.dex */
    static /* synthetic */ class AnonymousClass1 {
        static final /* synthetic */ int[] $SwitchMap$io$netty$handler$codec$stomp$StompSubframeDecoder$State;

        static {
            int[] iArr = new int[State.values().length];
            $SwitchMap$io$netty$handler$codec$stomp$StompSubframeDecoder$State = iArr;
            try {
                iArr[State.SKIP_CONTROL_CHARACTERS.ordinal()] = 1;
            } catch (NoSuchFieldError e) {
            }
            try {
                $SwitchMap$io$netty$handler$codec$stomp$StompSubframeDecoder$State[State.READ_HEADERS.ordinal()] = 2;
            } catch (NoSuchFieldError e2) {
            }
            try {
                $SwitchMap$io$netty$handler$codec$stomp$StompSubframeDecoder$State[State.BAD_FRAME.ordinal()] = 3;
            } catch (NoSuchFieldError e3) {
            }
            try {
                $SwitchMap$io$netty$handler$codec$stomp$StompSubframeDecoder$State[State.READ_CONTENT.ordinal()] = 4;
            } catch (NoSuchFieldError e4) {
            }
            try {
                $SwitchMap$io$netty$handler$codec$stomp$StompSubframeDecoder$State[State.FINALIZE_FRAME_READ.ordinal()] = 5;
            } catch (NoSuchFieldError e5) {
            }
        }
    }

    /* JADX WARN: Removed duplicated region for block: B:16:0x0056  */
    /* JADX WARN: Removed duplicated region for block: B:19:0x005b A[Catch: Exception -> 0x0109, TryCatch #0 {Exception -> 0x0109, blocks: (B:14:0x0045, B:44:0x00ec, B:46:0x00f3, B:47:0x00f7, B:19:0x005b, B:22:0x0062, B:24:0x0066, B:25:0x0069, B:27:0x0071, B:30:0x007b, B:32:0x008f, B:33:0x009c, B:35:0x00a5, B:37:0x00b8, B:39:0x00c0, B:41:0x00d1, B:43:0x00e0, B:49:0x0100, B:40:0x00c7), top: B:59:0x0045 }] */
    /* JADX WARN: Removed duplicated region for block: B:46:0x00f3 A[Catch: Exception -> 0x0109, TryCatch #0 {Exception -> 0x0109, blocks: (B:14:0x0045, B:44:0x00ec, B:46:0x00f3, B:47:0x00f7, B:19:0x005b, B:22:0x0062, B:24:0x0066, B:25:0x0069, B:27:0x0071, B:30:0x007b, B:32:0x008f, B:33:0x009c, B:35:0x00a5, B:37:0x00b8, B:39:0x00c0, B:41:0x00d1, B:43:0x00e0, B:49:0x0100, B:40:0x00c7), top: B:59:0x0045 }] */
    @Override // io.netty.handler.codec.ByteToMessageDecoder
    /*
        Code decompiled incorrectly, please refer to instructions dump.
    */
    protected void decode(ChannelHandlerContext ctx, ByteBuf in, List<Object> out) throws Exception {
        StompCommand command;
        StompHeadersSubframe frame;
        int i;
        int toRead;
        int i2 = AnonymousClass1.$SwitchMap$io$netty$handler$codec$stomp$StompSubframeDecoder$State[state().ordinal()];
        try {
            try {
                if (i2 == 1) {
                    skipControlCharacters(in);
                    checkpoint(State.READ_HEADERS);
                } else if (i2 != 2) {
                    if (i2 == 3) {
                        in.skipBytes(actualReadableBytes());
                        return;
                    }
                    i = AnonymousClass1.$SwitchMap$io$netty$handler$codec$stomp$StompSubframeDecoder$State[state().ordinal()];
                    if (i != 4) {
                        int toRead2 = in.readableBytes();
                        if (toRead2 == 0) {
                            return;
                        }
                        if (toRead2 > this.maxChunkSize) {
                            toRead2 = this.maxChunkSize;
                        }
                        if (this.contentLength >= 0) {
                            int remainingLength = (int) (this.contentLength - this.alreadyReadChunkSize);
                            if (toRead2 > remainingLength) {
                                toRead2 = remainingLength;
                            }
                            ByteBuf chunkBuffer = ByteBufUtil.readBytes(ctx.alloc(), in, toRead2);
                            int i3 = this.alreadyReadChunkSize + toRead2;
                            this.alreadyReadChunkSize = i3;
                            if (i3 >= this.contentLength) {
                                this.lastContent = new DefaultLastStompContentSubframe(chunkBuffer);
                                checkpoint(State.FINALIZE_FRAME_READ);
                            } else {
                                out.add(new DefaultStompContentSubframe(chunkBuffer));
                                return;
                            }
                        } else {
                            int nulIndex = ByteBufUtil.indexOf(in, in.readerIndex(), in.writerIndex(), (byte) 0);
                            if (nulIndex == in.readerIndex()) {
                                checkpoint(State.FINALIZE_FRAME_READ);
                            } else {
                                if (nulIndex > 0) {
                                    toRead = nulIndex - in.readerIndex();
                                } else {
                                    toRead = in.writerIndex() - in.readerIndex();
                                }
                                ByteBuf chunkBuffer2 = ByteBufUtil.readBytes(ctx.alloc(), in, toRead);
                                this.alreadyReadChunkSize += toRead;
                                if (nulIndex > 0) {
                                    this.lastContent = new DefaultLastStompContentSubframe(chunkBuffer2);
                                    checkpoint(State.FINALIZE_FRAME_READ);
                                } else {
                                    out.add(new DefaultStompContentSubframe(chunkBuffer2));
                                    return;
                                }
                            }
                        }
                    } else if (i != 5) {
                        return;
                    }
                    skipNullCharacter(in);
                    if (this.lastContent == null) {
                        this.lastContent = LastStompContentSubframe.EMPTY_LAST_CONTENT;
                    }
                    out.add(this.lastContent);
                    resetDecoder();
                    return;
                }
                i = AnonymousClass1.$SwitchMap$io$netty$handler$codec$stomp$StompSubframeDecoder$State[state().ordinal()];
                if (i != 4) {
                }
                skipNullCharacter(in);
                if (this.lastContent == null) {
                }
                out.add(this.lastContent);
                resetDecoder();
                return;
            } catch (Exception e) {
                StompContentSubframe errorContent = new DefaultLastStompContentSubframe(Unpooled.EMPTY_BUFFER);
                errorContent.setDecoderResult(DecoderResult.failure(e));
                out.add(errorContent);
                checkpoint(State.BAD_FRAME);
                return;
            }
            command = readCommand(in);
            frame = new DefaultStompHeadersSubframe(command);
            checkpoint(readHeaders(in, frame.headers()));
            out.add(frame);
        } catch (Exception e2) {
            if (frame == null) {
                frame = new DefaultStompHeadersSubframe(command);
            }
            frame.setDecoderResult(DecoderResult.failure(e2));
            out.add(frame);
            checkpoint(State.BAD_FRAME);
            return;
        }
        command = StompCommand.UNKNOWN;
        frame = null;
    }

    private StompCommand readCommand(ByteBuf in) {
        CharSequence commandSequence = this.commandParser.parse(in);
        if (commandSequence == null) {
            throw new DecoderException("Failed to read command from channel");
        }
        String commandStr = commandSequence.toString();
        try {
            return StompCommand.valueOf(commandStr);
        } catch (IllegalArgumentException e) {
            throw new DecoderException("Cannot to parse command " + commandStr);
        }
    }

    private State readHeaders(ByteBuf buffer, StompHeaders headers) {
        boolean headerRead;
        do {
            headerRead = this.headerParser.parseHeader(headers, buffer);
        } while (headerRead);
        if (headers.contains(StompHeaders.CONTENT_LENGTH)) {
            long contentLength = getContentLength(headers);
            this.contentLength = contentLength;
            if (contentLength == 0) {
                return State.FINALIZE_FRAME_READ;
            }
        }
        return State.READ_CONTENT;
    }

    private static long getContentLength(StompHeaders headers) {
        long contentLength = headers.getLong(StompHeaders.CONTENT_LENGTH, 0L);
        if (contentLength < 0) {
            throw new DecoderException(((Object) StompHeaders.CONTENT_LENGTH) + " must be non-negative");
        }
        return contentLength;
    }

    private static void skipNullCharacter(ByteBuf buffer) {
        byte b = buffer.readByte();
        if (b != 0) {
            throw new IllegalStateException("unexpected byte in buffer " + ((int) b) + " while expecting NULL byte");
        }
    }

    private static void skipControlCharacters(ByteBuf buffer) {
        while (true) {
            byte b = buffer.readByte();
            if (b != 13 && b != 10) {
                buffer.readerIndex(buffer.readerIndex() - 1);
                return;
            }
        }
    }

    private void resetDecoder() {
        checkpoint(State.SKIP_CONTROL_CHARACTERS);
        this.contentLength = -1L;
        this.alreadyReadChunkSize = 0;
        this.lastContent = null;
    }

    /* JADX INFO: Access modifiers changed from: private */
    /* loaded from: classes.dex */
    public static class Utf8LineParser implements ByteProcessor {
        private final AppendableCharSequence charSeq;
        private char interim;
        private int lineLength;
        private final int maxLineLength;
        private boolean nextRead;

        Utf8LineParser(AppendableCharSequence charSeq, int maxLineLength) {
            this.charSeq = (AppendableCharSequence) ObjectUtil.checkNotNull(charSeq, "charSeq");
            this.maxLineLength = maxLineLength;
        }

        AppendableCharSequence parse(ByteBuf byteBuf) {
            reset();
            int offset = byteBuf.forEachByte(this);
            if (offset == -1) {
                return null;
            }
            byteBuf.readerIndex(offset + 1);
            return this.charSeq;
        }

        AppendableCharSequence charSequence() {
            return this.charSeq;
        }

        @Override // io.netty.util.ByteProcessor
        public boolean process(byte nextByte) throws Exception {
            if (nextByte == 13) {
                this.lineLength++;
                return true;
            } else if (nextByte == 10) {
                return false;
            } else {
                int i = this.lineLength + 1;
                this.lineLength = i;
                if (i > this.maxLineLength) {
                    throw new TooLongFrameException("An STOMP line is larger than " + this.maxLineLength + " bytes.");
                }
                if (this.nextRead) {
                    this.interim = (char) (this.interim | ((nextByte & 63) << 6));
                    this.nextRead = false;
                } else {
                    char c = this.interim;
                    if (c != 0) {
                        this.charSeq.append((char) (c | (nextByte & 63)));
                        this.interim = (char) 0;
                    } else if (nextByte >= 0) {
                        this.charSeq.append((char) nextByte);
                    } else if ((nextByte & 224) == 192) {
                        this.interim = (char) ((nextByte & 31) << 6);
                    } else {
                        this.interim = (char) ((nextByte & BinaryMemcacheOpcodes.PREPEND) << 12);
                        this.nextRead = true;
                    }
                }
                return true;
            }
        }

        protected void reset() {
            this.charSeq.reset();
            this.lineLength = 0;
            this.interim = (char) 0;
            this.nextRead = false;
        }
    }

    /* JADX INFO: Access modifiers changed from: private */
    /* loaded from: classes.dex */
    public static final class HeaderParser extends Utf8LineParser {
        private String name;
        private boolean valid;
        private final boolean validateHeaders;

        HeaderParser(AppendableCharSequence charSeq, int maxLineLength, boolean validateHeaders) {
            super(charSeq, maxLineLength);
            this.validateHeaders = validateHeaders;
        }

        boolean parseHeader(StompHeaders headers, ByteBuf buf) {
            AppendableCharSequence value = super.parse(buf);
            if (value != null) {
                if (this.name == null && value.length() == 0) {
                    return false;
                }
                if (this.valid) {
                    headers.add((StompHeaders) this.name, value.toString());
                    return true;
                } else if (this.validateHeaders) {
                    if (StringUtil.isNullOrEmpty(this.name)) {
                        throw new IllegalArgumentException("received an invalid header line '" + value.toString() + '\'');
                    }
                    String line = this.name + ':' + value.toString();
                    throw new IllegalArgumentException("a header value or name contains a prohibited character ':', " + line);
                } else {
                    return true;
                }
            }
            return false;
        }

        @Override // io.netty.handler.codec.stomp.StompSubframeDecoder.Utf8LineParser, io.netty.util.ByteProcessor
        public boolean process(byte nextByte) throws Exception {
            if (nextByte == 58) {
                if (this.name == null) {
                    AppendableCharSequence charSeq = charSequence();
                    if (charSeq.length() != 0) {
                        this.name = charSeq.substring(0, charSeq.length());
                        charSeq.reset();
                        this.valid = true;
                        return true;
                    }
                    this.name = "";
                } else {
                    this.valid = false;
                }
            }
            return super.process(nextByte);
        }

        @Override // io.netty.handler.codec.stomp.StompSubframeDecoder.Utf8LineParser
        protected void reset() {
            this.name = null;
            this.valid = false;
            super.reset();
        }
    }
}
