package io.netty.handler.codec.xml;

import java.util.LinkedList;
import java.util.List;
/* loaded from: classes.dex */
public abstract class XmlElement {
    private final String name;
    private final String namespace;
    private final List<XmlNamespace> namespaces = new LinkedList();
    private final String prefix;

    /* JADX INFO: Access modifiers changed from: protected */
    public XmlElement(String name, String namespace, String prefix) {
        this.name = name;
        this.namespace = namespace;
        this.prefix = prefix;
    }

    public String name() {
        return this.name;
    }

    public String namespace() {
        return this.namespace;
    }

    public String prefix() {
        return this.prefix;
    }

    public List<XmlNamespace> namespaces() {
        return this.namespaces;
    }

    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        XmlElement that = (XmlElement) o;
        if (!this.name.equals(that.name)) {
            return false;
        }
        String str = this.namespace;
        if (str == null ? that.namespace != null : !str.equals(that.namespace)) {
            return false;
        }
        List<XmlNamespace> list = this.namespaces;
        if (list == null ? that.namespaces != null : !list.equals(that.namespaces)) {
            return false;
        }
        String str2 = this.prefix;
        if (str2 == null ? that.prefix == null : str2.equals(that.prefix)) {
            return true;
        }
        return false;
    }

    public int hashCode() {
        int result = this.name.hashCode();
        int i = result * 31;
        String str = this.namespace;
        int result2 = i + (str != null ? str.hashCode() : 0);
        int result3 = result2 * 31;
        String str2 = this.prefix;
        int result4 = (result3 + (str2 != null ? str2.hashCode() : 0)) * 31;
        List<XmlNamespace> list = this.namespaces;
        return result4 + (list != null ? list.hashCode() : 0);
    }

    public String toString() {
        return ", name='" + this.name + "', namespace='" + this.namespace + "', prefix='" + this.prefix + "', namespaces=" + this.namespaces;
    }
}
