package io.netty.handler.ssl;

import io.netty.buffer.ByteBufAllocator;
import io.netty.buffer.UnpooledByteBufAllocator;
import io.netty.internal.tcnative.SSL;
import java.security.PrivateKey;
import java.security.cert.X509Certificate;
import javax.net.ssl.SSLException;
import javax.net.ssl.X509KeyManager;
/* JADX INFO: Access modifiers changed from: package-private */
/* loaded from: classes.dex */
public class OpenSslKeyMaterialProvider {
    private final X509KeyManager keyManager;
    private final String password;

    /* JADX INFO: Access modifiers changed from: package-private */
    public OpenSslKeyMaterialProvider(X509KeyManager keyManager, String password) {
        this.keyManager = keyManager;
        this.password = password;
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    public static void validateKeyMaterialSupported(X509Certificate[] keyCertChain, PrivateKey key, String keyPassword) throws SSLException {
        validateSupported(keyCertChain);
        validateSupported(key, keyPassword);
    }

    private static void validateSupported(PrivateKey key, String password) throws SSLException {
        if (key == null) {
            return;
        }
        long pkeyBio = 0;
        long pkey = 0;
        try {
            try {
                pkeyBio = ReferenceCountedOpenSslContext.toBIO(UnpooledByteBufAllocator.DEFAULT, key);
                pkey = SSL.parsePrivateKey(pkeyBio, password);
            } catch (Exception e) {
                throw new SSLException("PrivateKey type not supported " + key.getFormat(), e);
            }
        } finally {
            SSL.freeBIO(pkeyBio);
            if (pkey != 0) {
                SSL.freePrivateKey(pkey);
            }
        }
    }

    private static void validateSupported(X509Certificate[] certificates) throws SSLException {
        if (certificates == null || certificates.length == 0) {
            return;
        }
        long chainBio = 0;
        long chain = 0;
        PemEncoded encoded = null;
        try {
            try {
                encoded = PemX509Certificate.toPEM(UnpooledByteBufAllocator.DEFAULT, true, certificates);
                chainBio = ReferenceCountedOpenSslContext.toBIO(UnpooledByteBufAllocator.DEFAULT, encoded.retain());
                chain = SSL.parseX509Chain(chainBio);
            } catch (Exception e) {
                throw new SSLException("Certificate type not supported", e);
            }
        } finally {
            SSL.freeBIO(chainBio);
            if (chain != 0) {
                SSL.freeX509Chain(chain);
            }
            if (encoded != null) {
                encoded.release();
            }
        }
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    public X509KeyManager keyManager() {
        return this.keyManager;
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    /* JADX WARN: Removed duplicated region for block: B:47:0x00ba  */
    /* JADX WARN: Removed duplicated region for block: B:50:0x00c1  */
    /*
        Code decompiled incorrectly, please refer to instructions dump.
    */
    public OpenSslKeyMaterial chooseKeyMaterial(ByteBufAllocator allocator, String alias) throws Exception {
        OpenSslKeyMaterial keyMaterial;
        long parsePrivateKey;
        X509Certificate[] certificates = this.keyManager.getCertificateChain(alias);
        if (certificates == null || certificates.length == 0) {
            return null;
        }
        PrivateKey key = this.keyManager.getPrivateKey(alias);
        PemEncoded encoded = PemX509Certificate.toPEM(allocator, true, certificates);
        long chainBio = 0;
        long pkeyBio = 0;
        long chain = 0;
        long pkey = 0;
        try {
            long chainBio2 = ReferenceCountedOpenSslContext.toBIO(allocator, encoded.retain());
            try {
                long chain2 = SSL.parseX509Chain(chainBio2);
                try {
                    if (key instanceof OpenSslPrivateKey) {
                        try {
                            keyMaterial = ((OpenSslPrivateKey) key).newKeyMaterial(chain2, certificates);
                        } catch (Throwable th) {
                            th = th;
                            chain = chain2;
                            chainBio = chainBio2;
                            SSL.freeBIO(chainBio);
                            SSL.freeBIO(pkeyBio);
                            if (chain != 0) {
                                SSL.freeX509Chain(chain);
                            }
                            if (pkey != 0) {
                                SSL.freePrivateKey(pkey);
                            }
                            encoded.release();
                            throw th;
                        }
                    } else {
                        pkeyBio = ReferenceCountedOpenSslContext.toBIO(allocator, key);
                        if (key != null) {
                            try {
                                parsePrivateKey = SSL.parsePrivateKey(pkeyBio, this.password);
                            } catch (Throwable th2) {
                                th = th2;
                                chainBio = chainBio2;
                                chain = chain2;
                                SSL.freeBIO(chainBio);
                                SSL.freeBIO(pkeyBio);
                                if (chain != 0) {
                                }
                                if (pkey != 0) {
                                }
                                encoded.release();
                                throw th;
                            }
                        } else {
                            parsePrivateKey = 0;
                        }
                        long pkey2 = parsePrivateKey;
                        try {
                            try {
                                keyMaterial = new DefaultOpenSslKeyMaterial(chain2, pkey2, certificates);
                                pkeyBio = pkeyBio;
                            } catch (Throwable th3) {
                                th = th3;
                                pkey = pkey2;
                                chainBio = chainBio2;
                                pkeyBio = pkeyBio;
                                chain = chain2;
                                SSL.freeBIO(chainBio);
                                SSL.freeBIO(pkeyBio);
                                if (chain != 0) {
                                }
                                if (pkey != 0) {
                                }
                                encoded.release();
                                throw th;
                            }
                        } catch (Throwable th4) {
                            th = th4;
                            pkey = pkey2;
                            chainBio = chainBio2;
                            pkeyBio = pkeyBio;
                            chain = chain2;
                        }
                    }
                    SSL.freeBIO(chainBio2);
                    SSL.freeBIO(pkeyBio);
                    if (0 != 0) {
                        SSL.freeX509Chain(0L);
                    }
                    if (0 != 0) {
                        SSL.freePrivateKey(0L);
                    }
                    encoded.release();
                    return keyMaterial;
                } catch (Throwable th5) {
                    th = th5;
                    chainBio = chainBio2;
                    chain = chain2;
                }
            } catch (Throwable th6) {
                th = th6;
                chainBio = chainBio2;
            }
        } catch (Throwable th7) {
            th = th7;
        }
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    public void destroy() {
    }
}
