package io.netty.handler.ssl;

import io.netty.buffer.ByteBufAllocator;
import io.netty.handler.ssl.ReferenceCountedOpenSslContext;
import io.netty.internal.tcnative.CertificateCallback;
import io.netty.internal.tcnative.SSLContext;
import io.netty.internal.tcnative.SniHostNameMatcher;
import io.netty.util.CharsetUtil;
import io.netty.util.internal.ObjectUtil;
import io.netty.util.internal.PlatformDependent;
import io.netty.util.internal.logging.InternalLogger;
import io.netty.util.internal.logging.InternalLoggerFactory;
import java.security.KeyStore;
import java.security.PrivateKey;
import java.security.cert.Certificate;
import java.security.cert.X509Certificate;
import javax.net.ssl.KeyManagerFactory;
import javax.net.ssl.SSLException;
import javax.net.ssl.TrustManagerFactory;
import javax.net.ssl.X509ExtendedTrustManager;
import javax.net.ssl.X509TrustManager;
/* loaded from: classes.dex */
public final class ReferenceCountedOpenSslServerContext extends ReferenceCountedOpenSslContext {
    private final OpenSslServerSessionContext sessionContext;
    private static final InternalLogger logger = InternalLoggerFactory.getInstance(ReferenceCountedOpenSslServerContext.class);
    private static final byte[] ID = {110, 101, 116, 116, 121};

    /* JADX INFO: Access modifiers changed from: package-private */
    public ReferenceCountedOpenSslServerContext(X509Certificate[] trustCertCollection, TrustManagerFactory trustManagerFactory, X509Certificate[] keyCertChain, PrivateKey key, String keyPassword, KeyManagerFactory keyManagerFactory, Iterable<String> ciphers, CipherSuiteFilter cipherFilter, ApplicationProtocolConfig apn, long sessionCacheSize, long sessionTimeout, ClientAuth clientAuth, String[] protocols, boolean startTls, boolean enableOcsp, String keyStore) throws SSLException {
        this(trustCertCollection, trustManagerFactory, keyCertChain, key, keyPassword, keyManagerFactory, ciphers, cipherFilter, toNegotiator(apn), sessionCacheSize, sessionTimeout, clientAuth, protocols, startTls, enableOcsp, keyStore);
    }

    ReferenceCountedOpenSslServerContext(X509Certificate[] trustCertCollection, TrustManagerFactory trustManagerFactory, X509Certificate[] keyCertChain, PrivateKey key, String keyPassword, KeyManagerFactory keyManagerFactory, Iterable<String> ciphers, CipherSuiteFilter cipherFilter, OpenSslApplicationProtocolNegotiator apn, long sessionCacheSize, long sessionTimeout, ClientAuth clientAuth, String[] protocols, boolean startTls, boolean enableOcsp, String keyStore) throws SSLException {
        super(ciphers, cipherFilter, apn, sessionCacheSize, sessionTimeout, 1, (Certificate[]) keyCertChain, clientAuth, protocols, startTls, enableOcsp, true);
        boolean success = false;
        try {
            this.sessionContext = newSessionContext(this, this.ctx, this.engineMap, trustCertCollection, trustManagerFactory, keyCertChain, key, keyPassword, keyManagerFactory, keyStore);
            success = true;
        } finally {
            if (!success) {
                release();
            }
        }
    }

    @Override // io.netty.handler.ssl.ReferenceCountedOpenSslContext, io.netty.handler.ssl.SslContext
    public OpenSslServerSessionContext sessionContext() {
        return this.sessionContext;
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    /* JADX WARN: Removed duplicated region for block: B:107:0x017b  */
    /* JADX WARN: Removed duplicated region for block: B:126:0x00b8 A[EXC_TOP_SPLITTER, SYNTHETIC] */
    /* JADX WARN: Removed duplicated region for block: B:64:0x0110 A[Catch: all -> 0x012f, Exception -> 0x0135, SSLException -> 0x013b, TRY_LEAVE, TryCatch #10 {all -> 0x012f, blocks: (B:62:0x0108, B:64:0x0110, B:66:0x0119, B:53:0x00ef, B:54:0x00f3), top: B:115:0x00b6 }] */
    /* JADX WARN: Removed duplicated region for block: B:71:0x0129  */
    /*
        Code decompiled incorrectly, please refer to instructions dump.
    */
    public static OpenSslServerSessionContext newSessionContext(ReferenceCountedOpenSslContext thiz, long ctx, OpenSslEngineMap engineMap, X509Certificate[] trustCertCollection, TrustManagerFactory trustManagerFactory, X509Certificate[] keyCertChain, PrivateKey key, String keyPassword, KeyManagerFactory keyManagerFactory, String keyStore) throws SSLException {
        KeyManagerFactory keyManagerFactory2;
        X509Certificate[] issuers;
        TrustManagerFactory trustManagerFactory2 = trustManagerFactory;
        OpenSslKeyMaterialProvider keyMaterialProvider = null;
        try {
            SSLContext.setVerify(ctx, 0, 10);
            if (OpenSsl.useKeyManagerFactory()) {
                if (keyManagerFactory == null) {
                    char[] keyPasswordChars = keyStorePassword(keyPassword);
                    KeyStore ks = buildKeyStore(keyCertChain, key, keyPasswordChars, keyStore);
                    keyManagerFactory2 = ks.aliases().hasMoreElements() ? new OpenSslX509KeyManagerFactory() : new OpenSslCachingX509KeyManagerFactory(KeyManagerFactory.getInstance(KeyManagerFactory.getDefaultAlgorithm()));
                    try {
                        try {
                            keyManagerFactory2.init(ks, keyPasswordChars);
                        } catch (Throwable th) {
                            e = th;
                            if (keyMaterialProvider != null) {
                            }
                            throw e;
                        }
                    } catch (Exception e) {
                        e = e;
                        try {
                            throw new SSLException("failed to set certificate and key", e);
                        } catch (Throwable th2) {
                            e = th2;
                            if (keyMaterialProvider != null) {
                            }
                            throw e;
                        }
                    }
                } else {
                    keyManagerFactory2 = keyManagerFactory;
                }
                keyMaterialProvider = providerFor(keyManagerFactory2, keyPassword);
                SSLContext.setCertificateCallback(ctx, new OpenSslServerCertificateCallback(engineMap, new OpenSslKeyMaterialManager(keyMaterialProvider)));
            } else if (keyManagerFactory != null) {
                throw new IllegalArgumentException("KeyManagerFactory not supported");
            } else {
                ObjectUtil.checkNotNull(keyCertChain, "keyCertChain");
                setKeyMaterial(ctx, keyCertChain, key, keyPassword);
            }
            try {
                try {
                    try {
                        try {
                            try {
                                try {
                                    if (trustCertCollection == null) {
                                        if (trustManagerFactory2 == null) {
                                            trustManagerFactory2 = TrustManagerFactory.getInstance(TrustManagerFactory.getDefaultAlgorithm());
                                            try {
                                                trustManagerFactory2.init((KeyStore) null);
                                            } catch (SSLException e2) {
                                                e = e2;
                                                throw e;
                                            } catch (Exception e3) {
                                                e = e3;
                                                throw new SSLException("unable to setup trustmanager", e);
                                            } catch (Throwable th3) {
                                                e = th3;
                                                if (keyMaterialProvider != null) {
                                                }
                                                throw e;
                                            }
                                        }
                                        X509TrustManager manager = chooseTrustManager(trustManagerFactory2.getTrustManagers());
                                        setVerifyCallback(ctx, engineMap, manager);
                                        issuers = manager.getAcceptedIssuers();
                                        if (issuers != null) {
                                            try {
                                                if (issuers.length > 0) {
                                                    long bio = 0;
                                                    try {
                                                        bio = toBIO(ByteBufAllocator.DEFAULT, issuers);
                                                        if (!SSLContext.setCACertificateBio(ctx, bio)) {
                                                            StringBuilder sb = new StringBuilder();
                                                            try {
                                                                sb.append("unable to setup accepted issuers for trustmanager ");
                                                                sb.append(manager);
                                                                throw new SSLException(sb.toString());
                                                            } catch (Throwable th4) {
                                                                th = th4;
                                                                freeBio(bio);
                                                                throw th;
                                                            }
                                                        }
                                                        freeBio(bio);
                                                        trustManagerFactory = trustManagerFactory2;
                                                        if (PlatformDependent.javaVersion() >= 8) {
                                                            SSLContext.setSniHostnameMatcher(ctx, new OpenSslSniHostnameMatcher(engineMap));
                                                        }
                                                        OpenSslServerSessionContext sessionContext = new OpenSslServerSessionContext(thiz, keyMaterialProvider);
                                                        sessionContext.setSessionIdContext(ID);
                                                        OpenSslKeyMaterialProvider keyMaterialProvider2 = null;
                                                        if (0 != 0) {
                                                            keyMaterialProvider2.destroy();
                                                        }
                                                        return sessionContext;
                                                    } catch (Throwable th5) {
                                                        th = th5;
                                                    }
                                                }
                                            } catch (SSLException e4) {
                                                e = e4;
                                                throw e;
                                            } catch (Exception e5) {
                                                e = e5;
                                                throw new SSLException("unable to setup trustmanager", e);
                                            } catch (Throwable th6) {
                                                e = th6;
                                                if (keyMaterialProvider != null) {
                                                }
                                                throw e;
                                            }
                                        }
                                        trustManagerFactory = trustManagerFactory2;
                                        if (PlatformDependent.javaVersion() >= 8) {
                                        }
                                        OpenSslServerSessionContext sessionContext2 = new OpenSslServerSessionContext(thiz, keyMaterialProvider);
                                        sessionContext2.setSessionIdContext(ID);
                                        OpenSslKeyMaterialProvider keyMaterialProvider22 = null;
                                        if (0 != 0) {
                                        }
                                        return sessionContext2;
                                    }
                                    trustManagerFactory2 = buildTrustManagerFactory(trustCertCollection, trustManagerFactory2, keyStore);
                                    OpenSslServerSessionContext sessionContext22 = new OpenSslServerSessionContext(thiz, keyMaterialProvider);
                                    sessionContext22.setSessionIdContext(ID);
                                    OpenSslKeyMaterialProvider keyMaterialProvider222 = null;
                                    if (0 != 0) {
                                    }
                                    return sessionContext22;
                                } catch (Throwable th7) {
                                    e = th7;
                                    if (keyMaterialProvider != null) {
                                        keyMaterialProvider.destroy();
                                    }
                                    throw e;
                                }
                                if (issuers != null) {
                                }
                                trustManagerFactory = trustManagerFactory2;
                                if (PlatformDependent.javaVersion() >= 8) {
                                }
                            } catch (Throwable th8) {
                                e = th8;
                            }
                        } catch (SSLException e6) {
                            e = e6;
                        } catch (Exception e7) {
                            e = e7;
                        }
                        X509TrustManager manager2 = chooseTrustManager(trustManagerFactory2.getTrustManagers());
                        setVerifyCallback(ctx, engineMap, manager2);
                        issuers = manager2.getAcceptedIssuers();
                    } catch (SSLException e8) {
                        e = e8;
                    } catch (Exception e9) {
                        e = e9;
                    } catch (Throwable th9) {
                        e = th9;
                    }
                } catch (Throwable th10) {
                    e = th10;
                }
            } catch (SSLException e10) {
                e = e10;
            } catch (Exception e11) {
                e = e11;
            }
        } catch (Exception e12) {
            e = e12;
        } catch (Throwable th11) {
            e = th11;
        }
    }

    private static void setVerifyCallback(long ctx, OpenSslEngineMap engineMap, X509TrustManager manager) {
        if (useExtendedTrustManager(manager)) {
            SSLContext.setCertVerifyCallback(ctx, new ExtendedTrustManagerVerifyCallback(engineMap, (X509ExtendedTrustManager) manager));
        } else {
            SSLContext.setCertVerifyCallback(ctx, new TrustManagerVerifyCallback(engineMap, manager));
        }
    }

    /* JADX INFO: Access modifiers changed from: private */
    /* loaded from: classes.dex */
    public static final class OpenSslServerCertificateCallback implements CertificateCallback {
        private final OpenSslEngineMap engineMap;
        private final OpenSslKeyMaterialManager keyManagerHolder;

        OpenSslServerCertificateCallback(OpenSslEngineMap engineMap, OpenSslKeyMaterialManager keyManagerHolder) {
            this.engineMap = engineMap;
            this.keyManagerHolder = keyManagerHolder;
        }

        public void handle(long ssl, byte[] keyTypeBytes, byte[][] asn1DerEncodedPrincipals) throws Exception {
            ReferenceCountedOpenSslEngine engine = this.engineMap.get(ssl);
            if (engine == null) {
                return;
            }
            try {
                this.keyManagerHolder.setKeyMaterialServerSide(engine);
            } catch (Throwable cause) {
                ReferenceCountedOpenSslServerContext.logger.debug("Failed to set the server-side key material", cause);
                engine.initHandshakeException(cause);
            }
        }
    }

    /* JADX INFO: Access modifiers changed from: private */
    /* loaded from: classes.dex */
    public static final class TrustManagerVerifyCallback extends ReferenceCountedOpenSslContext.AbstractCertificateVerifier {
        private final X509TrustManager manager;

        TrustManagerVerifyCallback(OpenSslEngineMap engineMap, X509TrustManager manager) {
            super(engineMap);
            this.manager = manager;
        }

        @Override // io.netty.handler.ssl.ReferenceCountedOpenSslContext.AbstractCertificateVerifier
        void verify(ReferenceCountedOpenSslEngine engine, X509Certificate[] peerCerts, String auth) throws Exception {
            this.manager.checkClientTrusted(peerCerts, auth);
        }
    }

    /* JADX INFO: Access modifiers changed from: private */
    /* loaded from: classes.dex */
    public static final class ExtendedTrustManagerVerifyCallback extends ReferenceCountedOpenSslContext.AbstractCertificateVerifier {
        private final X509ExtendedTrustManager manager;

        ExtendedTrustManagerVerifyCallback(OpenSslEngineMap engineMap, X509ExtendedTrustManager manager) {
            super(engineMap);
            this.manager = OpenSslTlsv13X509ExtendedTrustManager.wrap(manager);
        }

        @Override // io.netty.handler.ssl.ReferenceCountedOpenSslContext.AbstractCertificateVerifier
        void verify(ReferenceCountedOpenSslEngine engine, X509Certificate[] peerCerts, String auth) throws Exception {
            this.manager.checkClientTrusted(peerCerts, auth, engine);
        }
    }

    /* JADX INFO: Access modifiers changed from: private */
    /* loaded from: classes.dex */
    public static final class OpenSslSniHostnameMatcher implements SniHostNameMatcher {
        private final OpenSslEngineMap engineMap;

        OpenSslSniHostnameMatcher(OpenSslEngineMap engineMap) {
            this.engineMap = engineMap;
        }

        public boolean match(long ssl, String hostname) {
            ReferenceCountedOpenSslEngine engine = this.engineMap.get(ssl);
            if (engine == null) {
                ReferenceCountedOpenSslServerContext.logger.warn("No ReferenceCountedOpenSslEngine found for SSL pointer: {}", Long.valueOf(ssl));
                return false;
            }
            return engine.checkSniHostnameMatch(hostname.getBytes(CharsetUtil.UTF_8));
        }
    }
}
