package io.netty.resolver.dns;

import io.netty.util.NetUtil;
import io.netty.util.internal.ObjectUtil;
import io.netty.util.internal.SocketUtils;
import io.netty.util.internal.StringUtil;
import io.netty.util.internal.logging.InternalLogger;
import io.netty.util.internal.logging.InternalLoggerFactory;
import java.io.BufferedReader;
import java.io.File;
import java.io.FileReader;
import java.io.IOException;
import java.net.InetSocketAddress;
import java.util.ArrayList;
import java.util.Collection;
import java.util.Collections;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.regex.Pattern;
/* loaded from: classes.dex */
public final class UnixResolverDnsServerAddressStreamProvider implements DnsServerAddressStreamProvider {
    static final int DEFAULT_NDOTS = 1;
    private static final String DOMAIN_ROW_LABEL = "domain";
    private static final String ETC_RESOLVER_DIR = "/etc/resolver";
    private static final String ETC_RESOLV_CONF_FILE = "/etc/resolv.conf";
    private static final String NAMESERVER_ROW_LABEL = "nameserver";
    private static final String NDOTS_LABEL = "ndots:";
    private static final String OPTIONS_ROW_LABEL = "options";
    private static final String PORT_ROW_LABEL = "port";
    private static final String SEARCH_ROW_LABEL = "search";
    private static final String SORTLIST_ROW_LABEL = "sortlist";
    private final DnsServerAddresses defaultNameServerAddresses;
    private final Map<String, DnsServerAddresses> domainToNameServerStreamMap;
    private static final InternalLogger logger = InternalLoggerFactory.getInstance(UnixResolverDnsServerAddressStreamProvider.class);
    private static final Pattern SEARCH_DOMAIN_PATTERN = Pattern.compile("\\s+");

    /* JADX INFO: Access modifiers changed from: package-private */
    public static DnsServerAddressStreamProvider parseSilently() {
        try {
            UnixResolverDnsServerAddressStreamProvider nameServerCache = new UnixResolverDnsServerAddressStreamProvider(ETC_RESOLV_CONF_FILE, ETC_RESOLVER_DIR);
            return nameServerCache.mayOverrideNameServers() ? nameServerCache : DefaultDnsServerAddressStreamProvider.INSTANCE;
        } catch (Exception e) {
            logger.debug("failed to parse {} and/or {}", ETC_RESOLV_CONF_FILE, ETC_RESOLVER_DIR, e);
            return DefaultDnsServerAddressStreamProvider.INSTANCE;
        }
    }

    public UnixResolverDnsServerAddressStreamProvider(File etcResolvConf, File... etcResolverFiles) throws IOException {
        boolean useEtcResolverFiles = true;
        Map<String, DnsServerAddresses> etcResolvConfMap = parse((File) ObjectUtil.checkNotNull(etcResolvConf, "etcResolvConf"));
        useEtcResolverFiles = (etcResolverFiles == null || etcResolverFiles.length == 0) ? false : false;
        this.domainToNameServerStreamMap = useEtcResolverFiles ? parse(etcResolverFiles) : etcResolvConfMap;
        DnsServerAddresses defaultNameServerAddresses = etcResolvConfMap.get(etcResolvConf.getName());
        if (defaultNameServerAddresses == null) {
            Collection<DnsServerAddresses> values = etcResolvConfMap.values();
            if (values.isEmpty()) {
                throw new IllegalArgumentException(etcResolvConf + " didn't provide any name servers");
            }
            this.defaultNameServerAddresses = values.iterator().next();
        } else {
            this.defaultNameServerAddresses = defaultNameServerAddresses;
        }
        if (useEtcResolverFiles) {
            this.domainToNameServerStreamMap.putAll(etcResolvConfMap);
        }
    }

    public UnixResolverDnsServerAddressStreamProvider(String etcResolvConf, String etcResolverDir) throws IOException {
        this(etcResolvConf == null ? null : new File(etcResolvConf), etcResolverDir != null ? new File(etcResolverDir).listFiles() : null);
    }

    @Override // io.netty.resolver.dns.DnsServerAddressStreamProvider
    public DnsServerAddressStream nameServerAddressStream(String hostname) {
        while (true) {
            int i = hostname.indexOf(46, 1);
            if (i < 0 || i == hostname.length() - 1) {
                break;
            }
            DnsServerAddresses addresses = this.domainToNameServerStreamMap.get(hostname);
            if (addresses != null) {
                return addresses.stream();
            }
            hostname = hostname.substring(i + 1);
        }
        return this.defaultNameServerAddresses.stream();
    }

    private boolean mayOverrideNameServers() {
        return (this.domainToNameServerStreamMap.isEmpty() && this.defaultNameServerAddresses.stream().next() == null) ? false : true;
    }

    /* JADX WARN: Code restructure failed: missing block: B:57:0x0141, code lost:
        throw new java.lang.IllegalArgumentException("error parsing label nameserver in file " + r10 + ". value: " + r13);
     */
    /* JADX WARN: Removed duplicated region for block: B:124:0x027d  */
    /* JADX WARN: Removed duplicated region for block: B:125:0x0281  */
    /*
        Code decompiled incorrectly, please refer to instructions dump.
    */
    private static Map<String, DnsServerAddresses> parse(File... etcResolverFiles) throws IOException {
        FileReader fr;
        String str;
        int i;
        String str2;
        int i2;
        String line;
        String str3;
        int i3;
        FileReader fr2;
        char c;
        String maybeIP;
        int port;
        File[] fileArr = etcResolverFiles;
        String str4 = NAMESERVER_ROW_LABEL;
        Map<String, DnsServerAddresses> domainToNameServerStreamMap = new HashMap<>(fileArr.length << 1);
        int length = fileArr.length;
        int i4 = 0;
        int i5 = 0;
        loop0: while (i5 < length) {
            File etcResolverFile = fileArr[i5];
            if (etcResolverFile.isFile()) {
                FileReader fr3 = new FileReader(etcResolverFile);
                BufferedReader br = null;
                try {
                    br = new BufferedReader(fr3);
                    List<InetSocketAddress> addresses = new ArrayList<>(2);
                    String domainName = etcResolverFile.getName();
                    int port2 = 53;
                    String domainName2 = domainName;
                    List<InetSocketAddress> addresses2 = addresses;
                    while (true) {
                        String line2 = br.readLine();
                        if (line2 != null) {
                            String line3 = line2.trim();
                            try {
                            } catch (IllegalArgumentException e) {
                                e = e;
                                str2 = str4;
                                i2 = length;
                                fr = fr3;
                                line = line3;
                            }
                            if (line3.isEmpty()) {
                                str3 = str4;
                                i3 = length;
                                fr2 = fr3;
                            } else {
                                line = line3;
                                try {
                                    c = line.charAt(i4);
                                } catch (IllegalArgumentException e2) {
                                    e = e2;
                                    str2 = str4;
                                }
                                if (c == '#') {
                                    str3 = str4;
                                    i3 = length;
                                    fr2 = fr3;
                                } else if (c == ';') {
                                    str3 = str4;
                                    i3 = length;
                                    fr2 = fr3;
                                } else {
                                    if (line.startsWith(str4)) {
                                        int i6 = StringUtil.indexOfNonWhiteSpace(line, str4.length());
                                        str2 = str4;
                                        if (i6 < 0) {
                                            throw new IllegalArgumentException("error parsing label nameserver in file " + etcResolverFile + ". value: " + line);
                                        }
                                        try {
                                            int x = StringUtil.indexOfWhiteSpace(line, i6);
                                            i2 = length;
                                            if (x == -1) {
                                                try {
                                                    maybeIP = line.substring(i6);
                                                    fr = fr3;
                                                } catch (IllegalArgumentException e3) {
                                                    e = e3;
                                                    fr = fr3;
                                                    logger.warn("Could not parse entry. Ignoring line: {}", line, e);
                                                    str4 = str2;
                                                    fr3 = fr;
                                                    length = i2;
                                                    i4 = 0;
                                                } catch (Throwable th) {
                                                    th = th;
                                                    fr = fr3;
                                                    if (br != null) {
                                                    }
                                                    throw th;
                                                }
                                            } else {
                                                try {
                                                    int idx = StringUtil.indexOfNonWhiteSpace(line, x);
                                                    fr = fr3;
                                                    if (idx == -1 || line.charAt(idx) != '#') {
                                                        break loop0;
                                                    }
                                                    maybeIP = line.substring(i6, x);
                                                } catch (IllegalArgumentException e4) {
                                                    e = e4;
                                                    fr = fr3;
                                                    logger.warn("Could not parse entry. Ignoring line: {}", line, e);
                                                    str4 = str2;
                                                    fr3 = fr;
                                                    length = i2;
                                                    i4 = 0;
                                                }
                                            }
                                        } catch (IllegalArgumentException e5) {
                                            e = e5;
                                            i2 = length;
                                            fr = fr3;
                                            logger.warn("Could not parse entry. Ignoring line: {}", line, e);
                                            str4 = str2;
                                            fr3 = fr;
                                            length = i2;
                                            i4 = 0;
                                        }
                                        try {
                                            if (!NetUtil.isValidIpV4Address(maybeIP)) {
                                                try {
                                                    try {
                                                        if (!NetUtil.isValidIpV6Address(maybeIP)) {
                                                            int i7 = maybeIP.lastIndexOf(46);
                                                            if (i7 + 1 >= maybeIP.length()) {
                                                                throw new IllegalArgumentException("error parsing label nameserver in file " + etcResolverFile + ". invalid IP value: " + line);
                                                            }
                                                            int port3 = Integer.parseInt(maybeIP.substring(i7 + 1));
                                                            maybeIP = maybeIP.substring(0, i7);
                                                            port = port3;
                                                            addresses2.add(SocketUtils.socketAddress(maybeIP, port));
                                                            port2 = port;
                                                        }
                                                    } catch (IllegalArgumentException e6) {
                                                        e = e6;
                                                        logger.warn("Could not parse entry. Ignoring line: {}", line, e);
                                                        str4 = str2;
                                                        fr3 = fr;
                                                        length = i2;
                                                        i4 = 0;
                                                    }
                                                } catch (Throwable th2) {
                                                    th = th2;
                                                    if (br != null) {
                                                        fr.close();
                                                    } else {
                                                        br.close();
                                                    }
                                                    throw th;
                                                }
                                            }
                                            addresses2.add(SocketUtils.socketAddress(maybeIP, port));
                                            port2 = port;
                                        } catch (IllegalArgumentException e7) {
                                            e = e7;
                                            port2 = port;
                                            logger.warn("Could not parse entry. Ignoring line: {}", line, e);
                                            str4 = str2;
                                            fr3 = fr;
                                            length = i2;
                                            i4 = 0;
                                        }
                                        port = port2;
                                    } else {
                                        str2 = str4;
                                        i2 = length;
                                        fr = fr3;
                                        if (line.startsWith(DOMAIN_ROW_LABEL)) {
                                            int i8 = StringUtil.indexOfNonWhiteSpace(line, DOMAIN_ROW_LABEL.length());
                                            if (i8 < 0) {
                                                throw new IllegalArgumentException("error parsing label domain in file " + etcResolverFile + " value: " + line);
                                            }
                                            String domainName3 = line.substring(i8);
                                            try {
                                                if (!addresses2.isEmpty()) {
                                                    try {
                                                        putIfAbsent(domainToNameServerStreamMap, domainName3, addresses2);
                                                    } catch (IllegalArgumentException e8) {
                                                        e = e8;
                                                        domainName2 = domainName3;
                                                        logger.warn("Could not parse entry. Ignoring line: {}", line, e);
                                                        str4 = str2;
                                                        fr3 = fr;
                                                        length = i2;
                                                        i4 = 0;
                                                    }
                                                }
                                            } catch (IllegalArgumentException e9) {
                                                e = e9;
                                            }
                                            try {
                                                List<InetSocketAddress> addresses3 = new ArrayList<>(2);
                                                addresses2 = addresses3;
                                                domainName2 = domainName3;
                                            } catch (IllegalArgumentException e10) {
                                                e = e10;
                                                domainName2 = domainName3;
                                                logger.warn("Could not parse entry. Ignoring line: {}", line, e);
                                                str4 = str2;
                                                fr3 = fr;
                                                length = i2;
                                                i4 = 0;
                                            }
                                        } else {
                                            try {
                                                if (line.startsWith("port")) {
                                                    int i9 = StringUtil.indexOfNonWhiteSpace(line, "port".length());
                                                    if (i9 < 0) {
                                                        throw new IllegalArgumentException("error parsing label port in file " + etcResolverFile + " value: " + line);
                                                    }
                                                    int port4 = Integer.parseInt(line.substring(i9));
                                                    port2 = port4;
                                                } else if (line.startsWith(SORTLIST_ROW_LABEL)) {
                                                    logger.info("row type {} not supported. Ignoring line: {}", SORTLIST_ROW_LABEL, line);
                                                }
                                            } catch (IllegalArgumentException e11) {
                                                e = e11;
                                                logger.warn("Could not parse entry. Ignoring line: {}", line, e);
                                                str4 = str2;
                                                fr3 = fr;
                                                length = i2;
                                                i4 = 0;
                                            }
                                        }
                                    }
                                    str4 = str2;
                                    fr3 = fr;
                                    length = i2;
                                    i4 = 0;
                                }
                            }
                            str4 = str3;
                            fr3 = fr2;
                            length = i3;
                            i4 = 0;
                        } else {
                            str = str4;
                            i = length;
                            if (!addresses2.isEmpty()) {
                                putIfAbsent(domainToNameServerStreamMap, domainName2, addresses2);
                            }
                            br.close();
                        }
                    }
                } catch (Throwable th3) {
                    th = th3;
                    fr = fr3;
                }
            } else {
                str = str4;
                i = length;
            }
            i5++;
            i4 = 0;
            fileArr = etcResolverFiles;
            str4 = str;
            length = i;
        }
        return domainToNameServerStreamMap;
    }

    private static void putIfAbsent(Map<String, DnsServerAddresses> domainToNameServerStreamMap, String domainName, List<InetSocketAddress> addresses) {
        putIfAbsent(domainToNameServerStreamMap, domainName, DnsServerAddresses.sequential(addresses));
    }

    private static void putIfAbsent(Map<String, DnsServerAddresses> domainToNameServerStreamMap, String domainName, DnsServerAddresses addresses) {
        DnsServerAddresses existingAddresses = domainToNameServerStreamMap.put(domainName, addresses);
        if (existingAddresses != null) {
            domainToNameServerStreamMap.put(domainName, existingAddresses);
            logger.debug("Domain name {} already maps to addresses {} so new addresses {} will be discarded", domainName, existingAddresses, addresses);
        }
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    public static int parseEtcResolverFirstNdots() throws IOException {
        return parseEtcResolverFirstNdots(new File(ETC_RESOLV_CONF_FILE));
    }

    /* JADX WARN: Code restructure failed: missing block: B:10:0x0023, code lost:
        r3 = r3 + io.netty.resolver.dns.UnixResolverDnsServerAddressStreamProvider.NDOTS_LABEL.length();
        r0 = r3.indexOf(32, r3);
     */
    /* JADX WARN: Code restructure failed: missing block: B:11:0x002e, code lost:
        if (r0 >= 0) goto L19;
     */
    /* JADX WARN: Code restructure failed: missing block: B:12:0x0030, code lost:
        r5 = r3.length();
     */
    /* JADX WARN: Code restructure failed: missing block: B:13:0x0035, code lost:
        r5 = r0;
     */
    /* JADX WARN: Code restructure failed: missing block: B:14:0x0036, code lost:
        r5 = java.lang.Integer.parseInt(r3.substring(r3, r5));
     */
    /* JADX WARN: Code restructure failed: missing block: B:15:0x003f, code lost:
        r2.close();
     */
    /* JADX WARN: Code restructure failed: missing block: B:16:0x0042, code lost:
        return r5;
     */
    /* JADX WARN: Code restructure failed: missing block: B:8:0x001d, code lost:
        r3 = r3.indexOf(io.netty.resolver.dns.UnixResolverDnsServerAddressStreamProvider.NDOTS_LABEL);
     */
    /* JADX WARN: Code restructure failed: missing block: B:9:0x0021, code lost:
        if (r3 < 0) goto L20;
     */
    /*
        Code decompiled incorrectly, please refer to instructions dump.
    */
    static int parseEtcResolverFirstNdots(File etcResolvConf) throws IOException {
        FileReader fr = new FileReader(etcResolvConf);
        BufferedReader br = null;
        try {
            br = new BufferedReader(fr);
            while (true) {
                String line = br.readLine();
                if (line != null) {
                    if (line.startsWith(OPTIONS_ROW_LABEL)) {
                        break;
                    }
                } else {
                    break;
                }
            }
            br.close();
            return 1;
        } catch (Throwable th) {
            if (br == null) {
                fr.close();
            } else {
                br.close();
            }
            throw th;
        }
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    public static List<String> parseEtcResolverSearchDomains() throws IOException {
        return parseEtcResolverSearchDomains(new File(ETC_RESOLV_CONF_FILE));
    }

    static List<String> parseEtcResolverSearchDomains(File etcResolvConf) throws IOException {
        String localDomain = null;
        List<String> searchDomains = new ArrayList<>();
        FileReader fr = new FileReader(etcResolvConf);
        BufferedReader br = null;
        try {
            br = new BufferedReader(fr);
            while (true) {
                String line = br.readLine();
                if (line == null) {
                    break;
                } else if (localDomain == null && line.startsWith(DOMAIN_ROW_LABEL)) {
                    int i = StringUtil.indexOfNonWhiteSpace(line, DOMAIN_ROW_LABEL.length());
                    if (i >= 0) {
                        localDomain = line.substring(i);
                    }
                } else if (line.startsWith(SEARCH_ROW_LABEL)) {
                    int i2 = StringUtil.indexOfNonWhiteSpace(line, SEARCH_ROW_LABEL.length());
                    if (i2 >= 0) {
                        String[] domains = SEARCH_DOMAIN_PATTERN.split(line.substring(i2));
                        Collections.addAll(searchDomains, domains);
                    }
                }
            }
            br.close();
            return (localDomain == null || !searchDomains.isEmpty()) ? searchDomains : Collections.singletonList(localDomain);
        } catch (Throwable th) {
            if (br == null) {
                fr.close();
            } else {
                br.close();
            }
            throw th;
        }
    }
}
