package io.netty.util;

import androidx.recyclerview.widget.ItemTouchHelper;
import io.netty.util.internal.PlatformDependent;
import io.netty.util.internal.SocketUtils;
import io.netty.util.internal.StringUtil;
import io.netty.util.internal.SystemPropertyUtil;
import io.netty.util.internal.logging.InternalLogger;
import io.netty.util.internal.logging.InternalLoggerFactory;
import java.io.BufferedReader;
import java.io.File;
import java.io.FileReader;
import java.io.IOException;
import java.io.InputStream;
import java.io.InputStreamReader;
import java.net.Inet4Address;
import java.net.Inet6Address;
import java.net.InetAddress;
import java.net.InetSocketAddress;
import java.net.NetworkInterface;
import java.net.SocketException;
import java.net.UnknownHostException;
import java.security.AccessController;
import java.security.PrivilegedAction;
import java.util.ArrayList;
import java.util.Enumeration;
import java.util.Iterator;
import java.util.List;
import kotlin.UByte;
import kotlin.jvm.internal.ByteCompanionObject;
/* loaded from: classes.dex */
public final class NetUtil {
    private static final int IPV4_MAX_CHAR_BETWEEN_SEPARATOR = 3;
    private static final int IPV4_SEPARATORS = 3;
    private static final int IPV6_BYTE_COUNT = 16;
    private static final int IPV6_MAX_CHAR_BETWEEN_SEPARATOR = 4;
    private static final int IPV6_MAX_CHAR_COUNT = 39;
    private static final int IPV6_MAX_SEPARATORS = 8;
    private static final int IPV6_MIN_SEPARATORS = 2;
    private static final int IPV6_WORD_COUNT = 8;
    public static final InetAddress LOCALHOST;
    public static final Inet4Address LOCALHOST4;
    public static final Inet6Address LOCALHOST6;
    public static final NetworkInterface LOOPBACK_IF;
    public static final int SOMAXCONN;
    private static final InternalLogger logger;
    private static final boolean IPV4_PREFERRED = SystemPropertyUtil.getBoolean("java.net.preferIPv4Stack", false);
    private static final boolean IPV6_ADDRESSES_PREFERRED = SystemPropertyUtil.getBoolean("java.net.preferIPv6Addresses", false);

    /* JADX WARN: Code restructure failed: missing block: B:57:0x012c, code lost:
        if (r9 == null) goto L48;
     */
    /* JADX WARN: Code restructure failed: missing block: B:64:0x013a, code lost:
        if (r9 != null) goto L37;
     */
    /* JADX WARN: Code restructure failed: missing block: B:65:0x013c, code lost:
        io.netty.util.NetUtil.logger.debug("Using hard-coded IPv4 localhost address: {}", r6);
        r9 = r6;
     */
    /* JADX WARN: Multi-variable type inference failed */
    static {
        InternalLogger internalLoggerFactory = InternalLoggerFactory.getInstance(NetUtil.class);
        logger = internalLoggerFactory;
        internalLoggerFactory.debug("-Djava.net.preferIPv4Stack: {}", Boolean.valueOf(IPV4_PREFERRED));
        logger.debug("-Djava.net.preferIPv6Addresses: {}", Boolean.valueOf(IPV6_ADDRESSES_PREFERRED));
        byte[] LOCALHOST4_BYTES = {ByteCompanionObject.MAX_VALUE, 0, 0, 1};
        byte[] LOCALHOST6_BYTES = {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1};
        Inet4Address localhost4 = null;
        try {
            localhost4 = (Inet4Address) InetAddress.getByAddress("localhost", LOCALHOST4_BYTES);
        } catch (Exception e) {
            PlatformDependent.throwException(e);
        }
        LOCALHOST4 = localhost4;
        Inet6Address localhost6 = null;
        try {
            localhost6 = (Inet6Address) InetAddress.getByAddress("localhost", LOCALHOST6_BYTES);
        } catch (Exception e2) {
            PlatformDependent.throwException(e2);
        }
        LOCALHOST6 = localhost6;
        List<NetworkInterface> ifaces = new ArrayList<>();
        try {
            Enumeration<NetworkInterface> interfaces = NetworkInterface.getNetworkInterfaces();
            if (interfaces != null) {
                while (interfaces.hasMoreElements()) {
                    NetworkInterface iface = interfaces.nextElement();
                    if (SocketUtils.addressesFromNetworkInterface(iface).hasMoreElements()) {
                        ifaces.add(iface);
                    }
                }
            }
        } catch (SocketException e3) {
            logger.warn("Failed to retrieve the list of available network interfaces", (Throwable) e3);
        }
        NetworkInterface loopbackIface = null;
        InetAddress loopbackAddr = null;
        Iterator<NetworkInterface> it = ifaces.iterator();
        loop1: while (true) {
            if (!it.hasNext()) {
                break;
            }
            NetworkInterface iface2 = it.next();
            Enumeration<InetAddress> i = SocketUtils.addressesFromNetworkInterface(iface2);
            while (i.hasMoreElements()) {
                InetAddress addr = i.nextElement();
                if (addr.isLoopbackAddress()) {
                    loopbackIface = iface2;
                    loopbackAddr = addr;
                    break loop1;
                }
            }
        }
        if (loopbackIface == null) {
            try {
                Iterator<NetworkInterface> it2 = ifaces.iterator();
                while (true) {
                    if (!it2.hasNext()) {
                        break;
                    }
                    NetworkInterface iface3 = it2.next();
                    if (iface3.isLoopback()) {
                        Enumeration<InetAddress> i2 = SocketUtils.addressesFromNetworkInterface(iface3);
                        if (i2.hasMoreElements()) {
                            loopbackIface = iface3;
                            loopbackAddr = i2.nextElement();
                            break;
                        }
                    }
                }
                if (loopbackIface == null) {
                    logger.warn("Failed to find the loopback interface");
                }
            } catch (SocketException e4) {
                logger.warn("Failed to find the loopback interface", (Throwable) e4);
            }
        }
        if (loopbackIface != null) {
            logger.debug("Loopback interface: {} ({}, {})", loopbackIface.getName(), loopbackIface.getDisplayName(), loopbackAddr.getHostAddress());
        } else if (loopbackAddr == null) {
            try {
                if (NetworkInterface.getByInetAddress(LOCALHOST6) != null) {
                    logger.debug("Using hard-coded IPv6 localhost address: {}", localhost6);
                    loopbackAddr = localhost6;
                }
            } catch (Exception e5) {
            } catch (Throwable th) {
                if (loopbackAddr == null) {
                    logger.debug("Using hard-coded IPv4 localhost address: {}", localhost4);
                }
                throw th;
            }
        }
        LOOPBACK_IF = loopbackIface;
        LOCALHOST = loopbackAddr;
        SOMAXCONN = ((Integer) AccessController.doPrivileged(new PrivilegedAction<Integer>() { // from class: io.netty.util.NetUtil.1
            /* JADX WARN: Can't rename method to resolve collision */
            @Override // java.security.PrivilegedAction
            public Integer run() {
                int somaxconn = PlatformDependent.isWindows() ? ItemTouchHelper.Callback.DEFAULT_DRAG_ANIMATION_DURATION : 128;
                File file = new File("/proc/sys/net/core/somaxconn");
                BufferedReader in = null;
                try {
                    try {
                        try {
                            if (file.exists()) {
                                in = new BufferedReader(new FileReader(file));
                                somaxconn = Integer.parseInt(in.readLine());
                                if (NetUtil.logger.isDebugEnabled()) {
                                    NetUtil.logger.debug("{}: {}", file, Integer.valueOf(somaxconn));
                                }
                            } else {
                                Integer tmp = null;
                                if (SystemPropertyUtil.getBoolean("io.netty.net.somaxconn.trySysctl", false)) {
                                    tmp = NetUtil.sysctlGetInt("kern.ipc.somaxconn");
                                    if (tmp == null) {
                                        tmp = NetUtil.sysctlGetInt("kern.ipc.soacceptqueue");
                                        if (tmp != null) {
                                            somaxconn = tmp.intValue();
                                        }
                                    } else {
                                        somaxconn = tmp.intValue();
                                    }
                                }
                                if (tmp == null) {
                                    NetUtil.logger.debug("Failed to get SOMAXCONN from sysctl and file {}. Default: {}", file, Integer.valueOf(somaxconn));
                                }
                            }
                        } catch (Exception e6) {
                            NetUtil.logger.debug("Failed to get SOMAXCONN from sysctl and file {}. Default: {}", file, Integer.valueOf(somaxconn), e6);
                            if (0 != 0) {
                                in.close();
                            }
                        }
                        if (in != null) {
                            in.close();
                        }
                    } catch (Throwable th2) {
                        if (0 != 0) {
                            try {
                                in.close();
                            } catch (Exception e7) {
                            }
                        }
                        throw th2;
                    }
                } catch (Exception e8) {
                }
                return Integer.valueOf(somaxconn);
            }
        })).intValue();
    }

    /* JADX INFO: Access modifiers changed from: private */
    public static Integer sysctlGetInt(String sysctlKey) throws IOException {
        Process process = new ProcessBuilder("sysctl", sysctlKey).start();
        try {
            InputStream is = process.getInputStream();
            InputStreamReader isr = new InputStreamReader(is);
            BufferedReader br = new BufferedReader(isr);
            String line = br.readLine();
            if (line.startsWith(sysctlKey)) {
                for (int i = line.length() - 1; i > sysctlKey.length(); i--) {
                    if (!Character.isDigit(line.charAt(i))) {
                        Integer valueOf = Integer.valueOf(line.substring(i + 1));
                        br.close();
                        return valueOf;
                    }
                }
            }
            br.close();
            if (process != null) {
                process.destroy();
            }
            return null;
        } finally {
            if (process != null) {
                process.destroy();
            }
        }
    }

    public static boolean isIpV4StackPreferred() {
        return IPV4_PREFERRED;
    }

    public static boolean isIpV6AddressesPreferred() {
        return IPV6_ADDRESSES_PREFERRED;
    }

    public static byte[] createByteArrayFromIpAddressString(String ipAddressString) {
        if (isValidIpV4Address(ipAddressString)) {
            return validIpV4ToBytes(ipAddressString);
        }
        if (isValidIpV6Address(ipAddressString)) {
            if (ipAddressString.charAt(0) == '[') {
                ipAddressString = ipAddressString.substring(1, ipAddressString.length() - 1);
            }
            int percentPos = ipAddressString.indexOf(37);
            if (percentPos >= 0) {
                ipAddressString = ipAddressString.substring(0, percentPos);
            }
            return getIPv6ByName(ipAddressString, true);
        }
        return null;
    }

    private static int decimalDigit(String str, int pos) {
        return str.charAt(pos) - '0';
    }

    private static byte ipv4WordToByte(String ip, int from, int toExclusive) {
        int ret = decimalDigit(ip, from);
        int from2 = from + 1;
        if (from2 == toExclusive) {
            return (byte) ret;
        }
        int ret2 = (ret * 10) + decimalDigit(ip, from2);
        int from3 = from2 + 1;
        if (from3 == toExclusive) {
            return (byte) ret2;
        }
        return (byte) ((ret2 * 10) + decimalDigit(ip, from3));
    }

    static byte[] validIpV4ToBytes(String ip) {
        int i = ip.indexOf(46, 1);
        int i2 = ip.indexOf(46, i + 2);
        int i3 = ip.indexOf(46, i2 + 2);
        return new byte[]{ipv4WordToByte(ip, 0, i), ipv4WordToByte(ip, i + 1, i2), ipv4WordToByte(ip, i2 + 1, i3), ipv4WordToByte(ip, i3 + 1, ip.length())};
    }

    public static String intToIpAddress(int i) {
        StringBuilder buf = new StringBuilder(15);
        buf.append((i >> 24) & 255);
        buf.append('.');
        buf.append((i >> 16) & 255);
        buf.append('.');
        buf.append((i >> 8) & 255);
        buf.append('.');
        buf.append(i & 255);
        return buf.toString();
    }

    public static String bytesToIpAddress(byte[] bytes) {
        return bytesToIpAddress(bytes, 0, bytes.length);
    }

    public static String bytesToIpAddress(byte[] bytes, int offset, int length) {
        if (length != 4) {
            if (length == 16) {
                return toAddressString(bytes, offset, false);
            }
            throw new IllegalArgumentException("length: " + length + " (expected: 4 or 16)");
        }
        StringBuilder sb = new StringBuilder(15);
        sb.append(bytes[offset] & UByte.MAX_VALUE);
        sb.append('.');
        sb.append(bytes[offset + 1] & UByte.MAX_VALUE);
        sb.append('.');
        sb.append(bytes[offset + 2] & UByte.MAX_VALUE);
        sb.append('.');
        sb.append(bytes[offset + 3] & UByte.MAX_VALUE);
        return sb.toString();
    }

    public static boolean isValidIpV6Address(String ip) {
        return isValidIpV6Address((CharSequence) ip);
    }

    public static boolean isValidIpV6Address(CharSequence ip) {
        int start;
        int colons;
        int compressBegin;
        int end = ip.length();
        if (end < 2) {
            return false;
        }
        char c = ip.charAt(0);
        if (c == '[') {
            end--;
            if (ip.charAt(end) != ']') {
                return false;
            }
            start = 1;
            c = ip.charAt(1);
        } else {
            start = 0;
        }
        if (c == ':') {
            if (ip.charAt(start + 1) != ':') {
                return false;
            }
            colons = 2;
            compressBegin = start;
            start += 2;
        } else {
            colons = 0;
            compressBegin = -1;
        }
        int wordLen = 0;
        int i = start;
        while (true) {
            if (i >= end) {
                break;
            }
            char c2 = ip.charAt(i);
            if (isValidHexChar(c2)) {
                if (wordLen >= 4) {
                    return false;
                }
                wordLen++;
            } else if (c2 == '%') {
                end = i;
                break;
            } else if (c2 != '.') {
                if (c2 != ':' || colons > 7) {
                    return false;
                }
                if (ip.charAt(i - 1) == ':') {
                    if (compressBegin >= 0) {
                        return false;
                    }
                    compressBegin = i - 1;
                } else {
                    wordLen = 0;
                }
                colons++;
            } else if ((compressBegin >= 0 || colons == 6) && ((colons != 7 || compressBegin < start) && colons <= 7)) {
                int ipv4Start = i - wordLen;
                int j = ipv4Start - 2;
                if (isValidIPv4MappedChar(ip.charAt(j))) {
                    if (!isValidIPv4MappedChar(ip.charAt(j - 1)) || !isValidIPv4MappedChar(ip.charAt(j - 2)) || !isValidIPv4MappedChar(ip.charAt(j - 3))) {
                        return false;
                    }
                    j -= 5;
                }
                while (j >= start) {
                    char tmpChar = ip.charAt(j);
                    if (tmpChar != '0' && tmpChar != ':') {
                        return false;
                    }
                    j--;
                }
                int ipv4End = AsciiString.indexOf(ip, '%', ipv4Start + 7);
                if (ipv4End < 0) {
                    ipv4End = end;
                }
                return isValidIpV4Address(ip, ipv4Start, ipv4End);
            } else {
                return false;
            }
            i++;
        }
        if (compressBegin < 0) {
            return colons == 7 && wordLen > 0;
        }
        if (compressBegin + 2 != end) {
            if (wordLen <= 0) {
                return false;
            }
            if (colons >= 8 && compressBegin > start) {
                return false;
            }
        }
        return true;
    }

    private static boolean isValidIpV4Word(CharSequence word, int from, int toExclusive) {
        char c0;
        char c2;
        int len = toExclusive - from;
        if (len < 1 || len > 3 || (c0 = word.charAt(from)) < '0') {
            return false;
        }
        if (len == 3) {
            char c1 = word.charAt(from + 1);
            if (c1 < '0' || (c2 = word.charAt(from + 2)) < '0') {
                return false;
            }
            if (c0 > '1' || c1 > '9' || c2 > '9') {
                if (c0 != '2' || c1 > '5') {
                    return false;
                }
                if (c2 > '5' && (c1 >= '5' || c2 > '9')) {
                    return false;
                }
            }
            return true;
        } else if (c0 <= '9') {
            return len == 1 || isValidNumericChar(word.charAt(from + 1));
        } else {
            return false;
        }
    }

    private static boolean isValidHexChar(char c) {
        return (c >= '0' && c <= '9') || (c >= 'A' && c <= 'F') || (c >= 'a' && c <= 'f');
    }

    private static boolean isValidNumericChar(char c) {
        return c >= '0' && c <= '9';
    }

    private static boolean isValidIPv4MappedChar(char c) {
        return c == 'f' || c == 'F';
    }

    private static boolean isValidIPv4MappedSeparators(byte b0, byte b1, boolean mustBeZero) {
        return b0 == b1 && (b0 == 0 || (!mustBeZero && b1 == -1));
    }

    private static boolean isValidIPv4Mapped(byte[] bytes, int currentIndex, int compressBegin, int compressLength) {
        boolean mustBeZero = compressBegin + compressLength >= 14;
        return currentIndex <= 12 && currentIndex >= 2 && (!mustBeZero || compressBegin < 12) && isValidIPv4MappedSeparators(bytes[currentIndex + (-1)], bytes[currentIndex + (-2)], mustBeZero) && PlatformDependent.isZero(bytes, 0, currentIndex + (-3));
    }

    public static boolean isValidIpV4Address(CharSequence ip) {
        return isValidIpV4Address(ip, 0, ip.length());
    }

    public static boolean isValidIpV4Address(String ip) {
        return isValidIpV4Address(ip, 0, ip.length());
    }

    private static boolean isValidIpV4Address(CharSequence ip, int from, int toExcluded) {
        if (ip instanceof String) {
            return isValidIpV4Address((String) ip, from, toExcluded);
        }
        if (ip instanceof AsciiString) {
            return isValidIpV4Address((AsciiString) ip, from, toExcluded);
        }
        return isValidIpV4Address0(ip, from, toExcluded);
    }

    private static boolean isValidIpV4Address(String ip, int from, int toExcluded) {
        int i;
        int from2;
        int i2;
        int from3;
        int i3;
        int len = toExcluded - from;
        return len <= 15 && len >= 7 && (i = ip.indexOf(46, from + 1)) > 0 && isValidIpV4Word(ip, from, i) && (i2 = ip.indexOf(46, (from2 = i + 2))) > 0 && isValidIpV4Word(ip, from2 + (-1), i2) && (i3 = ip.indexOf(46, (from3 = i2 + 2))) > 0 && isValidIpV4Word(ip, from3 + (-1), i3) && isValidIpV4Word(ip, i3 + 1, toExcluded);
    }

    private static boolean isValidIpV4Address(AsciiString ip, int from, int toExcluded) {
        int i;
        int from2;
        int i2;
        int from3;
        int i3;
        int len = toExcluded - from;
        return len <= 15 && len >= 7 && (i = ip.indexOf('.', from + 1)) > 0 && isValidIpV4Word(ip, from, i) && (i2 = ip.indexOf('.', (from2 = i + 2))) > 0 && isValidIpV4Word(ip, from2 + (-1), i2) && (i3 = ip.indexOf('.', (from3 = i2 + 2))) > 0 && isValidIpV4Word(ip, from3 + (-1), i3) && isValidIpV4Word(ip, i3 + 1, toExcluded);
    }

    private static boolean isValidIpV4Address0(CharSequence ip, int from, int toExcluded) {
        int i;
        int from2;
        int i2;
        int from3;
        int i3;
        int len = toExcluded - from;
        return len <= 15 && len >= 7 && (i = AsciiString.indexOf(ip, '.', from + 1)) > 0 && isValidIpV4Word(ip, from, i) && (i2 = AsciiString.indexOf(ip, '.', (from2 = i + 2))) > 0 && isValidIpV4Word(ip, from2 + (-1), i2) && (i3 = AsciiString.indexOf(ip, '.', (from3 = i2 + 2))) > 0 && isValidIpV4Word(ip, from3 + (-1), i3) && isValidIpV4Word(ip, i3 + 1, toExcluded);
    }

    public static Inet6Address getByName(CharSequence ip) {
        return getByName(ip, true);
    }

    public static Inet6Address getByName(CharSequence ip, boolean ipv4Mapped) {
        byte[] bytes = getIPv6ByName(ip, ipv4Mapped);
        if (bytes == null) {
            return null;
        }
        try {
            return Inet6Address.getByAddress((String) null, bytes, -1);
        } catch (UnknownHostException e) {
            throw new RuntimeException(e);
        }
    }

    /* JADX WARN: Code restructure failed: missing block: B:102:0x0172, code lost:
        if ((r8 - r7) <= 3) goto L127;
     */
    /*
        Code decompiled incorrectly, please refer to instructions dump.
    */
    private static byte[] getIPv6ByName(CharSequence ip, boolean ipv4Mapped) {
        int currentIndex;
        byte[] bytes = new byte[16];
        int ipLength = ip.length();
        int compressBegin = 0;
        int compressLength = 0;
        int currentIndex2 = 0;
        int value = 0;
        int begin = -1;
        int i = 0;
        int ipv6Separators = 0;
        int ipv4Separators = 0;
        boolean needsShift = false;
        while (i < ipLength) {
            char c = ip.charAt(i);
            if (c == '.') {
                ipv4Separators++;
                int tmp = i - begin;
                if (tmp > 3 || begin < 0 || ipv4Separators > 3 || ((ipv6Separators > 0 && currentIndex2 + compressLength < 12) || i + 1 >= ipLength || currentIndex2 >= bytes.length || (ipv4Separators == 1 && (!ipv4Mapped || ((currentIndex2 != 0 && !isValidIPv4Mapped(bytes, currentIndex2, compressBegin, compressLength)) || ((tmp == 3 && (!isValidNumericChar(ip.charAt(i - 1)) || !isValidNumericChar(ip.charAt(i - 2)) || !isValidNumericChar(ip.charAt(i - 3)))) || ((tmp == 2 && (!isValidNumericChar(ip.charAt(i - 1)) || !isValidNumericChar(ip.charAt(i - 2)))) || (tmp == 1 && !isValidNumericChar(ip.charAt(i - 1)))))))))) {
                    return null;
                }
                int value2 = value << ((3 - tmp) << 2);
                int begin2 = ((value2 & 15) * 100) + (((value2 >> 4) & 15) * 10) + ((value2 >> 8) & 15);
                if (begin2 < 0 || begin2 > 255) {
                    return null;
                }
                bytes[currentIndex2] = (byte) begin2;
                value = 0;
                currentIndex2++;
                begin = -1;
            } else if (c == ':') {
                ipv6Separators++;
                if (i - begin > 4 || ipv4Separators > 0 || ipv6Separators > 8 || currentIndex2 + 1 >= bytes.length) {
                    return null;
                }
                int value3 = value << ((4 - (i - begin)) << 2);
                if (compressLength > 0) {
                    compressLength -= 2;
                }
                int currentIndex3 = currentIndex2 + 1;
                bytes[currentIndex2] = (byte) (((value3 & 15) << 4) | ((value3 >> 4) & 15));
                currentIndex2 = currentIndex3 + 1;
                bytes[currentIndex3] = (byte) ((((value3 >> 8) & 15) << 4) | ((value3 >> 12) & 15));
                int tmp2 = i + 1;
                if (tmp2 < ipLength && ip.charAt(tmp2) == ':') {
                    int tmp3 = tmp2 + 1;
                    if (compressBegin != 0 || (tmp3 < ipLength && ip.charAt(tmp3) == ':')) {
                        return null;
                    }
                    ipv6Separators++;
                    needsShift = ipv6Separators == 2 && value3 == 0;
                    compressBegin = currentIndex2;
                    compressLength = (bytes.length - compressBegin) - 2;
                    i++;
                }
                value = 0;
                begin = -1;
            } else if (!isValidHexChar(c) || (ipv4Separators > 0 && !isValidNumericChar(c))) {
                return null;
            } else {
                if (begin < 0) {
                    begin = i;
                } else if (i - begin > 4) {
                    return null;
                }
                value += StringUtil.decodeHexNibble(c) << ((i - begin) << 2);
            }
            i++;
        }
        boolean isCompressed = compressBegin > 0;
        if (ipv4Separators > 0) {
            int i2 = begin > 0 ? 3 : 3;
            if (ipv4Separators == i2 && currentIndex2 < bytes.length) {
                if (ipv6Separators == 0) {
                    compressLength = 12;
                } else if (ipv6Separators < 2 || ((isCompressed || ipv6Separators != 6 || ip.charAt(0) == ':') && (!isCompressed || ipv6Separators >= 8 || (ip.charAt(0) == ':' && compressBegin > 2)))) {
                    return null;
                } else {
                    compressLength -= 2;
                }
                int value4 = value << ((3 - (i - begin)) << 2);
                int begin3 = ((value4 & 15) * 100) + (((value4 >> 4) & 15) * 10) + ((value4 >> 8) & 15);
                if (begin3 < 0 || begin3 > 255) {
                    return null;
                }
                currentIndex = currentIndex2 + 1;
                bytes[currentIndex2] = (byte) begin3;
            }
            return null;
        }
        int tmp4 = ipLength - 1;
        if ((begin > 0 && i - begin > 4) || ipv6Separators < 2 || ((!isCompressed && (ipv6Separators + 1 != 8 || ip.charAt(0) == ':' || ip.charAt(tmp4) == ':')) || ((isCompressed && (ipv6Separators > 8 || (ipv6Separators == 8 && ((compressBegin <= 2 && ip.charAt(0) != ':') || (compressBegin >= 14 && ip.charAt(tmp4) != ':'))))) || currentIndex2 + 1 >= bytes.length || ((begin < 0 && ip.charAt(tmp4 - 1) != ':') || (compressBegin > 2 && ip.charAt(0) == ':'))))) {
            return null;
        }
        if (begin >= 0 && i - begin <= 4) {
            value <<= (4 - (i - begin)) << 2;
        }
        int currentIndex4 = currentIndex2 + 1;
        bytes[currentIndex2] = (byte) (((value & 15) << 4) | ((value >> 4) & 15));
        bytes[currentIndex4] = (byte) ((((value >> 8) & 15) << 4) | ((value >> 12) & 15));
        currentIndex = currentIndex4 + 1;
        int currentIndex5 = currentIndex + compressLength;
        if (needsShift || currentIndex5 >= bytes.length) {
            if (currentIndex5 >= bytes.length) {
                compressBegin++;
            }
            for (int i3 = currentIndex; i3 < bytes.length; i3++) {
                int begin4 = bytes.length - 1;
                while (begin4 >= compressBegin) {
                    bytes[begin4] = bytes[begin4 - 1];
                    begin4--;
                }
                bytes[begin4] = 0;
                compressBegin++;
            }
        } else {
            for (int i4 = 0; i4 < compressLength; i4++) {
                int begin5 = i4 + compressBegin;
                int currentIndex6 = begin5 + compressLength;
                if (currentIndex6 >= bytes.length) {
                    break;
                }
                bytes[currentIndex6] = bytes[begin5];
                bytes[begin5] = 0;
            }
        }
        if (ipv4Separators > 0) {
            bytes[11] = -1;
            bytes[10] = -1;
        }
        return bytes;
    }

    public static String toSocketAddressString(InetSocketAddress addr) {
        StringBuilder sb;
        String port = String.valueOf(addr.getPort());
        if (addr.isUnresolved()) {
            String hostname = getHostname(addr);
            sb = newSocketAddressStringBuilder(hostname, port, !isValidIpV6Address(hostname));
        } else {
            InetAddress address = addr.getAddress();
            String hostString = toAddressString(address);
            sb = newSocketAddressStringBuilder(hostString, port, address instanceof Inet4Address);
        }
        sb.append(':');
        sb.append(port);
        return sb.toString();
    }

    public static String toSocketAddressString(String host, int port) {
        String portStr = String.valueOf(port);
        StringBuilder newSocketAddressStringBuilder = newSocketAddressStringBuilder(host, portStr, !isValidIpV6Address(host));
        newSocketAddressStringBuilder.append(':');
        newSocketAddressStringBuilder.append(portStr);
        return newSocketAddressStringBuilder.toString();
    }

    private static StringBuilder newSocketAddressStringBuilder(String host, String port, boolean ipv4) {
        int hostLen = host.length();
        if (ipv4) {
            StringBuilder sb = new StringBuilder(hostLen + 1 + port.length());
            sb.append(host);
            return sb;
        }
        StringBuilder stringBuilder = new StringBuilder(hostLen + 3 + port.length());
        if (hostLen > 1 && host.charAt(0) == '[' && host.charAt(hostLen - 1) == ']') {
            stringBuilder.append(host);
            return stringBuilder;
        }
        stringBuilder.append('[');
        stringBuilder.append(host);
        stringBuilder.append(']');
        return stringBuilder;
    }

    public static String toAddressString(InetAddress ip) {
        return toAddressString(ip, false);
    }

    public static String toAddressString(InetAddress ip, boolean ipv4Mapped) {
        if (ip instanceof Inet4Address) {
            return ip.getHostAddress();
        }
        if (!(ip instanceof Inet6Address)) {
            throw new IllegalArgumentException("Unhandled type: " + ip);
        }
        return toAddressString(ip.getAddress(), 0, ipv4Mapped);
    }

    /* JADX WARN: Incorrect condition in loop: B:29:0x0060 */
    /*
        Code decompiled incorrectly, please refer to instructions dump.
    */
    private static String toAddressString(byte[] bytes, int offset, boolean ipv4Mapped) {
        boolean isIpv4Mapped;
        int currentLength;
        int[] words = new int[8];
        int end = offset + words.length;
        int i = offset;
        while (true) {
            isIpv4Mapped = true;
            if (i >= end) {
                break;
            }
            words[i] = (bytes[(i << 1) + 1] & UByte.MAX_VALUE) | ((bytes[i << 1] & UByte.MAX_VALUE) << 8);
            i++;
        }
        int currentStart = -1;
        int shortestStart = -1;
        int shortestLength = 0;
        int i2 = 0;
        while (i2 < words.length) {
            if (words[i2] == 0) {
                if (currentStart < 0) {
                    currentStart = i2;
                }
            } else if (currentStart >= 0) {
                int currentLength2 = i2 - currentStart;
                if (currentLength2 > shortestLength) {
                    shortestStart = currentStart;
                    shortestLength = currentLength2;
                }
                currentStart = -1;
            }
            i2++;
        }
        if (currentStart >= 0 && (currentLength = i2 - currentStart) > shortestLength) {
            shortestStart = currentStart;
            shortestLength = currentLength;
        }
        if (shortestLength == 1) {
            shortestLength = 0;
            shortestStart = -1;
        }
        int shortestEnd = shortestStart + shortestLength;
        StringBuilder b = new StringBuilder(39);
        if (shortestEnd < 0) {
            b.append(Integer.toHexString(words[0]));
            for (int i3 = 1; i3 < i; i3++) {
                b.append(':');
                b.append(Integer.toHexString(words[i3]));
            }
        } else {
            if (inRangeEndExclusive(0, shortestStart, shortestEnd)) {
                b.append("::");
                if (!ipv4Mapped || shortestEnd != 5 || words[5] != 65535) {
                    isIpv4Mapped = false;
                }
            } else {
                b.append(Integer.toHexString(words[0]));
                isIpv4Mapped = false;
            }
            for (int i4 = 1; i4 < words.length; i4++) {
                if (!inRangeEndExclusive(i4, shortestStart, shortestEnd)) {
                    if (!inRangeEndExclusive(i4 - 1, shortestStart, shortestEnd)) {
                        if (!isIpv4Mapped || i4 == 6) {
                            b.append(':');
                        } else {
                            b.append('.');
                        }
                    }
                    if (isIpv4Mapped && i4 > 5) {
                        b.append(words[i4] >> 8);
                        b.append('.');
                        b.append(words[i4] & 255);
                    } else {
                        b.append(Integer.toHexString(words[i4]));
                    }
                } else if (!inRangeEndExclusive(i4 - 1, shortestStart, shortestEnd)) {
                    b.append("::");
                }
            }
        }
        return b.toString();
    }

    public static String getHostname(InetSocketAddress addr) {
        return PlatformDependent.javaVersion() >= 7 ? addr.getHostString() : addr.getHostName();
    }

    private static boolean inRangeEndExclusive(int value, int start, int end) {
        return value >= start && value < end;
    }

    private NetUtil() {
    }
}
