package io.netty.util.internal;

import io.netty.util.internal.logging.InternalLogger;
import io.netty.util.internal.logging.InternalLoggerFactory;
import java.lang.Thread;
import java.security.SecureRandom;
import java.util.Random;
import java.util.concurrent.BlockingQueue;
import java.util.concurrent.LinkedBlockingQueue;
import java.util.concurrent.TimeUnit;
import java.util.concurrent.atomic.AtomicLong;
/* loaded from: classes.dex */
public final class ThreadLocalRandom extends Random {
    private static final long addend = 11;
    private static volatile long initialSeedUniquifier = 0;
    private static final long mask = 281474976710655L;
    private static final long multiplier = 25214903917L;
    private static volatile long seedGeneratorEndTime = 0;
    private static final long seedGeneratorStartTime;
    private static final Thread seedGeneratorThread;
    private static final BlockingQueue<Long> seedQueue;
    private static final long serialVersionUID = -5851777807851030925L;
    boolean initialized;
    private long pad0;
    private long pad1;
    private long pad2;
    private long pad3;
    private long pad4;
    private long pad5;
    private long pad6;
    private long pad7;
    private long rnd;
    private static final InternalLogger logger = InternalLoggerFactory.getInstance(ThreadLocalRandom.class);
    private static final AtomicLong seedUniquifier = new AtomicLong();

    static {
        initialSeedUniquifier = SystemPropertyUtil.getLong("io.netty.initialSeedUniquifier", 0L);
        if (initialSeedUniquifier == 0) {
            boolean secureRandom = SystemPropertyUtil.getBoolean("java.util.secureRandomSeed", false);
            if (secureRandom) {
                seedQueue = new LinkedBlockingQueue();
                seedGeneratorStartTime = System.nanoTime();
                Thread thread = new Thread("initialSeedUniquifierGenerator") { // from class: io.netty.util.internal.ThreadLocalRandom.1
                    @Override // java.lang.Thread, java.lang.Runnable
                    public void run() {
                        SecureRandom random = new SecureRandom();
                        byte[] seed = random.generateSeed(8);
                        long unused = ThreadLocalRandom.seedGeneratorEndTime = System.nanoTime();
                        long s = ((seed[0] & 255) << 56) | ((seed[1] & 255) << 48) | ((seed[2] & 255) << 40) | ((seed[3] & 255) << 32) | ((seed[4] & 255) << 24) | ((seed[5] & 255) << 16) | ((seed[6] & 255) << 8) | (255 & seed[7]);
                        ThreadLocalRandom.seedQueue.add(Long.valueOf(s));
                    }
                };
                seedGeneratorThread = thread;
                thread.setDaemon(true);
                seedGeneratorThread.setUncaughtExceptionHandler(new Thread.UncaughtExceptionHandler() { // from class: io.netty.util.internal.ThreadLocalRandom.2
                    @Override // java.lang.Thread.UncaughtExceptionHandler
                    public void uncaughtException(Thread t, Throwable e) {
                        ThreadLocalRandom.logger.debug("An exception has been raised by {}", t.getName(), e);
                    }
                });
                seedGeneratorThread.start();
                return;
            }
            initialSeedUniquifier = mix64(System.currentTimeMillis()) ^ mix64(System.nanoTime());
            seedGeneratorThread = null;
            seedQueue = null;
            seedGeneratorStartTime = 0L;
            return;
        }
        seedGeneratorThread = null;
        seedQueue = null;
        seedGeneratorStartTime = 0L;
    }

    public static void setInitialSeedUniquifier(long initialSeedUniquifier2) {
        initialSeedUniquifier = initialSeedUniquifier2;
    }

    /* JADX WARN: Code restructure failed: missing block: B:19:0x0046, code lost:
        r0 = r14.longValue();
     */
    /*
        Code decompiled incorrectly, please refer to instructions dump.
    */
    public static long getInitialSeedUniquifier() {
        Long seed;
        long initialSeedUniquifier2 = initialSeedUniquifier;
        if (initialSeedUniquifier2 != 0) {
            return initialSeedUniquifier2;
        }
        synchronized (ThreadLocalRandom.class) {
            long initialSeedUniquifier3 = initialSeedUniquifier;
            if (initialSeedUniquifier3 != 0) {
                return initialSeedUniquifier3;
            }
            long deadLine = seedGeneratorStartTime + TimeUnit.SECONDS.toNanos(3L);
            boolean interrupted = false;
            while (true) {
                long waitTime = deadLine - System.nanoTime();
                if (waitTime <= 0) {
                    try {
                        seed = seedQueue.poll();
                    } catch (InterruptedException e) {
                        interrupted = true;
                        logger.warn("Failed to generate a seed from SecureRandom due to an InterruptedException.");
                    }
                } else {
                    seed = seedQueue.poll(waitTime, TimeUnit.NANOSECONDS);
                }
                if (seed != null) {
                    break;
                } else if (waitTime <= 0) {
                    seedGeneratorThread.interrupt();
                    logger.warn("Failed to generate a seed from SecureRandom within {} seconds. Not enough entropy?", (Object) 3L);
                    break;
                }
            }
            long initialSeedUniquifier4 = (initialSeedUniquifier3 ^ 3627065505421648153L) ^ Long.reverse(System.nanoTime());
            initialSeedUniquifier = initialSeedUniquifier4;
            if (interrupted) {
                Thread.currentThread().interrupt();
                seedGeneratorThread.interrupt();
            }
            if (seedGeneratorEndTime == 0) {
                seedGeneratorEndTime = System.nanoTime();
            }
            return initialSeedUniquifier4;
        }
    }

    private static long newSeed() {
        long current;
        long actualCurrent;
        long next;
        do {
            current = seedUniquifier.get();
            actualCurrent = current != 0 ? current : getInitialSeedUniquifier();
            next = 181783497276652981L * actualCurrent;
        } while (!seedUniquifier.compareAndSet(current, next));
        if (current == 0 && logger.isDebugEnabled()) {
            if (seedGeneratorEndTime != 0) {
                logger.debug(String.format("-Dio.netty.initialSeedUniquifier: 0x%016x (took %d ms)", Long.valueOf(actualCurrent), Long.valueOf(TimeUnit.NANOSECONDS.toMillis(seedGeneratorEndTime - seedGeneratorStartTime))));
            } else {
                logger.debug(String.format("-Dio.netty.initialSeedUniquifier: 0x%016x", Long.valueOf(actualCurrent)));
            }
        }
        return System.nanoTime() ^ next;
    }

    private static long mix64(long z) {
        long z2 = ((z >>> 33) ^ z) * (-49064778989728563L);
        long z3 = ((z2 >>> 33) ^ z2) * (-4265267296055464877L);
        return (z3 >>> 33) ^ z3;
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    public ThreadLocalRandom() {
        super(newSeed());
        this.initialized = true;
    }

    public static ThreadLocalRandom current() {
        return InternalThreadLocalMap.get().random();
    }

    @Override // java.util.Random
    public void setSeed(long seed) {
        if (this.initialized) {
            throw new UnsupportedOperationException();
        }
        this.rnd = (multiplier ^ seed) & mask;
    }

    @Override // java.util.Random
    protected int next(int bits) {
        long j = ((this.rnd * multiplier) + addend) & mask;
        this.rnd = j;
        return (int) (j >>> (48 - bits));
    }

    public int nextInt(int least, int bound) {
        if (least >= bound) {
            throw new IllegalArgumentException();
        }
        return nextInt(bound - least) + least;
    }

    public long nextLong(long n) {
        if (n <= 0) {
            throw new IllegalArgumentException("n must be positive");
        }
        long offset = 0;
        while (n >= 2147483647L) {
            int bits = next(2);
            long half = n >>> 1;
            long nextn = (bits & 2) == 0 ? half : n - half;
            if ((bits & 1) == 0) {
                offset += n - nextn;
            }
            n = nextn;
        }
        return nextInt((int) n) + offset;
    }

    public long nextLong(long least, long bound) {
        if (least >= bound) {
            throw new IllegalArgumentException();
        }
        return nextLong(bound - least) + least;
    }

    public double nextDouble(double n) {
        if (n <= 0.0d) {
            throw new IllegalArgumentException("n must be positive");
        }
        return nextDouble() * n;
    }

    public double nextDouble(double least, double bound) {
        if (least >= bound) {
            throw new IllegalArgumentException();
        }
        return (nextDouble() * (bound - least)) + least;
    }
}
