package io.netty.util.internal.logging;

import io.netty.util.internal.ObjectUtil;
/* loaded from: classes.dex */
public abstract class InternalLoggerFactory {
    private static volatile InternalLoggerFactory defaultFactory;

    protected abstract InternalLogger newInstance(String str);

    private static InternalLoggerFactory newDefaultFactory(String name) {
        try {
            InternalLoggerFactory f = new Slf4JLoggerFactory(true);
            f.newInstance(name).debug("Using SLF4J as the default logging framework");
            return f;
        } catch (Throwable th) {
            try {
                InternalLoggerFactory f2 = Log4J2LoggerFactory.INSTANCE;
                f2.newInstance(name).debug("Using Log4J2 as the default logging framework");
                return f2;
            } catch (Throwable th2) {
                try {
                    InternalLoggerFactory f3 = Log4JLoggerFactory.INSTANCE;
                    f3.newInstance(name).debug("Using Log4J as the default logging framework");
                    return f3;
                } catch (Throwable th3) {
                    InternalLoggerFactory f4 = JdkLoggerFactory.INSTANCE;
                    f4.newInstance(name).debug("Using java.util.logging as the default logging framework");
                    return f4;
                }
            }
        }
    }

    public static InternalLoggerFactory getDefaultFactory() {
        if (defaultFactory == null) {
            defaultFactory = newDefaultFactory(InternalLoggerFactory.class.getName());
        }
        return defaultFactory;
    }

    public static void setDefaultFactory(InternalLoggerFactory defaultFactory2) {
        defaultFactory = (InternalLoggerFactory) ObjectUtil.checkNotNull(defaultFactory2, "defaultFactory");
    }

    public static InternalLogger getInstance(Class<?> clazz) {
        return getInstance(clazz.getName());
    }

    public static InternalLogger getInstance(String name) {
        return getDefaultFactory().newInstance(name);
    }
}
