package io.netty.util.internal.logging;

import com.gyh.wifidata.BuildConfig;
import java.security.AccessController;
import java.security.PrivilegedAction;
import org.apache.logging.log4j.Level;
import org.apache.logging.log4j.Logger;
import org.apache.logging.log4j.spi.ExtendedLogger;
import org.apache.logging.log4j.spi.ExtendedLoggerWrapper;
/* loaded from: classes.dex */
class Log4J2Logger extends ExtendedLoggerWrapper implements InternalLogger {
    private static final boolean VARARGS_ONLY = ((Boolean) AccessController.doPrivileged(new PrivilegedAction<Boolean>() { // from class: io.netty.util.internal.logging.Log4J2Logger.1
        /* JADX WARN: Can't rename method to resolve collision */
        @Override // java.security.PrivilegedAction
        public Boolean run() {
            try {
                Logger.class.getMethod(BuildConfig.BUILD_TYPE, String.class, Object.class);
                return false;
            } catch (NoSuchMethodException e) {
                return true;
            } catch (SecurityException e2) {
                return false;
            }
        }
    })).booleanValue();
    private static final long serialVersionUID = 5485418394879791397L;

    /* JADX INFO: Access modifiers changed from: package-private */
    public Log4J2Logger(Logger logger) {
        super((ExtendedLogger) logger, logger.getName(), logger.getMessageFactory());
        if (VARARGS_ONLY) {
            throw new UnsupportedOperationException("Log4J2 version mismatch");
        }
    }

    @Override // io.netty.util.internal.logging.InternalLogger
    public String name() {
        return getName();
    }

    @Override // io.netty.util.internal.logging.InternalLogger
    public void trace(Throwable t) {
        log(Level.TRACE, "Unexpected exception:", t);
    }

    @Override // io.netty.util.internal.logging.InternalLogger
    public void debug(Throwable t) {
        log(Level.DEBUG, "Unexpected exception:", t);
    }

    @Override // io.netty.util.internal.logging.InternalLogger
    public void info(Throwable t) {
        log(Level.INFO, "Unexpected exception:", t);
    }

    @Override // io.netty.util.internal.logging.InternalLogger
    public void warn(Throwable t) {
        log(Level.WARN, "Unexpected exception:", t);
    }

    @Override // io.netty.util.internal.logging.InternalLogger
    public void error(Throwable t) {
        log(Level.ERROR, "Unexpected exception:", t);
    }

    @Override // io.netty.util.internal.logging.InternalLogger
    public boolean isEnabled(InternalLogLevel level) {
        return isEnabled(toLevel(level));
    }

    @Override // io.netty.util.internal.logging.InternalLogger
    public void log(InternalLogLevel level, String msg) {
        log(toLevel(level), msg);
    }

    @Override // io.netty.util.internal.logging.InternalLogger
    public void log(InternalLogLevel level, String format, Object arg) {
        log(toLevel(level), format, arg);
    }

    @Override // io.netty.util.internal.logging.InternalLogger
    public void log(InternalLogLevel level, String format, Object argA, Object argB) {
        log(toLevel(level), format, argA, argB);
    }

    @Override // io.netty.util.internal.logging.InternalLogger
    public void log(InternalLogLevel level, String format, Object... arguments) {
        log(toLevel(level), format, arguments);
    }

    @Override // io.netty.util.internal.logging.InternalLogger
    public void log(InternalLogLevel level, String msg, Throwable t) {
        log(toLevel(level), msg, t);
    }

    @Override // io.netty.util.internal.logging.InternalLogger
    public void log(InternalLogLevel level, Throwable t) {
        log(toLevel(level), "Unexpected exception:", t);
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    /* renamed from: io.netty.util.internal.logging.Log4J2Logger$2  reason: invalid class name */
    /* loaded from: classes.dex */
    public static /* synthetic */ class AnonymousClass2 {
        static final /* synthetic */ int[] $SwitchMap$io$netty$util$internal$logging$InternalLogLevel;

        static {
            int[] iArr = new int[InternalLogLevel.values().length];
            $SwitchMap$io$netty$util$internal$logging$InternalLogLevel = iArr;
            try {
                iArr[InternalLogLevel.INFO.ordinal()] = 1;
            } catch (NoSuchFieldError e) {
            }
            try {
                $SwitchMap$io$netty$util$internal$logging$InternalLogLevel[InternalLogLevel.DEBUG.ordinal()] = 2;
            } catch (NoSuchFieldError e2) {
            }
            try {
                $SwitchMap$io$netty$util$internal$logging$InternalLogLevel[InternalLogLevel.WARN.ordinal()] = 3;
            } catch (NoSuchFieldError e3) {
            }
            try {
                $SwitchMap$io$netty$util$internal$logging$InternalLogLevel[InternalLogLevel.ERROR.ordinal()] = 4;
            } catch (NoSuchFieldError e4) {
            }
            try {
                $SwitchMap$io$netty$util$internal$logging$InternalLogLevel[InternalLogLevel.TRACE.ordinal()] = 5;
            } catch (NoSuchFieldError e5) {
            }
        }
    }

    private static Level toLevel(InternalLogLevel level) {
        int i = AnonymousClass2.$SwitchMap$io$netty$util$internal$logging$InternalLogLevel[level.ordinal()];
        if (i != 1) {
            if (i != 2) {
                if (i != 3) {
                    if (i != 4) {
                        if (i == 5) {
                            return Level.TRACE;
                        }
                        throw new Error();
                    }
                    return Level.ERROR;
                }
                return Level.WARN;
            }
            return Level.DEBUG;
        }
        return Level.INFO;
    }
}
