package io.netty.util.internal.shaded.org.jctools.queues;

import io.netty.util.internal.shaded.org.jctools.queues.MessagePassingQueue;
import io.netty.util.internal.shaded.org.jctools.util.PortableJvmInfo;
import io.netty.util.internal.shaded.org.jctools.util.UnsafeRefArrayAccess;
/* loaded from: classes.dex */
public class MpscArrayQueue<E> extends MpscArrayQueueL3Pad<E> {
    public MpscArrayQueue(int capacity) {
        super(capacity);
    }

    public boolean offerIfBelowThreshold(E e, int threshold) {
        long pIndex;
        if (e == null) {
            throw null;
        }
        long mask = this.mask;
        long capacity = mask + 1;
        long producerLimit = lvProducerLimit();
        do {
            pIndex = lvProducerIndex();
            long available = producerLimit - pIndex;
            long size = capacity - available;
            if (size >= threshold) {
                long cIndex = lvConsumerIndex();
                long size2 = pIndex - cIndex;
                long producerLimit2 = threshold;
                if (size2 >= producerLimit2) {
                    return false;
                }
                producerLimit = cIndex + capacity;
                soProducerLimit(producerLimit);
            }
        } while (!casProducerIndex(pIndex, pIndex + 1));
        long offset = calcElementOffset(pIndex, mask);
        UnsafeRefArrayAccess.soElement(this.buffer, offset, e);
        return true;
    }

    @Override // java.util.Queue, io.netty.util.internal.shaded.org.jctools.queues.MessagePassingQueue
    public boolean offer(E e) {
        long pIndex;
        if (e == null) {
            throw null;
        }
        long mask = this.mask;
        long producerLimit = lvProducerLimit();
        do {
            pIndex = lvProducerIndex();
            if (pIndex >= producerLimit) {
                long cIndex = lvConsumerIndex();
                long producerLimit2 = cIndex + mask + 1;
                if (pIndex >= producerLimit2) {
                    return false;
                }
                soProducerLimit(producerLimit2);
                producerLimit = producerLimit2;
            }
        } while (!casProducerIndex(pIndex, 1 + pIndex));
        long offset = calcElementOffset(pIndex, mask);
        UnsafeRefArrayAccess.soElement(this.buffer, offset, e);
        return true;
    }

    public final int failFastOffer(E e) {
        if (e == null) {
            throw null;
        }
        long mask = this.mask;
        long capacity = mask + 1;
        long pIndex = lvProducerIndex();
        if (pIndex >= lvProducerLimit()) {
            long cIndex = lvConsumerIndex();
            long producerLimit = cIndex + capacity;
            if (pIndex >= producerLimit) {
                return 1;
            }
            soProducerLimit(producerLimit);
        }
        if (!casProducerIndex(pIndex, 1 + pIndex)) {
            return -1;
        }
        long offset = calcElementOffset(pIndex, mask);
        UnsafeRefArrayAccess.soElement(this.buffer, offset, e);
        return 0;
    }

    @Override // java.util.Queue, io.netty.util.internal.shaded.org.jctools.queues.MessagePassingQueue
    public E poll() {
        long cIndex = lpConsumerIndex();
        long offset = calcElementOffset(cIndex);
        E[] buffer = this.buffer;
        E e = (E) UnsafeRefArrayAccess.lvElement(buffer, offset);
        if (e == null) {
            if (cIndex == lvProducerIndex()) {
                return null;
            }
            do {
                e = (E) UnsafeRefArrayAccess.lvElement(buffer, offset);
            } while (e == null);
            UnsafeRefArrayAccess.spElement(buffer, offset, null);
            soConsumerIndex(1 + cIndex);
            return e;
        }
        UnsafeRefArrayAccess.spElement(buffer, offset, null);
        soConsumerIndex(1 + cIndex);
        return e;
    }

    @Override // java.util.Queue, io.netty.util.internal.shaded.org.jctools.queues.MessagePassingQueue
    public E peek() {
        E[] buffer = this.buffer;
        long cIndex = lpConsumerIndex();
        long offset = calcElementOffset(cIndex);
        E e = (E) UnsafeRefArrayAccess.lvElement(buffer, offset);
        if (e != null) {
            return e;
        }
        if (cIndex != lvProducerIndex()) {
            do {
                e = (E) UnsafeRefArrayAccess.lvElement(buffer, offset);
            } while (e == null);
            return e;
        }
        return null;
    }

    @Override // io.netty.util.internal.shaded.org.jctools.queues.MessagePassingQueue
    public boolean relaxedOffer(E e) {
        return offer(e);
    }

    @Override // io.netty.util.internal.shaded.org.jctools.queues.MessagePassingQueue
    public E relaxedPoll() {
        E[] buffer = this.buffer;
        long cIndex = lpConsumerIndex();
        long offset = calcElementOffset(cIndex);
        E e = (E) UnsafeRefArrayAccess.lvElement(buffer, offset);
        if (e == null) {
            return null;
        }
        UnsafeRefArrayAccess.spElement(buffer, offset, null);
        soConsumerIndex(1 + cIndex);
        return e;
    }

    @Override // io.netty.util.internal.shaded.org.jctools.queues.MessagePassingQueue
    public E relaxedPeek() {
        E[] buffer = this.buffer;
        long mask = this.mask;
        long cIndex = lpConsumerIndex();
        return (E) UnsafeRefArrayAccess.lvElement(buffer, calcElementOffset(cIndex, mask));
    }

    @Override // io.netty.util.internal.shaded.org.jctools.queues.MessagePassingQueue
    public int drain(MessagePassingQueue.Consumer<E> c) {
        return drain(c, capacity());
    }

    @Override // io.netty.util.internal.shaded.org.jctools.queues.MessagePassingQueue
    public int fill(MessagePassingQueue.Supplier<E> s) {
        long result = 0;
        int capacity = capacity();
        do {
            int filled = fill(s, PortableJvmInfo.RECOMENDED_OFFER_BATCH);
            if (filled == 0) {
                return (int) result;
            }
            result += filled;
        } while (result <= capacity);
        return (int) result;
    }

    /* JADX WARN: Multi-variable type inference failed */
    @Override // io.netty.util.internal.shaded.org.jctools.queues.MessagePassingQueue
    public int drain(MessagePassingQueue.Consumer<E> c, int limit) {
        E[] buffer = this.buffer;
        long mask = this.mask;
        long cIndex = lpConsumerIndex();
        for (int i = 0; i < limit; i++) {
            long index = i + cIndex;
            long offset = calcElementOffset(index, mask);
            Object lvElement = UnsafeRefArrayAccess.lvElement(buffer, offset);
            if (lvElement == null) {
                return i;
            }
            UnsafeRefArrayAccess.spElement(buffer, offset, null);
            soConsumerIndex(1 + index);
            c.accept(lvElement);
        }
        return limit;
    }

    @Override // io.netty.util.internal.shaded.org.jctools.queues.MessagePassingQueue
    public int fill(MessagePassingQueue.Supplier<E> s, int limit) {
        long pIndex;
        int actualLimit;
        long mask = this.mask;
        long capacity = 1 + mask;
        long producerLimit = lvProducerLimit();
        do {
            pIndex = lvProducerIndex();
            long available = producerLimit - pIndex;
            if (available <= 0) {
                long cIndex = lvConsumerIndex();
                producerLimit = cIndex + capacity;
                available = producerLimit - pIndex;
                if (available <= 0) {
                    return 0;
                }
                soProducerLimit(producerLimit);
            }
            actualLimit = Math.min((int) available, limit);
        } while (!casProducerIndex(pIndex, actualLimit + pIndex));
        E[] buffer = this.buffer;
        for (int i = 0; i < actualLimit; i++) {
            long offset = calcElementOffset(i + pIndex, mask);
            UnsafeRefArrayAccess.soElement(buffer, offset, s.get());
        }
        return actualLimit;
    }

    /* JADX WARN: Multi-variable type inference failed */
    @Override // io.netty.util.internal.shaded.org.jctools.queues.MessagePassingQueue
    public void drain(MessagePassingQueue.Consumer<E> c, MessagePassingQueue.WaitStrategy w, MessagePassingQueue.ExitCondition exit) {
        E[] buffer = this.buffer;
        long mask = this.mask;
        long cIndex = lpConsumerIndex();
        int counter = 0;
        while (exit.keepRunning()) {
            for (int i = 0; i < 4096; i++) {
                long offset = calcElementOffset(cIndex, mask);
                Object lvElement = UnsafeRefArrayAccess.lvElement(buffer, offset);
                if (lvElement == null) {
                    counter = w.idle(counter);
                } else {
                    cIndex++;
                    counter = 0;
                    UnsafeRefArrayAccess.spElement(buffer, offset, null);
                    soConsumerIndex(cIndex);
                    c.accept(lvElement);
                }
            }
        }
    }

    @Override // io.netty.util.internal.shaded.org.jctools.queues.MessagePassingQueue
    public void fill(MessagePassingQueue.Supplier<E> s, MessagePassingQueue.WaitStrategy w, MessagePassingQueue.ExitCondition exit) {
        int idleCounter = 0;
        while (exit.keepRunning()) {
            if (fill(s, PortableJvmInfo.RECOMENDED_OFFER_BATCH) == 0) {
                idleCounter = w.idle(idleCounter);
            } else {
                idleCounter = 0;
            }
        }
    }
}
